<?php
session_start();
require_once 'config/config.php';
require_once 'includes/functions.php';

// 如果用户已登录，重定向到主页
if (isset($_SESSION['user_id'])) {
    header('Location: home.php');
    exit;
}

$error = '';

// 处理登录表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $username = $_POST['username'];
    $password = $_POST['password'];

    if (empty($username) || empty($password)) {
        $error = '请输入用户名和密码';
    } else {
        // 查询用户
        $sql = "SELECT user_id, username, password_hash, full_name, phone, user_address, user_role FROM users WHERE username = ?";
        $stmt = $conn->prepare($sql);
        if ($stmt) {
            $stmt->bind_param("s", $username);
            $stmt->execute();
            $result = $stmt->get_result();

            if ($result->num_rows == 1) {
                $user = $result->fetch_assoc();

                // 验证密码 - 使用 SHA2 256 哈希验证，与数据库初始设置一致
                if (hash('sha256', $password) === $user['password_hash']) {
                    // 登录成功，设置会话
                    $_SESSION['user_id'] = $user['user_id'];
                    $_SESSION['username'] = $user['username'];
                    $_SESSION['user_role'] = $user['user_role'];
                    $_SESSION['full_name'] = $user['full_name'];

                    // 记录登录操作
                    try {
                        if ($conn && $conn->connect_error == null) {
                            $operationDetails = "用户 {$user['username']} 登录系统";
                            $sql = "INSERT INTO operation_logs (user_id, operation_type, operation_details) VALUES (?, ?, ?)";
                            $logStmt = $conn->prepare($sql);
                            if ($logStmt) {
                                $operationType = '登录';
                                $logStmt->bind_param("iss", $user['user_id'], $operationType, $operationDetails);
                                $logStmt->execute();
                                $logStmt->close();
                            }
                        }
                    } catch (Exception $e) {
                        // 记录日志失败，但不影响登录流程
                        error_log("登录记录失败: " . $e->getMessage());
                    }

                    // 重定向到主页
                    header('Location: home.php');
                    exit;
                } else {
                    $error = '密码错误';
                }
            } else {
                $error = '用户名不存在';
            }
            $stmt->close();
        } else {
            $error = '系统错误，请联系管理员';
        }
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>登录 - <?php echo SITE_NAME; ?></title>
    <link rel="stylesheet" href="css/style.css">
</head>

<body class="login-page">
    <div class="login-container">
        <div class="login-header">
            <h1><?php echo SITE_NAME; ?></h1>
            <p><?php echo SITE_SUBTITLE; ?></p>
        </div>

        <?php if (!empty($error)): ?>
            <div class="alert alert-error"><?php echo $error; ?></div>
        <?php endif; ?>

        <form class="login-form" method="post" action="">
            <div class="form-group">
                <label for="username">用户名</label>
                <input type="text" id="username" name="username" required>
            </div>

            <div class="form-group">
                <label for="password">密码</label>
                <input type="password" id="password" name="password" required>
            </div>

            <div class="form-group">
                <button type="submit" class="btn btn-primary">登录</button>
            </div>
        </form>
    </div>
</body>

</html>