<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 初始化消息变量
$message = '';
$messageType = '';

// 获取筛选参数
$filterType = isset($_GET['filter']) ? sanitize($_GET['filter']) : 'turnover'; // 默认显示周转率分析
$sortBy = isset($_GET['sort_by']) ? sanitize($_GET['sort_by']) : 'turnover_rate'; // 默认按周转率排序
$sortOrder = isset($_GET['order']) ? sanitize($_GET['order']) : 'asc'; // 默认升序排列（周转率低的先显示）
$page = isset($_GET['p']) ? intval($_GET['p']) : 1;
$limit = 20; // 每页显示商品数量
$offset = ($page - 1) * $limit;

// 时间周期筛选
$periodType = isset($_GET['period']) ? sanitize($_GET['period']) : 'month'; // 默认显示月度数据
$periodDate = isset($_GET['date']) ? sanitize($_GET['date']) : date('Y-m-01'); // 默认显示当月

// 计算上一周期的日期（用于环比计算）
$previousPeriodDate = '';
if ($periodType == 'month') {
    $previousPeriodDate = date('Y-m-01', strtotime("$periodDate -1 month"));
} elseif ($periodType == 'quarter') {
    $previousPeriodDate = date('Y-m-d', strtotime("$periodDate -3 month"));
} elseif ($periodType == 'year') {
    $previousPeriodDate = date('Y-m-d', strtotime("$periodDate -1 year"));
} else {
    $previousPeriodDate = date('Y-m-d', strtotime("$periodDate -7 days"));
}

// 库存预警阈值
$lowStockThreshold = 10; // 低库存阈值
$highStockThreshold = 100; // 高库存阈值
$slowMovingDays = 30; // 滞销天数阈值

// 验证筛选类型是否有效
$validFilterTypes = ['turnover', 'slow_moving', 'out_of_stock', 'over_stock'];
if (!in_array($filterType, $validFilterTypes)) {
    $filterType = 'turnover';
}

// 验证排序字段是否有效
$validSortFields = ['turnover_rate', 'stock_days', 'stock_quantity', 'last_sold_days'];
if (!in_array($sortBy, $validSortFields)) {
    $sortBy = $filterType == 'turnover' ? 'turnover_rate' : 'last_sold_days';
}

// 验证排序顺序是否有效
$validSortOrders = ['asc', 'desc'];
if (!in_array($sortOrder, $validSortOrders)) {
    $sortOrder = $filterType == 'turnover' || $filterType == 'out_of_stock' ? 'asc' : 'desc';
}

// 验证周期类型是否有效
$validPeriodTypes = ['week', 'month', 'quarter', 'year'];
if (!in_array($periodType, $validPeriodTypes)) {
    $periodType = 'month';
}

// 验证日期格式是否有效
if (!preg_match('/^\d{4}-\d{2}-\d{2}$/', $periodDate)) {
    $periodDate = date('Y-m-01');
}

// 构建排序字段
$sortField = '';
switch ($sortBy) {
    case 'turnover_rate':
        $sortField = 'ia.turnover_rate';
        break;
    case 'stock_days':
        $sortField = 'ia.stock_days';
        break;
    case 'stock_quantity':
        $sortField = 'p.stock_quantity';
        break;
    case 'last_sold_days':
        $sortField = 'ia.last_sold_days';
        break;
    default:
        $sortField = 'ia.turnover_rate';
}

// 构建筛选条件
$whereClause = 'ia.period_type = ? AND ia.stat_date = ?';
$queryParams = [$periodType, $periodDate];
$paramTypes = 'ss';

switch ($filterType) {
    case 'slow_moving':
        $whereClause .= ' AND ia.last_sold_days > ?';
        $queryParams[] = $slowMovingDays;
        $paramTypes .= 'i';
        break;
    case 'out_of_stock':
        $whereClause .= ' AND p.stock_quantity <= ?';
        $queryParams[] = $lowStockThreshold;
        $paramTypes .= 'i';
        break;
    case 'over_stock':
        $whereClause .= ' AND p.stock_quantity > ?';
        $queryParams[] = $highStockThreshold;
        $paramTypes .= 'i';
        break;
}

// 查询统计数据
$sql = "SELECT ia.*, p.product_name, p.barcode, p.unit, p.unit_price, p.stock_quantity, 
        p.brand, p.manufacturer, p.reorder_level
        FROM inventory_analysis ia
        JOIN products p ON ia.product_id = p.product_id
        WHERE $whereClause
        ORDER BY $sortField $sortOrder
        LIMIT ?, ?";

// 添加分页参数
$queryParams[] = $offset;
$queryParams[] = $limit;
$paramTypes .= 'ii';

$result = executeQuery($conn, $sql, $paramTypes, $queryParams);

// 统计总记录数用于分页
$countSql = "SELECT COUNT(*) as total 
             FROM inventory_analysis ia
             JOIN products p ON ia.product_id = p.product_id
             WHERE $whereClause";

$countResult = executeQuery($conn, $countSql, substr($paramTypes, 0, -2), array_slice($queryParams, 0, -2));
$totalRecords = ($countResult['success'] && !empty($countResult['data'])) ? $countResult['data'][0]['total'] : 0;
$totalPages = ceil($totalRecords / $limit);

// 如果没有数据，生成一条提示信息
if (!$result['success'] || empty($result['data'])) {
    $message = '当前筛选条件下没有库存分析数据。';
    $messageType = 'info';
}

// 获取库存统计卡片数据
// 1. 平均周转率
$avgTurnoverSql = "SELECT AVG(turnover_rate) as avg_turnover 
                  FROM inventory_analysis 
                  WHERE period_type = ? AND stat_date = ?";
$avgTurnoverResult = executeQuery($conn, $avgTurnoverSql, 'ss', [$periodType, $periodDate]);
$avgTurnoverRate = ($avgTurnoverResult['success'] && !empty($avgTurnoverResult['data']))
    ? round($avgTurnoverResult['data'][0]['avg_turnover'], 2)
    : 0;

// 上一周期平均周转率
$prevAvgTurnoverSql = "SELECT AVG(turnover_rate) as avg_turnover 
                      FROM inventory_analysis 
                      WHERE period_type = ? AND stat_date = ?";
$prevAvgTurnoverResult = executeQuery($conn, $prevAvgTurnoverSql, 'ss', [$periodType, $previousPeriodDate]);
$prevAvgTurnoverRate = ($prevAvgTurnoverResult['success'] && !empty($prevAvgTurnoverResult['data']))
    ? round($prevAvgTurnoverResult['data'][0]['avg_turnover'], 2)
    : 0;

// 周转率环比计算
$turnoverRateChange = ($prevAvgTurnoverRate > 0)
    ? round(($avgTurnoverRate - $prevAvgTurnoverRate) / $prevAvgTurnoverRate * 100, 1)
    : 0;

// 2. 滞销商品数
$slowMovingSql = "SELECT COUNT(*) as slow_moving_count 
                 FROM inventory_analysis 
                 WHERE period_type = ? AND stat_date = ? AND slow_moving_days > ?";
$slowMovingResult = executeQuery($conn, $slowMovingSql, 'ssi', [$periodType, $periodDate, $slowMovingDays]);
$slowMovingCount = ($slowMovingResult['success'] && !empty($slowMovingResult['data']))
    ? $slowMovingResult['data'][0]['slow_moving_count']
    : 0;

// 上一周期滞销商品数
$prevSlowMovingSql = "SELECT COUNT(*) as slow_moving_count 
                     FROM inventory_analysis 
                     WHERE period_type = ? AND stat_date = ? AND slow_moving_days > ?";
$prevSlowMovingResult = executeQuery($conn, $prevSlowMovingSql, 'ssi', [$periodType, $previousPeriodDate, $slowMovingDays]);
$prevSlowMovingCount = ($prevSlowMovingResult['success'] && !empty($prevSlowMovingResult['data']))
    ? $prevSlowMovingResult['data'][0]['slow_moving_count']
    : 0;

// 滞销商品环比计算
$slowMovingChange = ($prevSlowMovingCount > 0)
    ? round(($slowMovingCount - $prevSlowMovingCount) / $prevSlowMovingCount * 100, 1)
    : 0;

// 3. 库存预警数
$alertSql = "SELECT COUNT(*) as alert_count 
            FROM inventory_analysis 
            WHERE period_type = ? AND stat_date = ? AND is_alert = 1";
$alertResult = executeQuery($conn, $alertSql, 'ss', [$periodType, $periodDate]);
$alertCount = ($alertResult['success'] && !empty($alertResult['data']))
    ? $alertResult['data'][0]['alert_count']
    : 0;

// 上一周期库存预警数
$prevAlertSql = "SELECT COUNT(*) as alert_count 
                FROM inventory_analysis 
                WHERE period_type = ? AND stat_date = ? AND is_alert = 1";
$prevAlertResult = executeQuery($conn, $prevAlertSql, 'ss', [$periodType, $previousPeriodDate]);
$prevAlertCount = ($prevAlertResult['success'] && !empty($prevAlertResult['data']))
    ? $prevAlertResult['data'][0]['alert_count']
    : 0;

// 库存预警环比计算
$alertChange = ($prevAlertCount > 0)
    ? round(($alertCount - $prevAlertCount) / $prevAlertCount * 100, 1)
    : 0;

// 4. 积压商品价值
$overStockValueSql = "SELECT SUM(p.unit_price * p.stock_quantity) as total_value 
                     FROM inventory_analysis ia
                     JOIN products p ON ia.product_id = p.product_id 
                     WHERE ia.period_type = ? AND ia.stat_date = ? AND ia.days_of_inventory > 90";
$overStockValueResult = executeQuery($conn, $overStockValueSql, 'ss', [$periodType, $periodDate]);
$overStockValue = ($overStockValueResult['success'] && !empty($overStockValueResult['data']))
    ? round($overStockValueResult['data'][0]['total_value'], 2)
    : 0;

// 上一周期积压商品价值
$prevOverStockValueSql = "SELECT SUM(p.unit_price * p.stock_quantity) as total_value 
                         FROM inventory_analysis ia
                         JOIN products p ON ia.product_id = p.product_id 
                         WHERE ia.period_type = ? AND ia.stat_date = ? AND ia.days_of_inventory > 90";
$prevOverStockValueResult = executeQuery($conn, $prevOverStockValueSql, 'ss', [$periodType, $previousPeriodDate]);
$prevOverStockValue = ($prevOverStockValueResult['success'] && !empty($prevOverStockValueResult['data']))
    ? round($prevOverStockValueResult['data'][0]['total_value'], 2)
    : 0;

// 积压商品价值环比计算
$overStockValueChange = ($prevOverStockValue > 0)
    ? round(($overStockValue - $prevOverStockValue) / $prevOverStockValue * 100, 1)
    : 0;

// 构建页面URL的函数
function buildPageUrl($page, $filterType, $sortBy, $sortOrder, $periodType, $periodDate)
{
    return "index.php?page=inventory&filter=$filterType&sort_by=$sortBy&order=$sortOrder&period=$periodType&date=$periodDate&p=$page";
}

// 获取排序链接
function getSortLink($field, $currentSortBy, $currentSortOrder, $filterType, $periodType, $periodDate)
{
    $newOrder = ($currentSortBy == $field && $currentSortOrder == 'desc') ? 'asc' : 'desc';
    $sortIcon = '';

    if ($currentSortBy == $field) {
        $sortIcon = ($currentSortOrder == 'desc') ? '▼' : '▲';
    }

    return "index.php?page=inventory&filter=$filterType&sort_by=$field&order=$newOrder&period=$periodType&date=$periodDate" . $sortIcon;
}

// 格式化数字的函数
function formatNumber($number, $decimals = 2)
{
    return number_format($number, $decimals, '.', ',');
}

// 获取库存状态标签
function getStockStatusLabel($stockQty, $reorderLevel, $lastSoldDays, $slowMovingDays)
{
    if ($stockQty <= 0) {
        return '<span class="stock-status out-of-stock">缺货</span>';
    } elseif ($stockQty <= $reorderLevel) {
        return '<span class="stock-status low-stock">低库存</span>';
    } elseif ($lastSoldDays > $slowMovingDays) {
        return '<span class="stock-status slow-moving">滞销</span>';
    } else {
        return '<span class="stock-status normal">正常</span>';
    }
}

// 获取周转率评级
function getTurnoverRating($turnoverRate)
{
    if ($turnoverRate <= 1) {
        return '<span class="rating poor">较差</span>';
    } elseif ($turnoverRate <= 3) {
        return '<span class="rating average">一般</span>';
    } elseif ($turnoverRate <= 6) {
        return '<span class="rating good">良好</span>';
    } else {
        return '<span class="rating excellent">优秀</span>';
    }
}

// 获取筛选类型标签
function getFilterTypeLabel($filterType)
{
    switch ($filterType) {
        case 'turnover':
            return '周转率分析';
        case 'slow_moving':
            return '滞销商品分析';
        case 'out_of_stock':
            return '缺货风险分析';
        case 'over_stock':
            return '库存积压分析';
        default:
            return '周转率分析';
    }
}
?>

<div class="page-header">
    <h3>库存分析</h3>
    <p class="page-description">分析库存周转率、滞销商品、缺货风险，优化库存管理</p>
</div>

<!-- 筛选表单 -->
<div class="filter-container">
    <form action="index.php" method="get" class="filter-form">
        <input type="hidden" name="page" value="inventory">

        <div class="form-group">
            <label for="filter">分析类型:</label>
            <select id="filter" name="filter" class="form-control">
                <option value="turnover" <?php echo $filterType == 'turnover' ? 'selected' : ''; ?>>周转率分析</option>
                <option value="slow_moving" <?php echo $filterType == 'slow_moving' ? 'selected' : ''; ?>>滞销商品分析</option>
                <option value="out_of_stock" <?php echo $filterType == 'out_of_stock' ? 'selected' : ''; ?>>缺货风险分析</option>
                <option value="over_stock" <?php echo $filterType == 'over_stock' ? 'selected' : ''; ?>>库存积压分析</option>
            </select>
        </div>

        <div class="form-group">
            <label for="period">统计周期:</label>
            <select id="period" name="period" class="form-control">
                <option value="week" <?php echo $periodType == 'week' ? 'selected' : ''; ?>>周</option>
                <option value="month" <?php echo $periodType == 'month' ? 'selected' : ''; ?>>月</option>
                <option value="quarter" <?php echo $periodType == 'quarter' ? 'selected' : ''; ?>>季度</option>
                <option value="year" <?php echo $periodType == 'year' ? 'selected' : ''; ?>>年</option>
            </select>
        </div>

        <div class="form-group">
            <label for="date">日期:</label>
            <input type="date" id="date" name="date" class="form-control" value="<?php echo $periodDate; ?>">
        </div>

        <div class="form-actions">
            <button type="submit" class="btn btn-primary">查询</button>
        </div>
    </form>
</div>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<!-- 库存分析统计卡片 -->
<div class="stats-cards">
    <div class="stat-card">
        <div class="stat-icon">
            <i class="fa fa-refresh"></i>
        </div>
        <div class="stat-content">
            <h4>平均周转率</h4>
            <div class="stat-value"><?php echo number_format($avgTurnoverRate, 1); ?></div>
            <div class="stat-footer">上月: <?php echo number_format($prevAvgTurnoverRate, 1); ?> <span class="<?php echo ($turnoverRateChange > 0 ? 'up' : 'down'); ?>"><?php echo ($turnoverRateChange > 0 ? '↑ ' . abs($turnoverRateChange) : '↓ ' . abs($turnoverRateChange)); ?>%</span></div>
        </div>
    </div>

    <div class="stat-card">
        <div class="stat-icon">
            <i class="fa fa-clock-o"></i>
        </div>
        <div class="stat-content">
            <h4>滞销商品数</h4>
            <div class="stat-value"><?php echo $slowMovingCount; ?></div>
            <div class="stat-footer">上月: <?php echo $prevSlowMovingCount; ?> <span class="<?php echo ($slowMovingChange > 0 ? 'up danger' : 'down success'); ?>"><?php echo ($slowMovingChange > 0 ? '↑ ' . abs($slowMovingChange) : '↓ ' . abs($slowMovingChange)); ?>%</span></div>
        </div>
    </div>

    <div class="stat-card">
        <div class="stat-icon">
            <i class="fa fa-exclamation-triangle"></i>
        </div>
        <div class="stat-content">
            <h4>库存预警数</h4>
            <div class="stat-value"><?php echo $alertCount; ?></div>
            <div class="stat-footer">上月: <?php echo $prevAlertCount; ?> <span class="<?php echo ($alertChange > 0 ? 'up danger' : 'down success'); ?>"><?php echo ($alertChange > 0 ? '↑ ' . abs($alertChange) : '↓ ' . abs($alertChange)); ?>%</span></div>
        </div>
    </div>

    <div class="stat-card">
        <div class="stat-icon">
            <i class="fa fa-cubes"></i>
        </div>
        <div class="stat-content">
            <h4>积压商品价值</h4>
            <div class="stat-value">¥<?php echo number_format($overStockValue, 2); ?></div>
            <div class="stat-footer">上月: ¥<?php echo number_format($prevOverStockValue, 2); ?> <span class="<?php echo ($overStockValueChange < 0 ? 'down' : 'up'); ?>"><?php echo ($overStockValueChange < 0 ? '↓ ' . abs($overStockValueChange) : '↑ ' . $overStockValueChange); ?>%</span></div>
        </div>
    </div>
</div>

<!-- 库存分析表格 -->
<?php if ($result['success'] && !empty($result['data'])): ?>
    <div class="data-container">
        <div class="data-header">
            <div class="filter-title">
                <?php echo getFilterTypeLabel($filterType); ?>
            </div>
            <div class="total-info">
                共找到 <strong><?php echo $totalRecords; ?></strong> 条记录
            </div>
        </div>

        <table class="data-table">
            <thead>
                <tr>
                    <th>商品名称</th>
                    <th>条码</th>
                    <th>品牌</th>
                    <th>
                        <a href="<?php echo getSortLink('stock_quantity', $sortBy, $sortOrder, $filterType, $periodType, $periodDate); ?>" class="sort-link">
                            库存数量 <?php echo ($sortBy == 'stock_quantity') ? ($sortOrder == 'desc' ? '▼' : '▲') : ''; ?>
                        </a>
                    </th>
                    <th>库存预警值</th>
                    <th>
                        <a href="<?php echo getSortLink('turnover_rate', $sortBy, $sortOrder, $filterType, $periodType, $periodDate); ?>" class="sort-link">
                            周转率 <?php echo ($sortBy == 'turnover_rate') ? ($sortOrder == 'desc' ? '▼' : '▲') : ''; ?>
                        </a>
                    </th>
                    <th>
                        <a href="<?php echo getSortLink('stock_days', $sortBy, $sortOrder, $filterType, $periodType, $periodDate); ?>" class="sort-link">
                            库存天数 <?php echo ($sortBy == 'stock_days') ? ($sortOrder == 'desc' ? '▼' : '▲') : ''; ?>
                        </a>
                    </th>
                    <th>
                        <a href="<?php echo getSortLink('last_sold_days', $sortBy, $sortOrder, $filterType, $periodType, $periodDate); ?>" class="sort-link">
                            最近销售天数 <?php echo ($sortBy == 'last_sold_days') ? ($sortOrder == 'desc' ? '▼' : '▲') : ''; ?>
                        </a>
                    </th>
                    <th>库存状态</th>
                    <th>评级</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($result['data'] as $row): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($row['product_name']); ?></td>
                        <td><?php echo htmlspecialchars($row['barcode']); ?></td>
                        <td><?php echo htmlspecialchars($row['brand'] ?: '-'); ?></td>
                        <td class="text-right"><?php echo formatNumber($row['stock_quantity'], 0); ?></td>
                        <td class="text-right"><?php echo formatNumber($row['reorder_level'], 0); ?></td>
                        <td class="text-right"><?php echo formatNumber($row['turnover_rate'], 2); ?></td>
                        <td class="text-right"><?php echo formatNumber($row['stock_days'], 0); ?></td>
                        <td class="text-right"><?php echo formatNumber($row['last_sold_days'], 0); ?></td>
                        <td class="text-center">
                            <?php echo getStockStatusLabel($row['stock_quantity'], $row['reorder_level'], $row['last_sold_days'], $slowMovingDays); ?>
                        </td>
                        <td class="text-center">
                            <?php echo getTurnoverRating($row['turnover_rate']); ?>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>

        <!-- 分页 -->
        <?php if ($totalPages > 1): ?>
            <div class="pagination">
                <?php if ($page > 1): ?>
                    <a href="<?php echo buildPageUrl(1, $filterType, $sortBy, $sortOrder, $periodType, $periodDate); ?>" class="page-link">首页</a>
                    <a href="<?php echo buildPageUrl($page - 1, $filterType, $sortBy, $sortOrder, $periodType, $periodDate); ?>" class="page-link">上一页</a>
                <?php endif; ?>

                <?php
                $startPage = max(1, $page - 2);
                $endPage = min($totalPages, $startPage + 4);

                if ($endPage - $startPage < 4) {
                    $startPage = max(1, $endPage - 4);
                }

                for ($i = $startPage; $i <= $endPage; $i++):
                ?>
                    <a href="<?php echo buildPageUrl($i, $filterType, $sortBy, $sortOrder, $periodType, $periodDate); ?>" class="page-link <?php echo ($i == $page) ? 'active' : ''; ?>"><?php echo $i; ?></a>
                <?php endfor; ?>

                <?php if ($page < $totalPages): ?>
                    <a href="<?php echo buildPageUrl($page + 1, $filterType, $sortBy, $sortOrder, $periodType, $periodDate); ?>" class="page-link">下一页</a>
                    <a href="<?php echo buildPageUrl($totalPages, $filterType, $sortBy, $sortOrder, $periodType, $periodDate); ?>" class="page-link">末页</a>
                <?php endif; ?>
            </div>
        <?php endif; ?>
    </div>
<?php endif; ?>

<style>
    .page-header {
        margin-bottom: 20px;
    }

    .page-description {
        color: #666;
        margin-top: 5px;
    }

    .filter-container {
        background-color: #f9f9f9;
        padding: 15px;
        border-radius: 5px;
        margin-bottom: 20px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
    }

    .filter-form {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
        align-items: flex-end;
    }

    .form-group {
        margin-bottom: 0;
    }

    .stats-cards {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
        margin-bottom: 20px;
    }

    .stat-card {
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        padding: 20px;
        flex: 1;
        min-width: 200px;
        display: flex;
        align-items: center;
    }

    .stat-icon {
        font-size: 2rem;
        color: #007bff;
        margin-right: 15px;
        width: 50px;
        height: 50px;
        background-color: #e6f2ff;
        border-radius: 50%;
        display: flex;
        align-items: center;
        justify-content: center;
    }

    .stat-content {
        flex: 1;
    }

    .stat-content h4 {
        margin: 0 0 10px 0;
        font-size: 0.9rem;
        color: #666;
    }

    .stat-value {
        font-size: 1.5rem;
        font-weight: bold;
        margin-bottom: 5px;
    }

    .stat-footer {
        font-size: 0.8rem;
        color: #666;
    }

    .up {
        color: #28a745;
    }

    .down {
        color: #0066cc;
    }

    .up.danger {
        color: #dc3545;
    }

    .data-container {
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
    }

    .data-header {
        padding: 10px 15px;
        border-bottom: 1px solid #eee;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .filter-title {
        font-weight: bold;
        color: #333;
    }

    .total-info {
        color: #666;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 12px 15px;
        text-align: left;
        border-bottom: 1px solid #eee;
    }

    .data-table th {
        background-color: #f9f9f9;
        font-weight: bold;
    }

    .data-table tbody tr:hover {
        background-color: #f5f5f5;
    }

    .text-center {
        text-align: center;
    }

    .text-right {
        text-align: right;
    }

    .sort-link {
        color: inherit;
        text-decoration: none;
        display: flex;
        align-items: center;
        justify-content: space-between;
    }

    .sort-link:hover {
        color: #007bff;
    }

    .stock-status {
        display: inline-block;
        padding: 3px 8px;
        border-radius: 3px;
        font-size: 0.75rem;
        font-weight: bold;
    }

    .out-of-stock {
        background-color: #f8d7da;
        color: #721c24;
    }

    .low-stock {
        background-color: #fff3cd;
        color: #856404;
    }

    .slow-moving {
        background-color: #d1ecf1;
        color: #0c5460;
    }

    .normal {
        background-color: #d4edda;
        color: #155724;
    }

    .rating {
        display: inline-block;
        padding: 3px 8px;
        border-radius: 3px;
        font-size: 0.75rem;
        font-weight: bold;
    }

    .poor {
        background-color: #f8d7da;
        color: #721c24;
    }

    .average {
        background-color: #fff3cd;
        color: #856404;
    }

    .good {
        background-color: #d4edda;
        color: #155724;
    }

    .excellent {
        background-color: #cce5ff;
        color: #004085;
    }

    .pagination {
        display: flex;
        justify-content: center;
        padding: 20px 0;
        gap: 5px;
    }

    .page-link {
        display: inline-block;
        padding: 5px 10px;
        background-color: #f9f9f9;
        border: 1px solid #ddd;
        color: #333;
        text-decoration: none;
        border-radius: 3px;
    }

    .page-link.active {
        background-color: #007bff;
        color: white;
        border-color: #007bff;
    }

    .page-link:hover:not(.active) {
        background-color: #e9e9e9;
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 根据选择的周期类型，修改日期输入的类型和格式
        const periodSelect = document.getElementById('period');
        const dateInput = document.getElementById('date');

        periodSelect.addEventListener('change', function() {
            const periodType = this.value;

            if (periodType === 'year') {
                dateInput.type = 'text';
                dateInput.pattern = '\\d{4}';
                dateInput.placeholder = 'YYYY';
                // 只保留年份
                if (dateInput.value) {
                    dateInput.value = dateInput.value.substr(0, 4);
                }
            } else if (periodType === 'quarter') {
                dateInput.type = 'text';
                dateInput.pattern = '\\d{4}-Q[1-4]';
                dateInput.placeholder = 'YYYY-Q1';
                // 修改为季度格式
                if (dateInput.value) {
                    const year = dateInput.value.substr(0, 4);
                    const month = parseInt(dateInput.value.substr(5, 2));
                    const quarter = Math.ceil(month / 3);
                    dateInput.value = year + '-Q' + quarter;
                }
            } else {
                dateInput.type = 'date';
            }
        });

        // 初始化时也要调用一次
        if (periodSelect.value === 'year') {
            dateInput.type = 'text';
            dateInput.pattern = '\\d{4}';
            dateInput.placeholder = 'YYYY';
            if (dateInput.value) {
                dateInput.value = dateInput.value.substr(0, 4);
            }
        } else if (periodSelect.value === 'quarter') {
            dateInput.type = 'text';
            dateInput.pattern = '\\d{4}-Q[1-4]';
            dateInput.placeholder = 'YYYY-Q1';
            if (dateInput.value) {
                const year = dateInput.value.substr(0, 4);
                const month = parseInt(dateInput.value.substr(5, 2));
                const quarter = Math.ceil(month / 3);
                dateInput.value = year + '-Q' + quarter;
            }
        }
    });
</script>