<?php
// 防止直接访问
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 获取查询参数
$warehouse_id = isset($_GET['warehouse_id']) ? (int)$_GET['warehouse_id'] : 0;
$product_id = isset($_GET['product_id']) ? (int)$_GET['product_id'] : 0;
$product_name = isset($_GET['product_name']) ? trim($_GET['product_name']) : '';
$barcode = isset($_GET['barcode']) ? trim($_GET['barcode']) : '';
$min_stock = isset($_GET['min_stock']) ? (int)$_GET['min_stock'] : 0;

// 构建查询条件
$whereClause = "";
$params = [];
$types = "";

if ($warehouse_id > 0) {
    $whereClause .= (!empty($whereClause) ? " AND " : " WHERE ") . "i.warehouse_id = ?";
    $params[] = $warehouse_id;
    $types .= "i";
}

if ($product_id > 0) {
    $whereClause .= (!empty($whereClause) ? " AND " : " WHERE ") . "i.product_id = ?";
    $params[] = $product_id;
    $types .= "i";
}

if (!empty($product_name)) {
    $product_name = "%" . $product_name . "%";
    $whereClause .= (!empty($whereClause) ? " AND " : " WHERE ") . "p.product_name LIKE ?";
    $params[] = $product_name;
    $types .= "s";
}

if (!empty($barcode)) {
    $barcode = "%" . $barcode . "%";
    $whereClause .= (!empty($whereClause) ? " AND " : " WHERE ") . "p.barcode LIKE ?";
    $params[] = $barcode;
    $types .= "s";
}

if ($min_stock > 0) {
    $whereClause .= (!empty($whereClause) ? " AND " : " WHERE ") . "i.quantity <= ?";
    $params[] = $min_stock;
    $types .= "i";
}

// 获取库存列表
$inventories = [];
$sql = "SELECT i.inventory_id, i.product_id, i.warehouse_id, i.quantity as current_stock, i.min_stock_level as min_stock, 
        i.updated_at, p.product_name, p.barcode, p.unit, p.unit_price, 
        w.warehouse_name, w.type as warehouse_type
        FROM inventory i
        JOIN products p ON i.product_id = p.product_id
        JOIN warehouses w ON i.warehouse_id = w.warehouse_id
        $whereClause
        ORDER BY w.warehouse_name, p.product_name";

$stmt = $conn->prepare($sql);

if ($stmt) {
    if (!empty($params)) {
        $stmt->bind_param($types, ...$params);
    }

    $stmt->execute();
    $result = $stmt->get_result();
    while ($row = $result->fetch_assoc()) {
        $inventories[] = $row;
    }
    $stmt->close();
} else {
    // 处理prepare失败的情况
    echo '<div class="alert alert-error">数据库查询准备失败: ' . $conn->error . '</div>';
}

// 获取所有仓库
$warehouses = [];
$warehouseSql = "SELECT warehouse_id, warehouse_name, type as warehouse_type FROM warehouses ORDER BY warehouse_name";
$warehouseStmt = $conn->prepare($warehouseSql);
if ($warehouseStmt) {
    $warehouseStmt->execute();
    $warehouseResult = $warehouseStmt->get_result();
    while ($row = $warehouseResult->fetch_assoc()) {
        $warehouses[] = $row;
    }
    $warehouseStmt->close();
} else {
    echo '<div class="alert alert-error">获取仓库列表失败: ' . $conn->error . '</div>';
}

// 获取所有商品
$products = [];
$productSql = "SELECT product_id, product_name, barcode FROM products ORDER BY product_name";
$productStmt = $conn->prepare($productSql);
if ($productStmt) {
    $productStmt->execute();
    $productResult = $productStmt->get_result();
    while ($row = $productResult->fetch_assoc()) {
        $products[] = $row;
    }
    $productStmt->close();
} else {
    echo '<div class="alert alert-error">获取商品列表失败: ' . $conn->error . '</div>';
}

// 计算库存总量和总价值
$totalStock = 0;
$totalValue = 0;
foreach ($inventories as $inventory) {
    $totalStock += $inventory['current_stock'];
    $totalValue += $inventory['current_stock'] * $inventory['unit_price'];
}
?>

<!-- jQuery库必须在Select2之前引入 -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<!-- 引入Select2库 -->
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>

<!-- 搜索表单 -->
<div class="module-tools">
    <div class="tool-left">
        <h4>库存查询</h4>
    </div>
    <div class="tool-right">
        <form action="index.php" method="get" class="search-form">
            <input type="hidden" name="page" value="query">

            <div class="search-group">
                <select name="warehouse_id" class="search-input select2-warehouse">
                    <option value="">所有仓库</option>
                    <?php foreach ($warehouses as $warehouse): ?>
                        <option value="<?php echo $warehouse['warehouse_id']; ?>" <?php echo $warehouse_id == $warehouse['warehouse_id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($warehouse['warehouse_name'] . ' (' . getWarehouseTypeChinese($warehouse['warehouse_type']) . ')'); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="search-group">
                <select name="product_id" class="search-input select2-product">
                    <option value="">所有商品</option>
                    <?php foreach ($products as $product): ?>
                        <option value="<?php echo $product['product_id']; ?>" <?php echo $product_id == $product['product_id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($product['product_name'] . ' (' . $product['barcode'] . ')'); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="search-group">
                <input type="text" name="product_name" class="search-input" placeholder="商品名称" value="<?php echo htmlspecialchars($product_name); ?>">
            </div>

            <div class="search-group">
                <input type="text" name="barcode" class="search-input" placeholder="条码" value="<?php echo htmlspecialchars($barcode); ?>">
            </div>

            <div class="search-group">
                <input type="number" name="min_stock" class="search-input" placeholder="库存低于" value="<?php echo $min_stock > 0 ? $min_stock : ''; ?>" min="0">
            </div>

            <button type="submit" class="btn btn-secondary">搜索</button>
            <a href="index.php?page=query" class="btn btn-secondary">重置</a>
        </form>
    </div>
</div>

<!-- 库存统计信息 -->
<div class="inventory-stats">
    <div class="stat-item">
        <span class="stat-label">查询结果数:</span>
        <span class="stat-value"><?php echo count($inventories); ?></span>
    </div>
    <div class="stat-item">
        <span class="stat-label">库存总量:</span>
        <span class="stat-value"><?php echo $totalStock; ?></span>
    </div>
    <div class="stat-item">
        <span class="stat-label">库存总价值:</span>
        <span class="stat-value">¥<?php echo number_format($totalValue, 2); ?></span>
    </div>
</div>

<!-- 库存列表 -->
<div class="data-wrapper">
    <table class="data-table">
        <thead>
            <tr>
                <th>ID</th>
                <th>仓库</th>
                <th>商品名称</th>
                <th>条码</th>
                <th>单位</th>
                <th>单价</th>
                <th>当前库存</th>
                <th>最低库存</th>
                <th>库存金额</th>
                <th>库存状态</th>
                <th>更新时间</th>
                <th>操作</th>
            </tr>
        </thead>
        <tbody>
            <?php if (count($inventories) > 0): ?>
                <?php foreach ($inventories as $inventory): ?>
                    <?php
                    $stockStatus = '';
                    if ($inventory['current_stock'] < $inventory['min_stock']) {
                        $stockStatus = '<span class="badge badge-danger">库存不足</span>';
                    } else {
                        $stockStatus = '<span class="badge badge-success">库存正常</span>';
                    }

                    $stockValue = $inventory['current_stock'] * $inventory['unit_price'];
                    ?>
                    <tr class="stock-status-<?php echo $stockStatus; ?>">
                        <td><?php echo $inventory['inventory_id']; ?></td>
                        <td><?php echo htmlspecialchars($inventory['warehouse_name']); ?></td>
                        <td><?php echo htmlspecialchars($inventory['product_name']); ?></td>
                        <td><?php echo htmlspecialchars($inventory['barcode']); ?></td>
                        <td><?php echo htmlspecialchars($inventory['unit']); ?></td>
                        <td><?php echo number_format($inventory['unit_price'], 2); ?></td>
                        <td><?php echo $inventory['current_stock']; ?></td>
                        <td><?php echo $inventory['min_stock']; ?></td>
                        <td><?php echo number_format($stockValue, 2); ?></td>
                        <td>
                            <?php echo $stockStatus; ?>
                        </td>
                        <td><?php echo $inventory['updated_at']; ?></td>
                        <td class="actions">
                            <a href="index.php?page=batch&product_id=<?php echo $inventory['product_id']; ?>&warehouse_id=<?php echo $inventory['warehouse_id']; ?>" class="btn btn-secondary btn-sm">查看批次</a>
                            <a href="index.php?page=transfer&source_id=<?php echo $inventory['warehouse_id']; ?>&product_id=<?php echo $inventory['product_id']; ?>" class="btn btn-primary btn-sm">库存调拨</a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="12" class="text-center">暂无库存数据</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>
</div>

<style>
    .inventory-stats {
        display: flex;
        justify-content: flex-start;
        margin-bottom: 20px;
        background-color: #f9f9f9;
        padding: 15px;
        border-radius: 5px;
    }

    .stat-item {
        margin-right: 30px;
    }

    .stat-label {
        font-weight: bold;
        margin-right: 5px;
    }

    .stat-value {
        color: #2c3e50;
    }

    .stock-status-warning td {
        background-color: #fff3cd;
    }

    .stock-status-out td {
        background-color: #f8d7da;
    }

    /* Select2样式修正 */
    .select2-container {
        width: 100% !important;
        margin-bottom: 10px;
    }

    .select2-container .select2-selection--single {
        height: 38px;
        padding: 5px;
    }

    .select2-container--default .select2-selection--single .select2-selection__rendered {
        line-height: 28px;
    }

    .select2-container--default .select2-selection--single .select2-selection__arrow {
        height: 36px;
    }
</style>

<script>
    // 初始化Select2
    $(document).ready(function() {
        $('.select2-product').select2({
            placeholder: "请选择商品",
            allowClear: true,
            width: '100%'
        });

        $('.select2-warehouse').select2({
            placeholder: "请选择仓库",
            allowClear: true,
            width: '100%'
        });
    });
</script>