<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 初始化消息变量
$message = '';
$messageType = '';

// 获取活动ID
$activity_id = isset($_GET['id']) ? intval($_GET['id']) : 0;
$is_new = isset($_GET['new']) ? true : false;

if ($activity_id <= 0) {
    echo '<div class="alert alert-error">无效的活动ID</div>';
    echo '<div class="form-actions"><a href="index.php?page=activity" class="btn btn-primary">返回活动列表</a></div>';
    exit;
}

// 获取活动信息
$sql = "SELECT * FROM promotion_activities WHERE activity_id = ?";
$result = executeQuery($conn, $sql, 'i', [$activity_id]);

if (!$result['success'] || empty($result['data'])) {
    echo '<div class="alert alert-error">未找到该促销活动</div>';
    echo '<div class="form-actions"><a href="index.php?page=activity" class="btn btn-primary">返回活动列表</a></div>';
    exit;
}

$activity = $result['data'][0];

// 处理关联商品的添加
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['add_products']) && isset($_POST['selected_products']) && is_array($_POST['selected_products'])) {
    $selected_products = array_map('intval', $_POST['selected_products']);

    if (empty($selected_products)) {
        $message = '请选择要关联的商品';
        $messageType = 'error';
    } else {
        // 检查这些商品是否已经关联了
        $existingSql = "SELECT product_id FROM promotion_products WHERE activity_id = ? AND product_id IN (" . implode(',', array_fill(0, count($selected_products), '?')) . ")";
        $existingTypes = 'i' . str_repeat('i', count($selected_products));
        $existingParams = array_merge([$activity_id], $selected_products);

        $existingResult = executeQuery($conn, $existingSql, $existingTypes, $existingParams);
        $existingProducts = $existingResult['success'] ? array_column($existingResult['data'], 'product_id') : [];

        // 过滤掉已经关联的商品
        $newProducts = array_diff($selected_products, $existingProducts);

        if (empty($newProducts)) {
            $message = '所选商品已全部关联到此活动';
            $messageType = 'info';
        } else {
            // 为折扣类型准备特定折扣率
            $discountRates = [];
            if ($activity['activity_type'] == 'discount' && isset($_POST['discount_rates']) && is_array($_POST['discount_rates'])) {
                foreach ($_POST['discount_rates'] as $product_id => $rate) {
                    if (is_numeric($rate) && $rate > 0 && $rate <= 1) {
                        $discountRates[intval($product_id)] = floatval($rate);
                    }
                }
            }

            // 添加关联
            $successCount = 0;
            $failCount = 0;

            foreach ($newProducts as $product_id) {
                $discount_rate = isset($discountRates[$product_id]) ? $discountRates[$product_id] : null;

                $insertSql = "INSERT INTO promotion_products (activity_id, product_id, discount_rate) VALUES (?, ?, ?)";
                $insertResult = executeQuery($conn, $insertSql, 'iid', [$activity_id, $product_id, $discount_rate]);

                if ($insertResult['success']) {
                    $successCount++;
                } else {
                    $failCount++;
                }
            }

            // 记录操作日志
            if ($successCount > 0) {
                $operationDetails = "用户 {$_SESSION['username']} 为促销活动 (ID: {$activity_id}) 添加了 {$successCount} 个关联商品";
                log_operation($_SESSION['user_id'], '添加', $operationDetails);

                $message = "已成功添加 {$successCount} 个商品关联";
                if ($failCount > 0) {
                    $message .= "，{$failCount} 个商品添加失败";
                    $messageType = 'warning';
                } else {
                    $messageType = 'success';
                }
            } else {
                $message = '添加商品关联失败';
                $messageType = 'error';
            }
        }
    }
}

// 处理移除关联商品
if (isset($_GET['action']) && $_GET['action'] == 'remove' && isset($_GET['product_id'])) {
    $product_id = intval($_GET['product_id']);

    $deleteSql = "DELETE FROM promotion_products WHERE activity_id = ? AND product_id = ?";
    $deleteResult = executeQuery($conn, $deleteSql, 'ii', [$activity_id, $product_id]);

    if ($deleteResult['success'] && $deleteResult['data'] > 0) {
        // 记录操作日志
        $operationDetails = "用户 {$_SESSION['username']} 从促销活动 (ID: {$activity_id}) 中移除了商品 (ID: {$product_id})";
        log_operation($_SESSION['user_id'], '删除', $operationDetails);

        $message = '商品已从活动中移除';
        $messageType = 'success';
    } else {
        $message = '移除商品关联失败';
        $messageType = 'error';
    }
}

// 批量移除关联商品
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['remove_selected']) && isset($_POST['selected_relations']) && is_array($_POST['selected_relations'])) {
    $selected_relations = array_map('intval', $_POST['selected_relations']);

    if (empty($selected_relations)) {
        $message = '请选择要移除的关联商品';
        $messageType = 'error';
    } else {
        // 构建SQL参数
        $placeholders = implode(',', array_fill(0, count($selected_relations), '?'));
        $types = 'i' . str_repeat('i', count($selected_relations));
        $params = array_merge([$activity_id], $selected_relations);

        $deleteSql = "DELETE FROM promotion_products WHERE activity_id = ? AND product_id IN ($placeholders)";
        $deleteResult = executeQuery($conn, $deleteSql, $types, $params);

        if ($deleteResult['success'] && $deleteResult['data'] > 0) {
            // 记录操作日志
            $operationDetails = "用户 {$_SESSION['username']} 从促销活动 (ID: {$activity_id}) 中批量移除了 " . count($selected_relations) . " 个商品";
            log_operation($_SESSION['user_id'], '批量删除', $operationDetails);

            $message = '已成功移除 ' . $deleteResult['data'] . ' 个商品关联';
            $messageType = 'success';
        } else {
            $message = '移除商品关联失败';
            $messageType = 'error';
        }
    }
}

// 更新商品折扣率
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['update_discount_rates']) && $activity['activity_type'] == 'discount') {
    if (isset($_POST['product_discount_rates']) && is_array($_POST['product_discount_rates'])) {
        $updatedCount = 0;

        foreach ($_POST['product_discount_rates'] as $product_id => $rate) {
            $product_id = intval($product_id);
            $rate = is_numeric($rate) ? floatval($rate) : null;

            // 只更新有效的折扣率或明确设置为NULL的
            if (($rate !== null && $rate > 0 && $rate <= 1) || $rate === null) {
                $updateSql = "UPDATE promotion_products SET discount_rate = ? WHERE activity_id = ? AND product_id = ?";
                $updateResult = executeQuery($conn, $updateSql, 'dii', [$rate, $activity_id, $product_id]);

                if ($updateResult['success'] && $updateResult['data'] > 0) {
                    $updatedCount++;
                }
            }
        }

        if ($updatedCount > 0) {
            // 记录操作日志
            $operationDetails = "用户 {$_SESSION['username']} 更新了促销活动 (ID: {$activity_id}) 中 {$updatedCount} 个商品的折扣率";
            log_operation($_SESSION['user_id'], '更新', $operationDetails);

            $message = "已成功更新 {$updatedCount} 个商品的折扣率";
            $messageType = 'success';
        } else {
            $message = '没有更新任何商品的折扣率';
            $messageType = 'info';
        }
    }
}

// 获取已关联的商品列表
$associatedSql = "SELECT pp.*, p.product_name, p.barcode, p.unit, p.unit_price 
                  FROM promotion_products pp 
                  JOIN products p ON pp.product_id = p.product_id 
                  WHERE pp.activity_id = ?
                  ORDER BY p.product_name";
$associatedResult = executeQuery($conn, $associatedSql, 'i', [$activity_id]);
$associatedProducts = $associatedResult['success'] ? $associatedResult['data'] : [];

// 处理搜索商品
$searchKeyword = isset($_POST['search_keyword']) ? sanitize($_POST['search_keyword']) : '';
$availableProducts = [];

if (!empty($searchKeyword) || $is_new) {
    // 获取已关联的商品ID列表，用于排除
    $excludeIds = array_column($associatedProducts, 'product_id');
    $excludeClause = '';

    if (!empty($excludeIds)) {
        $excludeClause = " AND p.product_id NOT IN (" . implode(',', $excludeIds) . ")";
    }

    // 构建搜索条件
    $searchClause = '';
    if (!empty($searchKeyword)) {
        $searchClause = " AND (p.product_name LIKE ? OR p.barcode LIKE ?)";
        $searchParams = ["%{$searchKeyword}%", "%{$searchKeyword}%"];
        $searchTypes = 'ss';
    } else {
        $searchParams = [];
        $searchTypes = '';
    }

    // 查询可用商品
    $availableSql = "SELECT p.product_id, p.product_name, p.barcode, p.unit, p.unit_price 
                    FROM products p 
                    WHERE 1=1{$excludeClause}{$searchClause} 
                    ORDER BY p.product_name 
                    LIMIT 50";

    $availableResult = executeQuery($conn, $availableSql, $searchTypes, $searchParams);
    $availableProducts = $availableResult['success'] ? $availableResult['data'] : [];
}

// 修改函数定义，使用if(!function_exists)检查避免重复声明
if (!function_exists('getActivityTypeName')) {
    function getActivityTypeName($type)
    {
        switch ($type) {
            case 'discount':
                return '折扣';
            case 'full_reduction':
                return '满减';
            case 'package':
                return '套餐';
            default:
                return '未知';
        }
    }
}
?>

<div class="page-header">
    <h3>管理促销活动关联商品</h3>
    <div class="activity-info">
        <span><strong>活动名称:</strong> <?php echo htmlspecialchars($activity['activity_name']); ?></span>
        <span><strong>活动类型:</strong> <?php echo getActivityTypeName($activity['activity_type']); ?></span>
        <span><strong>时间范围:</strong> <?php echo $activity['start_date'] . ' 至 ' . $activity['end_date']; ?></span>
    </div>
</div>

<?php if ($is_new): ?>
    <div class="alert alert-info">您刚刚创建了新的促销活动，现在您可以为该活动添加关联商品。</div>
<?php endif; ?>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<!-- 已关联商品列表 -->
<div class="section-header">
    <h4>已关联商品</h4>
</div>

<?php if (count($associatedProducts) > 0): ?>
    <form action="" method="post" id="related-form">
        <div class="table-actions">
            <?php if ($activity['activity_type'] == 'discount'): ?>
                <button type="submit" name="update_discount_rates" class="btn btn-primary">更新折扣率</button>
            <?php endif; ?>
            <button type="submit" name="remove_selected" class="btn btn-danger" id="remove-selected" disabled>移除所选</button>
        </div>

        <table class="data-table">
            <thead>
                <tr>
                    <th width="20"><input type="checkbox" id="select-all-related"></th>
                    <th>商品名称</th>
                    <th>条码</th>
                    <th>单位</th>
                    <th>单价</th>
                    <?php if ($activity['activity_type'] == 'discount'): ?>
                        <th width="150">商品特定折扣率</th>
                    <?php endif; ?>
                    <th width="80">操作</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($associatedProducts as $product): ?>
                    <tr>
                        <td><input type="checkbox" name="selected_relations[]" value="<?php echo $product['product_id']; ?>" class="related-checkbox"></td>
                        <td><?php echo htmlspecialchars($product['product_name']); ?></td>
                        <td><?php echo htmlspecialchars($product['barcode']); ?></td>
                        <td><?php echo htmlspecialchars($product['unit']); ?></td>
                        <td>¥<?php echo number_format($product['unit_price'], 2); ?></td>
                        <?php if ($activity['activity_type'] == 'discount'): ?>
                            <td>
                                <input type="number" name="product_discount_rates[<?php echo $product['product_id']; ?>]"
                                    class="form-control discount-rate" step="0.01" min="0.01" max="1"
                                    value="<?php echo $product['discount_rate'] !== null ? number_format($product['discount_rate'], 2, '.', '') : ''; ?>"
                                    placeholder="使用活动默认">
                            </td>
                        <?php endif; ?>
                        <td>
                            <a href="index.php?page=activity&action=products&id=<?php echo $activity_id; ?>&action=remove&product_id=<?php echo $product['product_id']; ?>"
                                class="btn btn-danger btn-sm"
                                onclick="return confirm('确定要移除此商品吗？')">移除</a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </form>
<?php else: ?>
    <div class="alert alert-info">该活动尚未关联任何商品</div>
<?php endif; ?>

<!-- 添加商品表单 -->
<div class="section-header">
    <h4>添加关联商品</h4>
</div>

<form action="" method="post" class="search-form" id="search-form">
    <div class="form-group">
        <input type="text" name="search_keyword" placeholder="输入商品名称或条码搜索" class="form-control" value="<?php echo htmlspecialchars($searchKeyword); ?>">
        <button type="submit" class="btn btn-secondary">搜索商品</button>
    </div>
</form>

<?php if (count($availableProducts) > 0): ?>
    <form action="" method="post" id="add-form">
        <div class="table-actions">
            <button type="submit" name="add_products" class="btn btn-primary" id="add-selected" disabled>添加所选商品</button>
        </div>

        <table class="data-table">
            <thead>
                <tr>
                    <th width="20"><input type="checkbox" id="select-all-available"></th>
                    <th>商品名称</th>
                    <th>条码</th>
                    <th>单位</th>
                    <th>单价</th>
                    <?php if ($activity['activity_type'] == 'discount'): ?>
                        <th width="150">商品特定折扣率</th>
                    <?php endif; ?>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($availableProducts as $product): ?>
                    <tr>
                        <td><input type="checkbox" name="selected_products[]" value="<?php echo $product['product_id']; ?>" class="available-checkbox"></td>
                        <td><?php echo htmlspecialchars($product['product_name']); ?></td>
                        <td><?php echo htmlspecialchars($product['barcode']); ?></td>
                        <td><?php echo htmlspecialchars($product['unit']); ?></td>
                        <td>¥<?php echo number_format($product['unit_price'], 2); ?></td>
                        <?php if ($activity['activity_type'] == 'discount'): ?>
                            <td>
                                <input type="number" name="discount_rates[<?php echo $product['product_id']; ?>]"
                                    class="form-control discount-rate" step="0.01" min="0.01" max="1"
                                    placeholder="使用活动默认">
                            </td>
                        <?php endif; ?>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </form>
<?php elseif (!empty($searchKeyword)): ?>
    <div class="alert alert-info">没有找到匹配的商品，或所有匹配商品已经关联到此活动</div>
<?php endif; ?>

<div class="form-actions">
    <a href="index.php?page=activity&action=view&id=<?php echo $activity_id; ?>" class="btn btn-secondary">查看活动详情</a>
    <a href="index.php?page=activity" class="btn btn-secondary">返回活动列表</a>
</div>

<style>
    .page-header {
        margin-bottom: 20px;
    }

    .activity-info {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
        margin-top: 10px;
        background-color: #f8f9fa;
        padding: 10px;
        border-radius: 4px;
    }

    .section-header {
        margin: 25px 0 15px 0;
        border-bottom: 1px solid #dee2e6;
        padding-bottom: 5px;
    }

    .table-actions {
        margin-bottom: 10px;
        display: flex;
        gap: 10px;
    }

    .form-group {
        display: flex;
        gap: 10px;
        margin-bottom: 15px;
    }

    .form-control {
        display: block;
        width: 100%;
        padding: 8px 12px;
        font-size: 14px;
        line-height: 1.5;
        color: #495057;
        background-color: #fff;
        border: 1px solid #ced4da;
        border-radius: 4px;
        transition: border-color 0.15s ease-in-out;
    }

    .form-control.discount-rate {
        width: 100px;
    }

    .form-actions {
        margin-top: 20px;
        padding-top: 15px;
        border-top: 1px solid #e9ecef;
        display: flex;
        gap: 10px;
    }

    .btn-sm {
        padding: 5px 10px;
        font-size: 12px;
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 已关联商品全选功能
        const selectAllRelated = document.getElementById('select-all-related');
        const relatedCheckboxes = document.querySelectorAll('.related-checkbox');
        const removeSelectedBtn = document.getElementById('remove-selected');

        if (selectAllRelated) {
            selectAllRelated.addEventListener('change', function() {
                relatedCheckboxes.forEach(checkbox => {
                    checkbox.checked = this.checked;
                });
                updateRemoveButton();
            });

            relatedCheckboxes.forEach(checkbox => {
                checkbox.addEventListener('change', function() {
                    updateRemoveButton();

                    // 检查是否所有复选框都被选中
                    const allChecked = Array.from(relatedCheckboxes).every(cb => cb.checked);
                    selectAllRelated.checked = allChecked;
                });
            });
        }

        function updateRemoveButton() {
            if (removeSelectedBtn) {
                const hasChecked = Array.from(relatedCheckboxes).some(cb => cb.checked);
                removeSelectedBtn.disabled = !hasChecked;
            }
        }

        // 可用商品全选功能
        const selectAllAvailable = document.getElementById('select-all-available');
        const availableCheckboxes = document.querySelectorAll('.available-checkbox');
        const addSelectedBtn = document.getElementById('add-selected');

        if (selectAllAvailable) {
            selectAllAvailable.addEventListener('change', function() {
                availableCheckboxes.forEach(checkbox => {
                    checkbox.checked = this.checked;
                });
                updateAddButton();
            });

            availableCheckboxes.forEach(checkbox => {
                checkbox.addEventListener('change', function() {
                    updateAddButton();

                    // 检查是否所有复选框都被选中
                    const allChecked = Array.from(availableCheckboxes).every(cb => cb.checked);
                    selectAllAvailable.checked = allChecked;
                });
            });
        }

        function updateAddButton() {
            if (addSelectedBtn) {
                const hasChecked = Array.from(availableCheckboxes).some(cb => cb.checked);
                addSelectedBtn.disabled = !hasChecked;
            }
        }

        // 折扣率输入验证
        const discountRates = document.querySelectorAll('.discount-rate');

        discountRates.forEach(input => {
            input.addEventListener('input', function() {
                const value = parseFloat(this.value);
                if (value < 0.01) {
                    this.setCustomValidity('折扣率不能小于0.01');
                } else if (value > 1) {
                    this.setCustomValidity('折扣率不能大于1');
                } else {
                    this.setCustomValidity('');
                }
            });
        });
    });
</script>