<?php
session_start();
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取当前页面
$page = isset($_GET['page']) ? $_GET['page'] : 'activity';

// 页面标题
$pageTitle = '促销与会员';
$subTitle = '';

// 获取操作
$action = isset($_GET['action']) ? $_GET['action'] : '';

// 获取子页面内容
$contentFile = '';
switch ($page) {
    case 'activity':
        if ($action == 'add') {
            $contentFile = 'activity_add.php';
            $subTitle = '添加促销活动';
        } elseif ($action == 'edit') {
            $contentFile = 'activity_edit.php';
            $subTitle = '编辑促销活动';
        } elseif ($action == 'view') {
            $contentFile = 'activity_view.php';
            $subTitle = '查看促销活动';
        } else {
            $contentFile = 'activity.php';
            $subTitle = '促销管理';
        }
        break;
    case 'member':
        if ($action == 'add') {
            $contentFile = 'member_add.php';
            $subTitle = '添加会员';
        } elseif ($action == 'edit') {
            $contentFile = 'member_edit.php';
            $subTitle = '编辑会员';
        } elseif ($action == 'view') {
            $contentFile = 'member_view.php';
            $subTitle = '查看会员';
        } else {
            $contentFile = 'member.php';
            $subTitle = '会员管理';
        }
        break;
    case 'points':
        if ($action == 'add') {
            $contentFile = 'points_add.php';
            $subTitle = '添加积分商品';
        } elseif ($action == 'edit') {
            $contentFile = 'points_edit.php';
            $subTitle = '编辑积分商品';
        } elseif ($action == 'view') {
            $contentFile = 'points_view.php';
            $subTitle = '查看积分商品';
        } elseif ($action == 'redeem') {
            $contentFile = 'points_redeem.php';
            $subTitle = '积分兑换';
        } elseif ($action == 'redemptions') {
            $contentFile = 'points_redemptions.php';
            $subTitle = '兑换记录管理';
        } elseif ($action == 'redemption_detail') {
            $contentFile = 'redemption_detail.php';
            $subTitle = '兑换详情';
        } elseif ($action == 'transactions') {
            $contentFile = 'points_transactions.php';
            $subTitle = '积分交易记录';
        } else {
            $contentFile = 'points.php';
            $subTitle = '积分商品管理';
        }
        break;
    default:
        $contentFile = 'activity.php';
        $subTitle = '促销管理';
}

// 检查文件是否存在
if (!file_exists($contentFile)) {
    $contentFile = 'activity.php';
    $subTitle = '促销管理';
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $subTitle; ?> - <?php echo $pageTitle; ?> - <?php echo SITE_NAME; ?></title>
    <link rel="stylesheet" href="../../css/style.css">
</head>

<body>
    <header class="main-header">
        <div class="user-info">
            <span class="user-name"><?php echo isset($_SESSION['full_name']) ? $_SESSION['full_name'] : '用户'; ?></span>
            <span class="user-role"><?php echo $_SESSION['user_role']; ?></span>
        </div>

        <div class="site-title">
            <h1><?php echo SITE_NAME; ?></h1>
            <p><?php echo SITE_SUBTITLE; ?></p>
        </div>

        <div class="header-actions">
            <a href="../../logout.php" class="btn btn-logout">退出登录</a>
        </div>
    </header>

    <div class="module-layout">
        <aside class="module-sidebar">
            <div class="module-sidebar-header">
                <h2><?php echo $pageTitle; ?></h2>
            </div>

            <nav class="module-nav">
                <a href="../../home.php" class="module-nav-item">返回首页</a>
                <a href="index.php?page=activity" class="module-nav-item <?php echo $page == 'activity' ? 'active' : ''; ?>">促销管理</a>
                <a href="index.php?page=member" class="module-nav-item <?php echo $page == 'member' ? 'active' : ''; ?>">会员管理</a>
                <a href="index.php?page=points" class="module-nav-item <?php echo $page == 'points' ? 'active' : ''; ?>">积分兑换</a>
            </nav>
        </aside>

        <main class="module-content">
            <div class="module-content-header">
                <h2><?php echo $subTitle; ?></h2>
            </div>
            <?php
            // 包含子页面内容
            if (file_exists($contentFile)) {
                include $contentFile;
            } else {
                echo "<div class='alert alert-error'>找不到页面文件: {$contentFile}</div>";
            }
            ?>
        </main>
    </div>

    <footer class="main-footer">
        <p>&copy; <?php echo date('Y'); ?> <?php echo SITE_NAME; ?> - 版权所有</p>
    </footer>
</body>

</html>