<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 初始化变量
$errors = [];
$success = '';
$member_id = isset($_GET['member_id']) ? intval($_GET['member_id']) : 0;
$product_id = isset($_GET['product_id']) ? intval($_GET['product_id']) : 0;
$quantity = isset($_GET['quantity']) ? intval($_GET['quantity']) : 1;

// 如果传递了product_id参数，获取商品信息
$product = null;
$memberInfo = null;

if ($product_id > 0) {
    // 获取商品信息
    $sql = "SELECT * FROM point_products WHERE product_id = ? AND is_active = 1";
    if ($stmt = $conn->prepare($sql)) {
        $stmt->bind_param("i", $product_id);
        $stmt->execute();
        $result = $stmt->get_result();
        if ($result->num_rows > 0) {
            $product = $result->fetch_assoc();
        } else {
            $errors[] = '未找到该积分商品或商品已下架';
        }
        $stmt->close();
    } else {
        $errors[] = '查询商品时出错：' . $conn->error;
    }
}

// 获取会员信息
if ($member_id > 0) {
    $sql = "SELECT m.*, c.customer_name, c.phone, c.email 
            FROM members m 
            JOIN customers c ON m.customer_id = c.customer_id 
            WHERE m.member_id = ? AND m.status = 'active'";

    if ($stmt = $conn->prepare($sql)) {
        $stmt->bind_param("i", $member_id);
        $stmt->execute();
        $result = $stmt->get_result();
        if ($result->num_rows > 0) {
            $memberInfo = $result->fetch_assoc();
        } else {
            $errors[] = '未找到该会员或会员未激活';
        }
        $stmt->close();
    } else {
        $errors[] = '查询会员时出错：' . $conn->error;
    }
}

// 获取所有活跃会员（用于下拉选择）
$active_members = [];
$member_sql = "SELECT m.member_id, m.member_no, c.customer_name, m.points
              FROM members m
              JOIN customers c ON m.customer_id = c.customer_id
              WHERE m.status = 'active'
              ORDER BY c.customer_name";

if ($stmt = $conn->prepare($member_sql)) {
    $stmt->execute();
    $result = $stmt->get_result();
    while ($row = $result->fetch_assoc()) {
        $active_members[] = $row;
    }
    $stmt->close();
}

// 获取所有可用的积分商品
$availableProducts = [];
$availableProductsSql = "SELECT * FROM point_products WHERE is_active = 1";

if ($stmt = $conn->prepare($availableProductsSql)) {
    $stmt->execute();
    $result = $stmt->get_result();
    while ($row = $result->fetch_assoc()) {
        $availableProducts[] = $row;
    }
    $stmt->close();
}

// 获取商品类型名称
if (!function_exists('getProductTypeName')) {
    function getProductTypeName($type)
    {
        switch ($type) {
            case 'physical':
                return '实物商品';
            case 'voucher':
                return '代金券';
            case 'coupon':
                return '优惠券';
            default:
                return '未知';
        }
    }
}

// 处理提交的兑换请求
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['redeem'])) {
    // 获取并验证表单数据
    $product_id = isset($_POST['product_id']) ? intval($_POST['product_id']) : 0;
    $member_id = isset($_POST['member_id']) ? intval($_POST['member_id']) : 0;
    $quantity = isset($_POST['quantity']) ? intval($_POST['quantity']) : 0;

    // 基本验证
    if ($product_id <= 0) {
        $errors[] = '请选择有效的商品';
    }

    if ($member_id <= 0) {
        $errors[] = '请选择有效的会员';
    }

    if ($quantity <= 0) {
        $errors[] = '请输入有效的兑换数量';
    }

    // 如果没有错误，继续处理
    if (empty($errors)) {
        // 再次获取商品和会员信息，确保数据最新
        $productSql = "SELECT * FROM point_products WHERE product_id = ? AND is_active = 1";
        $memberSql = "SELECT * FROM members WHERE member_id = ? AND status = 'active'";

        $product = null;
        $member = null;

        // 获取商品信息
        if ($stmt = $conn->prepare($productSql)) {
            $stmt->bind_param("i", $product_id);
            $stmt->execute();
            $result = $stmt->get_result();
            if ($result->num_rows > 0) {
                $product = $result->fetch_assoc();
            } else {
                $errors[] = '未找到该积分商品或商品已下架';
            }
            $stmt->close();
        } else {
            $errors[] = '查询商品时出错：' . $conn->error;
        }

        // 获取会员信息
        if ($stmt = $conn->prepare($memberSql)) {
            $stmt->bind_param("i", $member_id);
            $stmt->execute();
            $result = $stmt->get_result();
            if ($result->num_rows > 0) {
                $member = $result->fetch_assoc();
            } else {
                $errors[] = '未找到该会员或会员未激活';
            }
            $stmt->close();
        } else {
            $errors[] = '查询会员时出错：' . $conn->error;
        }

        // 如果商品和会员信息都有效，继续处理
        if ($product && $member) {
            // 检查库存（针对实物商品）
            if ($product['product_type'] == 'physical' && $product['stock_quantity'] < $quantity) {
                $errors[] = '商品库存不足，当前库存为' . $product['stock_quantity'];
            }

            // 计算所需总积分
            $points_required = $product['points_required'] * $quantity;

            // 检查会员积分是否足够
            if ($member['points'] < $points_required) {
                $errors[] = '会员积分不足，当前积分为' . $member['points'] . '，需要' . $points_required . '积分';
            }

            // 如果通过所有验证，进行兑换操作
            if (empty($errors)) {
                // 开始事务
                $conn->begin_transaction();

                try {
                    // 1. 插入兑换记录
                    $redemptionSql = "INSERT INTO point_redemptions (member_id, product_id, quantity, points_used, redemption_date, status, notes) 
                                    VALUES (?, ?, ?, ?, NOW(), 'pending', ?)";
                    $stmt = $conn->prepare($redemptionSql);
                    $notes = "会员积分兑换商品：" . $product['product_name'];
                    $stmt->bind_param("iiiis", $member_id, $product_id, $quantity, $points_required, $notes);
                    $stmt->execute();
                    $redemption_id = $conn->insert_id;

                    // 2. 更新会员积分（减少）
                    $updateMemberSql = "UPDATE members SET points = points - ? WHERE member_id = ?";
                    $stmt = $conn->prepare($updateMemberSql);
                    $stmt->bind_param("ii", $points_required, $member_id);
                    $stmt->execute();

                    // 3. 更新商品库存（如果是实物商品）
                    if ($product['product_type'] == 'physical') {
                        $updateProductSql = "UPDATE point_products SET stock_quantity = stock_quantity - ? WHERE product_id = ?";
                        $stmt = $conn->prepare($updateProductSql);
                        $stmt->bind_param("ii", $quantity, $product_id);
                        $stmt->execute();
                    }

                    // 4. 添加积分交易记录
                    $transactionSql = "INSERT INTO point_transactions (member_id, transaction_type, points, description, transaction_date, related_id) 
                                    VALUES (?, 'redemption', ?, ?, NOW(), ?)";
                    $pointsReduction = -$points_required; // 负值表示减少积分
                    $description = "兑换商品：" . $product['product_name'] . " x " . $quantity;
                    $stmt = $conn->prepare($transactionSql);
                    $stmt->bind_param("iisi", $member_id, $pointsReduction, $description, $redemption_id);
                    $stmt->execute();

                    // 提交事务
                    $conn->commit();

                    // 设置成功消息
                    $success = "积分兑换成功！兑换ID: " . $redemption_id;

                    // 清空商品和数量字段，以便用户进行新的兑换
                    $product_id = 0;
                    $product = null;
                    $quantity = 1;

                    // 重新获取会员信息（显示更新后的积分）
                    if ($stmt = $conn->prepare("SELECT m.*, c.customer_name, c.phone, c.email 
                                                FROM members m 
                                                JOIN customers c ON m.customer_id = c.customer_id 
                                                WHERE m.member_id = ? AND m.status = 'active'")) {
                        $stmt->bind_param("i", $member_id);
                        $stmt->execute();
                        $result = $stmt->get_result();
                        if ($result->num_rows > 0) {
                            $memberInfo = $result->fetch_assoc();
                        }
                        $stmt->close();
                    }
                } catch (Exception $e) {
                    // 回滚事务
                    $conn->rollback();
                    $errors[] = '兑换过程中出错：' . $e->getMessage();
                }
            }
        }
    }
}
?>

<div class="page-header">
    <h3>积分兑换</h3>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-error">
        <ul>
            <?php foreach ($errors as $error): ?>
                <li><?php echo htmlspecialchars($error); ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<?php if (!empty($success)): ?>
    <div class="alert alert-success">
        <?php echo htmlspecialchars($success); ?>
    </div>
<?php endif; ?>

<form method="get" class="form-horizontal redemption-form" id="member-selection-form">
    <input type="hidden" name="page" value="points">
    <input type="hidden" name="action" value="redeem">

    <div class="row redemption-container">
        <div class="span6">
            <div class="form-group">
                <label class="control-label" for="member_id">选择会员</label>
                <div class="controls">
                    <select name="member_id" id="member_id" class="input-xlarge">
                        <option value="">-- 请选择会员 --</option>
                        <?php foreach ($active_members as $member): ?>
                            <option value="<?php echo $member['member_id']; ?>" <?php echo ($member_id == $member['member_id']) ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($member['customer_name']); ?>
                                (<?php echo htmlspecialchars($member['member_no']); ?>) -
                                <?php echo number_format($member['points']); ?>积分
                            </option>
                        <?php endforeach; ?>
                    </select>
                    <button type="submit" class="btn btn-primary">选择会员</button>
                </div>
            </div>

            <?php if ($memberInfo): ?>
                <div class="member-info-box">
                    <h4>会员信息</h4>
                    <div class="member-details">
                        <div class="member-item">
                            <label>会员卡号：</label>
                            <span><?php echo htmlspecialchars($memberInfo['member_no']); ?></span>
                        </div>
                        <div class="member-item">
                            <label>会员姓名：</label>
                            <span><?php echo htmlspecialchars($memberInfo['customer_name']); ?></span>
                        </div>
                        <div class="member-item">
                            <label>当前积分：</label>
                            <span class="points"><?php echo number_format($memberInfo['points']); ?></span>
                        </div>
                        <div class="member-item">
                            <label>联系电话：</label>
                            <span><?php echo htmlspecialchars($memberInfo['phone']); ?></span>
                        </div>
                    </div>
                </div>
            <?php endif; ?>
        </div>

        <div class="span6">
            <?php if ($memberInfo): ?>
                <form method="get" class="product-selection-form">
                    <input type="hidden" name="page" value="points">
                    <input type="hidden" name="action" value="redeem">
                    <input type="hidden" name="member_id" value="<?php echo $member_id; ?>">

                    <div class="form-group">
                        <label class="control-label" for="product_id">选择兑换商品</label>
                        <div class="controls">
                            <select name="product_id" id="product_id" class="input-xlarge">
                                <option value="">-- 请选择商品 --</option>
                                <?php foreach ($availableProducts as $availableProduct): ?>
                                    <option value="<?php echo $availableProduct['product_id']; ?>" <?php echo ($product_id == $availableProduct['product_id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($availableProduct['product_name']); ?>
                                        (<?php echo getProductTypeName($availableProduct['product_type']); ?>) -
                                        <?php echo number_format($availableProduct['points_required']); ?> 积分
                                    </option>
                                <?php endforeach; ?>
                            </select>
                            <button type="submit" class="btn btn-info">选择商品</button>
                        </div>
                    </div>
                </form>

                <?php if ($product): ?>
                    <div class="product-info-box">
                        <h4>商品信息</h4>
                        <div class="product-details">
                            <div class="product-item">
                                <label>商品名称：</label>
                                <span><?php echo htmlspecialchars($product['product_name']); ?></span>
                            </div>
                            <div class="product-item">
                                <label>商品类型：</label>
                                <span><?php echo getProductTypeName($product['product_type']); ?></span>
                            </div>
                            <div class="product-item">
                                <label>所需积分：</label>
                                <span class="points-required"><?php echo number_format($product['points_required']); ?> 积分</span>
                            </div>
                            <?php if ($product['product_type'] == 'physical'): ?>
                                <div class="product-item">
                                    <label>库存数量：</label>
                                    <span><?php echo number_format($product['stock_quantity']); ?></span>
                                </div>
                            <?php endif; ?>
                        </div>

                        <div class="product-description">
                            <label>商品描述：</label>
                            <div class="description-content">
                                <?php echo !empty($product['description']) ? nl2br(htmlspecialchars($product['description'])) : '暂无商品描述'; ?>
                            </div>
                        </div>
                    </div>

                    <form method="post" class="redemption-confirm-form">
                        <input type="hidden" name="member_id" value="<?php echo $member_id; ?>">
                        <input type="hidden" name="product_id" value="<?php echo $product_id; ?>">

                        <div class="form-group">
                            <label class="control-label" for="quantity">兑换数量</label>
                            <div class="controls">
                                <input type="number" name="quantity" id="quantity" class="input-mini" min="1" max="<?php echo ($product['product_type'] == 'physical') ? $product['stock_quantity'] : 1000; ?>" value="<?php echo $quantity; ?>" required>
                                <p class="help-block" id="points-calculation">
                                    总计需要: <span class="total-points"><?php echo number_format($product['points_required'] * $quantity); ?></span> 积分
                                </p>
                            </div>
                        </div>

                        <div class="form-actions">
                            <button type="submit" name="redeem" class="btn btn-primary">确认兑换</button>
                            <a href="index.php?page=points" class="btn">返回积分商品列表</a>
                        </div>
                    </form>
                <?php endif; ?>
            <?php endif; ?>
        </div>
    </div>
</form>

<style>
    .redemption-container {
        margin-top: 20px;
    }

    .member-info-box,
    .product-info-box {
        background-color: #f9f9f9;
        border: 1px solid #ddd;
        border-radius: 4px;
        padding: 15px;
        margin-bottom: 20px;
    }

    .member-details,
    .product-details {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
        margin-bottom: 15px;
    }

    .member-item,
    .product-item {
        flex: 1 0 45%;
        min-width: 200px;
    }

    .member-item label,
    .product-item label,
    .product-description label {
        font-weight: bold;
        display: inline-block;
        min-width: 100px;
    }

    .points,
    .points-required,
    .total-points {
        color: #d9534f;
        font-weight: bold;
    }

    .product-description {
        margin-top: 15px;
        border-top: 1px solid #eee;
        padding-top: 15px;
    }

    .description-content {
        background-color: #fff;
        border: 1px solid #eee;
        border-radius: 4px;
        padding: 10px;
        margin-top: 5px;
        min-height: 60px;
    }

    .form-actions {
        padding: 15px;
        background-color: #f5f5f5;
        border-top: 1px solid #ddd;
        border-radius: 0 0 4px 4px;
        text-align: right;
    }

    .controls button {
        margin-left: 10px;
        vertical-align: middle;
    }

    @media (max-width: 767px) {

        .member-item,
        .product-item {
            flex: 1 0 100%;
        }
    }
</style>

<script>
    // 动态计算所需总积分
    document.addEventListener('DOMContentLoaded', function() {
        var quantityInput = document.getElementById('quantity');
        var pointsCalculation = document.getElementById('points-calculation');
        var totalPointsSpan = document.querySelector('.total-points');

        if (quantityInput && pointsCalculation && totalPointsSpan) {
            var pointsRequired = <?php echo isset($product['points_required']) ? $product['points_required'] : 0; ?>;

            quantityInput.addEventListener('input', function() {
                var quantity = parseInt(this.value) || 0;
                var totalPoints = quantity * pointsRequired;
                totalPointsSpan.textContent = new Intl.NumberFormat().format(totalPoints);
            });
        }
    });
</script>