<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 消息初始化
$message = '';
$message_type = '';

// 获取兑换ID
$redemption_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

// 处理状态更新表单提交
if (isset($_POST['update_status'])) {
    // 获取表单数据
    $redemptionId = isset($_POST['redemption_id']) ? intval($_POST['redemption_id']) : 0;
    $newStatus = isset($_POST['new_status']) ? sanitize($_POST['new_status']) : '';
    $notes = isset($_POST['notes']) ? sanitize($_POST['notes']) : '';

    // 验证数据
    if ($redemptionId <= 0 || !in_array($newStatus, ['completed', 'cancelled'])) {
        $message = '提交的数据无效';
        $message_type = 'error';
    } else {
        // 获取当前兑换记录
        $result = executeQuery(
            $conn,
            "SELECT r.*, p.points_required, p.stock 
             FROM point_redemptions r 
             JOIN point_products p ON r.product_id = p.product_id 
             WHERE r.redemption_id = ?",
            'i',
            [$redemptionId]
        );

        if (!$result['success'] || empty($result['data'])) {
            $message = '未找到该兑换记录';
            $message_type = 'error';
        } else {
            $redemption = $result['data'][0];

            // 只能更新待处理的兑换
            if ($redemption['status'] !== 'pending') {
                $message = '只能更新待处理状态的兑换记录';
                $message_type = 'error';
            } else {
                // 开始事务
                $conn->begin_transaction();

                try {
                    // 更新备注信息，附加状态变更记录
                    $statusChangeNote = date('Y-m-d H:i:s') . ' - 状态从"待处理"变更为"' .
                        getRedemptionStatusName($newStatus) . '"';

                    if (!empty($notes)) {
                        $statusChangeNote .= "\n备注: " . $notes;
                    }

                    $updatedNotes = !empty($redemption['notes']) ?
                        $redemption['notes'] . "\n\n" . $statusChangeNote :
                        $statusChangeNote;

                    // 更新兑换记录状态
                    $updateResult = executeQuery(
                        $conn,
                        "UPDATE point_redemptions 
                         SET status = ?, 
                             processed_by = ?, 
                             processed_date = NOW(), 
                             notes = ? 
                         WHERE redemption_id = ?",
                        'sisi',
                        [$newStatus, $_SESSION['user_id'], $updatedNotes, $redemptionId]
                    );

                    if (!$updateResult['success']) {
                        throw new Exception('更新兑换状态失败');
                    }

                    // 如果取消兑换，需要将积分退还给会员
                    if ($newStatus === 'cancelled') {
                        // 更新会员积分
                        $updateMemberResult = executeQuery(
                            $conn,
                            "UPDATE members 
                             SET points = points + ? 
                             WHERE member_id = ?",
                            'ii',
                            [$redemption['points_used'], $redemption['member_id']]
                        );

                        if (!$updateMemberResult['success']) {
                            throw new Exception('退还积分失败');
                        }

                        // 记录积分交易
                        $insertTransactionResult = executeQuery(
                            $conn,
                            "INSERT INTO point_transactions (
                                member_id, transaction_type, points, 
                                transaction_date, related_id, description, created_by
                             ) VALUES (?, 'refund', ?, NOW(), ?, ?, ?)",
                            'iiisi',
                            [
                                $redemption['member_id'],
                                $redemption['points_used'],
                                $redemptionId,
                                '取消兑换#' . $redemptionId . '退还积分',
                                $_SESSION['user_id']
                            ]
                        );

                        if (!$insertTransactionResult['success']) {
                            throw new Exception('记录积分交易失败');
                        }

                        // 如果是实物商品，需要更新库存
                        $productResult = executeQuery(
                            $conn,
                            "SELECT product_type FROM point_products WHERE product_id = ?",
                            'i',
                            [$redemption['product_id']]
                        );

                        if (!$productResult['success']) {
                            throw new Exception('获取商品信息失败');
                        }

                        if ($productResult['data'][0]['product_type'] === 'physical') {
                            $updateStockResult = executeQuery(
                                $conn,
                                "UPDATE point_products 
                                 SET stock = stock + ? 
                                 WHERE product_id = ?",
                                'ii',
                                [$redemption['quantity'], $redemption['product_id']]
                            );

                            if (!$updateStockResult['success']) {
                                throw new Exception('更新商品库存失败');
                            }
                        }
                    }

                    // 提交事务
                    $conn->commit();

                    $message = '兑换状态已成功更新为' . getRedemptionStatusName($newStatus);
                    $message_type = 'success';
                } catch (Exception $e) {
                    // 回滚事务
                    $conn->rollback();

                    $message = '处理失败: ' . $e->getMessage();
                    $message_type = 'error';
                }
            }
        }
    }
}

if ($redemption_id <= 0) {
    echo '<div class="alert alert-error">无效的兑换ID</div>';
    echo '<div class="form-actions"><a href="index.php?page=points&action=redemptions" class="btn btn-primary">返回兑换记录列表</a></div>';
    exit;
}

// 获取兑换详细信息
$sql = "SELECT r.*, m.member_no, c.customer_name, c.phone, c.email, 
               p.product_name, p.product_type, p.points_required, 
               u.username as processed_by_name
        FROM point_redemptions r 
        JOIN members m ON r.member_id = m.member_id 
        JOIN customers c ON m.customer_id = c.customer_id 
        JOIN point_products p ON r.product_id = p.product_id 
        LEFT JOIN users u ON r.processed_by = u.user_id 
        WHERE r.redemption_id = ?";

$result = executeQuery($conn, $sql, 'i', [$redemption_id]);

if (!$result['success'] || empty($result['data'])) {
    echo '<div class="alert alert-error">未找到该兑换记录</div>';
    echo '<div class="form-actions"><a href="index.php?page=points&action=redemptions" class="btn btn-primary">返回兑换记录列表</a></div>';
    exit;
}

$redemption = $result['data'][0];

// 获取兑换状态中文名称
if (!function_exists('getRedemptionStatusName')) {
    function getRedemptionStatusName($status)
    {
        switch ($status) {
            case 'pending':
                return '待处理';
            case 'completed':
                return '已完成';
            case 'cancelled':
                return '已取消';
            default:
                return '未知';
        }
    }
}

// 获取兑换状态样式类
if (!function_exists('getRedemptionStatusClass')) {
    function getRedemptionStatusClass($status)
    {
        switch ($status) {
            case 'pending':
                return 'warning';
            case 'completed':
                return 'success';
            case 'cancelled':
                return 'secondary';
            default:
                return 'info';
        }
    }
}

// 获取商品类型中文名称
if (!function_exists('getProductTypeName')) {
    function getProductTypeName($type)
    {
        switch ($type) {
            case 'physical':
                return '实物商品';
            case 'voucher':
                return '代金券';
            case 'coupon':
                return '优惠券';
            default:
                return '未知';
        }
    }
}
?>

<div class="page-header">
    <h3>兑换详情</h3>
</div>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $message_type === 'error' ? 'danger' : $message_type; ?>">
        <?php echo $message; ?>
    </div>
<?php endif; ?>

<div class="view-wrapper">
    <div class="view-section">
        <h4>兑换基本信息</h4>
        <div class="view-row">
            <div class="view-item">
                <label>兑换ID</label>
                <div class="view-value"><?php echo $redemption['redemption_id']; ?></div>
            </div>
            <div class="view-item">
                <label>兑换状态</label>
                <div class="view-value">
                    <span class="badge badge-<?php echo getRedemptionStatusClass($redemption['status']); ?>">
                        <?php echo getRedemptionStatusName($redemption['status']); ?>
                    </span>
                </div>
            </div>
            <div class="view-item">
                <label>兑换日期</label>
                <div class="view-value"><?php echo $redemption['redemption_date']; ?></div>
            </div>
        </div>
        <?php if ($redemption['processed_by']): ?>
            <div class="view-row">
                <div class="view-item">
                    <label>处理人员</label>
                    <div class="view-value">
                        <?php echo htmlspecialchars($redemption['processed_by_name']); ?>
                    </div>
                </div>
                <div class="view-item">
                    <label>处理日期</label>
                    <div class="view-value"><?php echo $redemption['processed_date']; ?></div>
                </div>
                <div class="view-item"></div>
            </div>
        <?php endif; ?>
    </div>

    <div class="view-section">
        <h4>会员信息</h4>
        <div class="view-row">
            <div class="view-item">
                <label>会员卡号</label>
                <div class="view-value"><?php echo htmlspecialchars($redemption['member_no']); ?></div>
            </div>
            <div class="view-item">
                <label>会员姓名</label>
                <div class="view-value"><?php echo htmlspecialchars($redemption['customer_name']); ?></div>
            </div>
            <div class="view-item">
                <label>联系电话</label>
                <div class="view-value"><?php echo htmlspecialchars($redemption['phone']); ?></div>
            </div>
        </div>
        <?php if (!empty($redemption['email'])): ?>
            <div class="view-row">
                <div class="view-item">
                    <label>电子邮箱</label>
                    <div class="view-value"><?php echo htmlspecialchars($redemption['email']); ?></div>
                </div>
                <div class="view-item"></div>
                <div class="view-item"></div>
            </div>
        <?php endif; ?>
    </div>

    <div class="view-section">
        <h4>商品信息</h4>
        <div class="view-row">
            <div class="view-item">
                <label>商品名称</label>
                <div class="view-value"><?php echo htmlspecialchars($redemption['product_name']); ?></div>
            </div>
            <div class="view-item">
                <label>商品类型</label>
                <div class="view-value"><?php echo getProductTypeName($redemption['product_type']); ?></div>
            </div>
            <div class="view-item">
                <label>单个积分</label>
                <div class="view-value"><?php echo number_format($redemption['points_required']); ?> 积分</div>
            </div>
        </div>
        <div class="view-row">
            <div class="view-item">
                <label>兑换数量</label>
                <div class="view-value"><?php echo $redemption['quantity']; ?></div>
            </div>
            <div class="view-item">
                <label>总消耗积分</label>
                <div class="view-value"><?php echo number_format($redemption['points_used']); ?> 积分</div>
            </div>
            <div class="view-item"></div>
        </div>
    </div>

    <?php if (!empty($redemption['notes'])): ?>
        <div class="view-section">
            <h4>备注与状态变更记录</h4>
            <div class="view-row full-width">
                <div class="view-item">
                    <div class="view-value notes-box"><?php echo nl2br(htmlspecialchars($redemption['notes'])); ?></div>
                </div>
            </div>
        </div>
    <?php endif; ?>

    <div class="view-actions">
        <a href="index.php?page=points&action=redemptions" class="btn btn-secondary">返回兑换记录列表</a>
        <a href="index.php?page=member&action=view&id=<?php echo $redemption['member_id']; ?>" class="btn btn-info">查看会员详情</a>
        <a href="index.php?page=points&action=view&id=<?php echo $redemption['product_id']; ?>" class="btn btn-info">查看商品详情</a>

        <?php if ($redemption['status'] == 'pending'): ?>
            <a href="javascript:void(0)" onclick="showStatusUpdateModal(<?php echo $redemption['redemption_id']; ?>, 'completed')" class="btn btn-success">标记为已完成</a>
            <a href="javascript:void(0)" onclick="showStatusUpdateModal(<?php echo $redemption['redemption_id']; ?>, 'cancelled')" class="btn btn-danger">标记为已取消</a>
        <?php endif; ?>
    </div>
</div>

<!-- 状态更新模态框 -->
<div id="status-update-modal" class="modal">
    <div class="modal-content">
        <span class="close" onclick="closeModal()">&times;</span>
        <h3>更新兑换状态</h3>

        <form id="status-update-form" method="post">
            <input type="hidden" id="redemption_id" name="redemption_id" value="">
            <input type="hidden" id="new_status" name="new_status" value="">

            <div class="form-group">
                <label for="notes">备注信息</label>
                <textarea class="form-control" id="notes" name="notes" rows="4" placeholder="请输入处理备注信息..."></textarea>
            </div>

            <div class="modal-actions">
                <button type="submit" name="update_status" class="btn btn-primary">确认更新</button>
                <button type="button" class="btn btn-secondary" onclick="closeModal()">取消</button>
            </div>
        </form>
    </div>
</div>

<style>
    .page-header {
        margin-bottom: 20px;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .view-wrapper {
        background-color: #f9f9f9;
        padding: 20px;
        border-radius: 5px;
        margin-bottom: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .view-section {
        margin-bottom: 25px;
        padding-bottom: 15px;
        border-bottom: 1px solid #e9ecef;
    }

    .view-section:last-child {
        border-bottom: none;
        padding-bottom: 0;
    }

    .view-section h4 {
        margin-top: 0;
        margin-bottom: 15px;
        color: #495057;
        font-size: 18px;
    }

    .view-row {
        display: flex;
        flex-wrap: wrap;
        margin-bottom: 15px;
    }

    .view-row:last-child {
        margin-bottom: 0;
    }

    .view-item {
        flex: 0 0 33.333333%;
        max-width: 33.333333%;
        padding-right: 15px;
        box-sizing: border-box;
        margin-bottom: 10px;
    }

    .view-row.full-width .view-item {
        flex: 0 0 100%;
        max-width: 100%;
    }

    .view-item label {
        display: block;
        font-weight: bold;
        margin-bottom: 5px;
        color: #6c757d;
        font-size: 14px;
    }

    .view-value {
        color: #212529;
        word-break: break-word;
    }

    .badge {
        display: inline-block;
        padding: 3px 8px;
        font-size: 12px;
        font-weight: 600;
        border-radius: 3px;
        color: white;
    }

    .badge-success {
        background-color: #28a745;
    }

    .badge-warning {
        background-color: #ffc107;
        color: #212529;
    }

    .badge-secondary {
        background-color: #6c757d;
    }

    .badge-info {
        background-color: #17a2b8;
    }

    .notes-box {
        background-color: #f0f0f0;
        padding: 10px;
        border-radius: 4px;
        border-left: 3px solid #6c757d;
        white-space: pre-line;
    }

    .view-actions {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
        margin-top: 20px;
    }

    /* 模态框样式 */
    .modal {
        display: none;
        position: fixed;
        z-index: 1000;
        left: 0;
        top: 0;
        width: 100%;
        height: 100%;
        overflow: auto;
        background-color: rgba(0, 0, 0, 0.4);
    }

    .modal-content {
        background-color: #fefefe;
        margin: 10% auto;
        padding: 20px;
        border: 1px solid #888;
        width: 50%;
        border-radius: 5px;
        box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        position: relative;
    }

    .close {
        color: #aaa;
        position: absolute;
        top: 10px;
        right: 20px;
        font-size: 28px;
        font-weight: bold;
        cursor: pointer;
    }

    .close:hover,
    .close:focus {
        color: black;
        text-decoration: none;
    }

    .modal-actions {
        margin-top: 20px;
        display: flex;
        justify-content: flex-end;
        gap: 10px;
    }

    @media (max-width: 767.98px) {
        .view-item {
            flex: 0 0 100%;
            max-width: 100%;
        }

        .modal-content {
            width: 90%;
            margin: 15% auto;
        }
    }
</style>

<script>
    // 显示状态更新模态框
    function showStatusUpdateModal(redemptionId, newStatus) {
        document.getElementById('redemption_id').value = redemptionId;
        document.getElementById('new_status').value = newStatus;

        const statusText = newStatus === 'completed' ? '完成' : '取消';
        document.querySelector('#status-update-modal h3').textContent = '确认将兑换状态改为' + statusText;

        document.getElementById('status-update-modal').style.display = 'block';
    }

    // 关闭模态框
    function closeModal() {
        document.getElementById('status-update-modal').style.display = 'none';
    }

    // 点击模态框外部关闭
    window.onclick = function(event) {
        const statusModal = document.getElementById('status-update-modal');
        if (event.target === statusModal) {
            statusModal.style.display = 'none';
        }
    };
</script>