<?php
// 采购对账管理页面
// 防止直接访问
if (!defined('IN_SYSTEM')) {
    define('IN_SYSTEM', true);
}

// 初始化消息变量
$message = '';
$messageType = '';

// 获取采购对账列表
$statements = [];
$search = isset($_GET['keyword']) ? $_GET['keyword'] : '';

// 处理添加/编辑采购对账
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 获取表单数据
    $order_id = isset($_POST['order_id']) ? (int)$_POST['order_id'] : 0;
    $settlement_date = isset($_POST['settlement_date']) ? trim($_POST['settlement_date']) : '';
    $amount = isset($_POST['amount']) ? (float)$_POST['amount'] : 0;
    $settlement_type = isset($_POST['settlement_type']) ? trim($_POST['settlement_type']) : 'payment';

    // 验证数据
    if (empty($order_id) || empty($settlement_date) || $amount <= 0) {
        $message = '请填写所有必填字段！';
        $messageType = 'error';
    } else {
        // 添加新采购对账
        if ($_POST['action'] == 'add') {
            try {
                // 检查是否是订单付款
                if ($settlement_type == 'payment') {
                    // 确保订单存在
                    $checkSql = "SELECT po.order_id, po.total_amount, po.supplier_id FROM purchase_orders po WHERE po.order_id = ?";
                    $checkStmt = $conn->prepare($checkSql);

                    if ($checkStmt === false) {
                        $message = "准备检查订单的SQL语句失败: " . $conn->error;
                        $messageType = 'error';
                    } else {
                        $checkStmt->bind_param("i", $order_id);

                        if ($checkStmt->execute()) {
                            $checkResult = $checkStmt->get_result();

                            if ($checkResult && $checkResult->num_rows > 0) {
                                $orderData = $checkResult->fetch_assoc();
                                $supplier_id = $orderData['supplier_id'];

                                // 检查是否已付款超过订单金额
                                $paidSql = "SELECT COALESCE(SUM(settlement_amount), 0) as paid_amount FROM purchase_settlements WHERE order_id = ? AND payment_status = 'paid'";
                                $paidStmt = $conn->prepare($paidSql);

                                if ($paidStmt === false) {
                                    $message = "准备查询已付款金额的SQL语句失败: " . $conn->error;
                                    $messageType = 'error';
                                } else {
                                    $paidStmt->bind_param("i", $order_id);

                                    if ($paidStmt->execute()) {
                                        $paidResult = $paidStmt->get_result();

                                        if ($paidResult) {
                                            $paidData = $paidResult->fetch_assoc();
                                            $totalPaid = $paidData['paid_amount'] + $amount;

                                            if ($totalPaid > $orderData['total_amount']) {
                                                $message = "付款金额超过订单总金额！最多可付：" . number_format($orderData['total_amount'] - $paidData['paid_amount'], 2);
                                                $messageType = 'error';
                                            } else {
                                                // 添加结算记录
                                                addSettlementRecord($conn, $order_id, $settlement_date, $amount, $settlement_type, $supplier_id);
                                            }
                                        } else {
                                            $message = "获取已付款金额失败: " . $paidStmt->error;
                                            $messageType = 'error';
                                        }
                                    } else {
                                        $message = "执行查询已付款金额失败: " . $paidStmt->error;
                                        $messageType = 'error';
                                    }
                                    $paidStmt->close();
                                }
                            } else {
                                $message = "找不到指定订单！";
                                $messageType = 'error';
                            }
                        } else {
                            $message = "检查订单信息失败: " . $checkStmt->error;
                            $messageType = 'error';
                        }
                        $checkStmt->close();
                    }
                }
                // 处理其他结算类型
                else {
                    // 获取供应商ID
                    $supplierSql = "SELECT supplier_id FROM purchase_orders WHERE order_id = ?";
                    $supplierStmt = $conn->prepare($supplierSql);
                    if ($supplierStmt === false) {
                        $message = "准备获取供应商ID的SQL语句失败: " . $conn->error;
                        $messageType = 'error';
                    } else {
                        $supplierStmt->bind_param("i", $order_id);
                        if ($supplierStmt->execute()) {
                            $supplierResult = $supplierStmt->get_result();
                            if ($supplierResult && $supplierResult->num_rows > 0) {
                                $supplierData = $supplierResult->fetch_assoc();
                                $supplier_id = $supplierData['supplier_id'];
                                addSettlementRecord($conn, $order_id, $settlement_date, $amount, $settlement_type, $supplier_id);
                            } else {
                                $message = "找不到订单对应的供应商！";
                                $messageType = 'error';
                            }
                        } else {
                            $message = "获取供应商ID失败: " . $supplierStmt->error;
                            $messageType = 'error';
                        }
                        $supplierStmt->close();
                    }
                }
            } catch (Exception $e) {
                $message = "系统错误: " . $e->getMessage();
                $messageType = 'error';
            }
        }
        // 更新采购对账
        elseif ($_POST['action'] == 'edit' && isset($_POST['settlement_id'])) {
            $settlement_id = (int)$_POST['settlement_id'];

            try {
                // 检查结算记录是否存在
                $checkSql = "SELECT * FROM purchase_settlements WHERE settlement_id = ?";
                $checkStmt = $conn->prepare($checkSql);

                if ($checkStmt === false) {
                    $message = "准备检查结算记录的SQL语句失败: " . $conn->error;
                    $messageType = 'error';
                } else {
                    $checkStmt->bind_param("i", $settlement_id);

                    if ($checkStmt->execute()) {
                        $checkResult = $checkStmt->get_result();

                        if ($checkResult && $checkResult->num_rows > 0) {
                            $oldData = $checkResult->fetch_assoc();

                            // 获取供应商ID
                            $supplierSql = "SELECT supplier_id FROM purchase_orders WHERE order_id = ?";
                            $supplierStmt = $conn->prepare($supplierSql);
                            if ($supplierStmt === false) {
                                $message = "准备获取供应商ID的SQL语句失败: " . $conn->error;
                                $messageType = 'error';
                            } else {
                                $supplierStmt->bind_param("i", $order_id);
                                if ($supplierStmt->execute()) {
                                    $supplierResult = $supplierStmt->get_result();
                                    if ($supplierResult && $supplierResult->num_rows > 0) {
                                        $supplierData = $supplierResult->fetch_assoc();
                                        $supplier_id = $supplierData['supplier_id'];

                                        // 如果是订单付款，需要检查新的付款金额是否合法
                                        if ($settlement_type == 'payment') {
                                            // 获取订单金额
                                            $orderSql = "SELECT total_amount FROM purchase_orders WHERE order_id = ?";
                                            $orderStmt = $conn->prepare($orderSql);

                                            if ($orderStmt === false) {
                                                $message = "准备查询订单的SQL语句失败: " . $conn->error;
                                                $messageType = 'error';
                                            } else {
                                                $orderStmt->bind_param("i", $order_id);

                                                if ($orderStmt->execute()) {
                                                    $orderResult = $orderStmt->get_result();

                                                    if ($orderResult && $orderResult->num_rows > 0) {
                                                        $orderData = $orderResult->fetch_assoc();

                                                        // 获取除当前记录外的已付款总额
                                                        $paidSql = "SELECT COALESCE(SUM(settlement_amount), 0) as paid_amount FROM purchase_settlements WHERE order_id = ? AND payment_status = 'paid' AND settlement_id != ?";
                                                        $paidStmt = $conn->prepare($paidSql);

                                                        if ($paidStmt === false) {
                                                            $message = "准备查询已付款金额的SQL语句失败: " . $conn->error;
                                                            $messageType = 'error';
                                                        } else {
                                                            $paidStmt->bind_param("ii", $order_id, $settlement_id);

                                                            if ($paidStmt->execute()) {
                                                                $paidResult = $paidStmt->get_result();

                                                                if ($paidResult) {
                                                                    $paidData = $paidResult->fetch_assoc();
                                                                    $totalPaid = $paidData['paid_amount'] + $amount;

                                                                    if ($totalPaid > $orderData['total_amount']) {
                                                                        $message = "付款金额超过订单总金额！最多可付：" . number_format($orderData['total_amount'] - $paidData['paid_amount'], 2);
                                                                        $messageType = 'error';
                                                                    } else {
                                                                        updateSettlementRecord($conn, $settlement_id, $order_id, $settlement_date, $amount, $settlement_type, $supplier_id);
                                                                    }
                                                                } else {
                                                                    $message = "获取已付款金额失败: " . $paidStmt->error;
                                                                    $messageType = 'error';
                                                                }
                                                            } else {
                                                                $message = "执行查询已付款金额失败: " . $paidStmt->error;
                                                                $messageType = 'error';
                                                            }
                                                            $paidStmt->close();
                                                        }
                                                    } else {
                                                        $message = "找不到指定订单！";
                                                        $messageType = 'error';
                                                    }
                                                } else {
                                                    $message = "执行查询订单失败: " . $orderStmt->error;
                                                    $messageType = 'error';
                                                }
                                                $orderStmt->close();
                                            }
                                        } else {
                                            // 对于非订单付款或其他结算类型，直接更新
                                            updateSettlementRecord($conn, $settlement_id, $order_id, $settlement_date, $amount, $settlement_type, $supplier_id);
                                        }
                                    } else {
                                        $message = "找不到订单对应的供应商！";
                                        $messageType = 'error';
                                    }
                                } else {
                                    $message = "获取供应商ID失败: " . $supplierStmt->error;
                                    $messageType = 'error';
                                }
                                $supplierStmt->close();
                            }
                        } else {
                            $message = "找不到指定的结算记录！";
                            $messageType = 'error';
                        }
                    } else {
                        $message = "检查结算记录失败: " . $checkStmt->error;
                        $messageType = 'error';
                    }
                    $checkStmt->close();
                }
            } catch (Exception $e) {
                $message = "系统错误: " . $e->getMessage();
                $messageType = 'error';
            }
        }
    }
}

// 添加结算记录函数
function addSettlementRecord($conn, $order_id, $settlement_date, $amount, $settlement_type, $supplier_id)
{
    global $message, $messageType;

    try {
        // 准备SQL语句
        $sql = "INSERT INTO purchase_settlements (order_id, payment_date, settlement_amount, payment_status) VALUES (?, ?, ?, ?)";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $message = "准备添加结算记录的SQL语句失败: " . $conn->error;
            $messageType = 'error';
            return;
        }

        // 将settlement_type转换为payment_status
        $payment_status = ($settlement_type == 'payment') ? 'paid' : 'unpaid';

        // 绑定参数并执行
        $stmt->bind_param("isds", $order_id, $settlement_date, $amount, $payment_status);

        if ($stmt->execute()) {
            $settlement_id = $stmt->insert_id;
            $message = "添加结算记录成功！";
            $messageType = 'success';

            // 更新供应商应付/已付金额
            updateSupplierBalances($conn, $supplier_id);

            // 记录操作日志
            $typeText = ($settlement_type == 'payment') ? '付款' : '其他结算';
            $operationDetails = "用户 {$_SESSION['username']} 添加了订单(ID: {$order_id})的{$typeText}记录，金额: ￥" . number_format($amount, 2);
            log_operation($_SESSION['user_id'], "添加采购{$typeText}", $operationDetails);

            // 重定向到列表页面
            header("Location: index.php?page=statement&message={$message}&type={$messageType}");
            exit;
        } else {
            $message = "添加结算记录失败: " . $stmt->error;
            $messageType = 'error';
        }
        $stmt->close();
    } catch (Exception $e) {
        $message = "添加结算记录异常: " . $e->getMessage();
        $messageType = 'error';
    }
}

// 更新结算记录函数
function updateSettlementRecord($conn, $settlement_id, $order_id, $settlement_date, $amount, $settlement_type, $supplier_id)
{
    global $message, $messageType;

    try {
        // 准备SQL语句
        $sql = "UPDATE purchase_settlements SET order_id = ?, payment_date = ?, settlement_amount = ?, payment_status = ? WHERE settlement_id = ?";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $message = "准备更新结算记录的SQL语句失败: " . $conn->error;
            $messageType = 'error';
            return;
        }

        // 将settlement_type转换为payment_status
        $payment_status = ($settlement_type == 'payment') ? 'paid' : 'unpaid';

        // 绑定参数并执行
        $stmt->bind_param("isdsi", $order_id, $settlement_date, $amount, $payment_status, $settlement_id);

        if ($stmt->execute()) {
            $message = "更新结算记录成功！";
            $messageType = 'success';

            // 更新供应商应付/已付金额
            updateSupplierBalances($conn, $supplier_id);

            // 记录操作日志
            $typeText = ($settlement_type == 'payment') ? '付款' : '其他结算';
            $operationDetails = "用户 {$_SESSION['username']} 更新了订单(ID: {$order_id})的{$typeText}记录，金额: ￥" . number_format($amount, 2);
            log_operation($_SESSION['user_id'], "更新采购{$typeText}", $operationDetails);

            // 重定向到列表页面
            header("Location: index.php?page=statement&message={$message}&type={$messageType}");
            exit;
        } else {
            $message = "更新结算记录失败: " . $stmt->error;
            $messageType = 'error';
        }
        $stmt->close();
    } catch (Exception $e) {
        $message = "更新结算记录异常: " . $e->getMessage();
        $messageType = 'error';
    }
}

// 更新供应商余额函数
function updateSupplierBalances($conn, $supplier_id)
{
    try {
        // 计算应付总额（从采购订单）
        $totalPayableSql = "SELECT COALESCE(SUM(total_amount), 0) as total_payable FROM purchase_orders WHERE supplier_id = ?";
        $stmt = $conn->prepare($totalPayableSql);

        if ($stmt === false) {
            return false;
        }

        $stmt->bind_param("i", $supplier_id);

        if (!$stmt->execute()) {
            return false;
        }

        $result = $stmt->get_result();

        if (!$result) {
            return false;
        }

        $row = $result->fetch_assoc();
        $totalPayable = $row['total_payable'];
        $stmt->close();

        // 计算已付总额（从结算记录）
        $totalPaidSql = "SELECT COALESCE(SUM(settlement_amount), 0) as total_paid 
                       FROM purchase_settlements ps 
                       JOIN purchase_orders po ON ps.order_id = po.order_id 
                       WHERE po.supplier_id = ? AND ps.payment_status = 'paid'";
        $stmt = $conn->prepare($totalPaidSql);

        if ($stmt === false) {
            return false;
        }

        $stmt->bind_param("i", $supplier_id);

        if (!$stmt->execute()) {
            return false;
        }

        $result = $stmt->get_result();

        if (!$result) {
            return false;
        }

        $row = $result->fetch_assoc();
        $totalPaid = $row['total_paid'];
        $stmt->close();

        // 更新供应商记录
        $updateSql = "UPDATE suppliers SET total_payable = ?, total_paid = ? WHERE supplier_id = ?";
        $stmt = $conn->prepare($updateSql);

        if ($stmt === false) {
            return false;
        }

        $stmt->bind_param("ddi", $totalPayable, $totalPaid, $supplier_id);
        $result = $stmt->execute();
        $stmt->close();

        return $result;
    } catch (Exception $e) {
        error_log("更新供应商余额失败: " . $e->getMessage());
        return false;
    }
}

// 处理删除采购对账
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $settlement_id = (int)$_GET['id'];

    try {
        // 先获取结算记录信息用于日志记录和更新供应商余额
        $sql = "SELECT ps.*, po.order_number, po.supplier_id, s.supplier_name 
                FROM purchase_settlements ps 
                JOIN purchase_orders po ON ps.order_id = po.order_id 
                JOIN suppliers s ON po.supplier_id = s.supplier_id 
                WHERE ps.settlement_id = ?";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $message = "准备查询结算记录的SQL语句失败: " . $conn->error;
            $messageType = 'error';
        } else {
            $stmt->bind_param("i", $settlement_id);

            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result && $result->num_rows > 0) {
                    $settlement = $result->fetch_assoc();
                    $supplier_id = $settlement['supplier_id'];

                    // 执行删除操作
                    $sql = "DELETE FROM purchase_settlements WHERE settlement_id = ?";
                    $deleteStmt = $conn->prepare($sql);

                    if ($deleteStmt === false) {
                        $message = "准备删除结算记录的SQL语句失败: " . $conn->error;
                        $messageType = 'error';
                    } else {
                        $deleteStmt->bind_param("i", $settlement_id);

                        if ($deleteStmt->execute()) {
                            $message = "结算记录删除成功！";
                            $messageType = 'success';

                            // 更新供应商应付/已付金额
                            updateSupplierBalances($conn, $supplier_id);

                            // 记录操作日志
                            $typeText = ($settlement['payment_status'] == 'paid') ? '付款' : '其他结算';
                            $orderText = "订单编号: {$settlement['order_number']}";
                            $operationDetails = "用户 {$_SESSION['username']} 删除了供应商 {$settlement['supplier_name']} 的{$typeText}记录，金额: ￥" . number_format($settlement['settlement_amount'], 2) . "，{$orderText}";
                            log_operation($_SESSION['user_id'], "删除采购{$typeText}", $operationDetails);
                        } else {
                            $message = "删除结算记录失败: " . $deleteStmt->error;
                            $messageType = 'error';
                        }
                        $deleteStmt->close();
                    }
                } else {
                    $message = "找不到指定的结算记录！";
                    $messageType = 'error';
                }
            } else {
                $message = "查询结算记录失败: " . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        }
    } catch (Exception $e) {
        $message = "系统错误: " . $e->getMessage();
        $messageType = 'error';
    }

    // 重定向到采购对账列表
    header("Location: index.php?page=statement&message={$message}&type={$messageType}");
    exit;
}

// 获取要编辑的采购对账信息
$editStatement = null;
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $settlement_id = (int)$_GET['id'];

    try {
        $sql = "SELECT ps.*, po.supplier_id FROM purchase_settlements ps
                JOIN purchase_orders po ON ps.order_id = po.order_id
                WHERE ps.settlement_id = ?";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $message = "准备查询结算记录的SQL语句失败: " . $conn->error;
            $messageType = 'error';
        } else {
            $stmt->bind_param("i", $settlement_id);

            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result && $result->num_rows > 0) {
                    $editStatement = $result->fetch_assoc();
                } else {
                    $message = "找不到指定的结算记录！";
                    $messageType = 'error';
                }
            } else {
                $message = "执行查询失败: " . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        }
    } catch (Exception $e) {
        $message = "系统错误: " . $e->getMessage();
        $messageType = 'error';
    }
}

// 获取要查看的采购对账详情
$viewStatement = null;
if (isset($_GET['action']) && $_GET['action'] == 'view' && isset($_GET['id'])) {
    $settlement_id = (int)$_GET['id'];

    try {
        $sql = "SELECT ps.*, po.order_number, po.supplier_id, s.supplier_name 
                FROM purchase_settlements ps 
                JOIN purchase_orders po ON ps.order_id = po.order_id 
                JOIN suppliers s ON po.supplier_id = s.supplier_id 
                WHERE ps.settlement_id = ?";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $message = "准备查询结算记录的SQL语句失败: " . $conn->error;
            $messageType = 'error';
        } else {
            $stmt->bind_param("i", $settlement_id);

            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result && $result->num_rows > 0) {
                    $viewStatement = $result->fetch_assoc();
                } else {
                    $message = "找不到指定的结算记录！";
                    $messageType = 'error';
                }
            } else {
                $message = "执行查询失败: " . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        }
    } catch (Exception $e) {
        $message = "系统错误: " . $e->getMessage();
        $messageType = 'error';
    }
}

// 获取订单列表（用于表单选择，初始加载为空或编辑时显示对应订单）
$orders = [];
try {
    // 如果是编辑模式，加载该供应商的订单
    if (isset($editStatement) && isset($editStatement['supplier_id'])) {
        $sql = "SELECT order_id, order_number, order_date, total_amount FROM purchase_orders 
                WHERE supplier_id = ? ORDER BY order_date DESC";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $message = "准备查询订单列表的SQL语句失败: " . $conn->error;
            $messageType = 'error';
        } else {
            $stmt->bind_param("i", $editStatement['supplier_id']);

            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result) {
                    while ($row = $result->fetch_assoc()) {
                        $orders[] = $row;
                    }
                } else {
                    $message = "获取订单列表失败: " . $stmt->error;
                    $messageType = 'error';
                }
            } else {
                $message = "执行查询订单列表失败: " . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        }
    }
} catch (Exception $e) {
    $message = "获取订单列表失败: " . $e->getMessage();
    $messageType = 'error';
}

// 获取采购对账列表（用于显示在页面上）
try {
    // 处理搜索
    if (!empty($search)) {
        $searchTerm = "%{$search}%";
        $sql = "SELECT ps.*, po.order_number, s.supplier_name 
                FROM purchase_settlements ps 
                JOIN purchase_orders po ON ps.order_id = po.order_id 
                JOIN suppliers s ON po.supplier_id = s.supplier_id 
                WHERE s.supplier_name LIKE ? OR po.order_number LIKE ? 
                ORDER BY ps.payment_date DESC";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $message = "准备查询结算记录列表的SQL语句失败: " . $conn->error;
            $messageType = 'error';
        } else {
            $stmt->bind_param("ss", $searchTerm, $searchTerm);

            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result) {
                    while ($row = $result->fetch_assoc()) {
                        $statements[] = $row;
                    }
                } else {
                    $message = "获取结算记录列表失败: " . $stmt->error;
                    $messageType = 'error';
                }
            } else {
                $message = "执行查询结算记录列表失败: " . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        }
    } else {
        $sql = "SELECT ps.*, po.order_number, s.supplier_name 
                FROM purchase_settlements ps 
                JOIN purchase_orders po ON ps.order_id = po.order_id 
                JOIN suppliers s ON po.supplier_id = s.supplier_id 
                ORDER BY ps.payment_date DESC";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $message = "准备查询结算记录列表的SQL语句失败: " . $conn->error;
            $messageType = 'error';
        } else {
            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result) {
                    while ($row = $result->fetch_assoc()) {
                        $statements[] = $row;
                    }
                } else {
                    $message = "获取结算记录列表失败: " . $stmt->error;
                    $messageType = 'error';
                }
            } else {
                $message = "执行查询结算记录列表失败: " . $stmt->error;
                $messageType = 'error';
            }
            $stmt->close();
        }
    }
} catch (Exception $e) {
    $message = "获取结算记录列表失败: " . $e->getMessage();
    $messageType = 'error';
}

// 处理从URL传来的消息
if (isset($_GET['message']) && isset($_GET['type'])) {
    $message = $_GET['message'];
    $messageType = $_GET['type'];
}

// 批量更新结算类型后立即刷新页面
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['batch_action']) && isset($_POST['settlement_ids'])) {
    $action = $_POST['batch_action'];
    $settlementIds = $_POST['settlement_ids'];
    $updatedCount = 0;
    $failedCount = 0;

    if (!empty($settlementIds) && in_array($action, ['paid', 'unpaid', 'refund'])) {
        try {
            // 准备SQL语句
            $sql = "UPDATE purchase_settlements SET payment_status = ? WHERE settlement_id = ?";
            $stmt = $conn->prepare($sql);

            if ($stmt === false) {
                $message = "准备批量更新结算类型的SQL语句失败: " . $conn->error;
                $messageType = 'error';
            } else {
                foreach ($settlementIds as $settlementId) {
                    $stmt->bind_param("si", $action, $settlementId);

                    if ($stmt->execute()) {
                        $updatedCount++;
                    } else {
                        $failedCount++;
                    }
                }

                // 记录操作日志
                $actionText = '';
                switch ($action) {
                    case 'paid':
                        $actionText = '订单付款';
                        break;
                    case 'unpaid':
                        $actionText = '调整';
                        break;
                    case 'refund':
                        $actionText = '退款';
                        break;
                }

                $operationDetails = "用户 {$_SESSION['username']} 批量将 {$updatedCount} 个结算记录类型设置为{$actionText}";
                log_operation($_SESSION['user_id'], '批量更新结算类型', $operationDetails);

                $message = "成功更新 {$updatedCount} 个结算记录类型";
                if ($failedCount > 0) {
                    $message .= "，{$failedCount} 个记录更新失败";
                }
                $messageType = ($failedCount > 0) ? 'warning' : 'success';

                // 添加重定向以刷新页面
                header("Location: index.php?page=statement&message=" . urlencode($message) . "&type=" . urlencode($messageType));
                exit;
            }
        } catch (Exception $e) {
            $message = "批量更新结算类型失败: " . $e->getMessage();
            $messageType = 'error';
        }
    } else {
        $message = "请选择要处理的结算记录和有效的操作";
        $messageType = 'error';
    }
}

// 处理更新结算类型的单个请求
if (isset($_GET['action']) && $_GET['action'] == 'update_payment' && isset($_GET['id']) && isset($_GET['status'])) {
    $settlement_id = (int)$_GET['id'];
    $new_status = $_GET['status'];

    // 验证状态值有效性
    if (in_array($new_status, ['paid', 'unpaid', 'refund'])) {
        try {
            $sql = "UPDATE purchase_settlements SET payment_status = ? WHERE settlement_id = ?";
            $stmt = $conn->prepare($sql);

            if ($stmt === false) {
                $message = "准备更新结算类型的SQL语句失败: " . $conn->error;
                $messageType = 'error';
            } else {
                $stmt->bind_param("si", $new_status, $settlement_id);

                if ($stmt->execute()) {
                    // 获取结算记录信息用于日志记录
                    $settlementSql = "SELECT s.supplier_name, po.order_number, ps.settlement_amount 
                                    FROM purchase_settlements ps 
                                    JOIN purchase_orders po ON ps.order_id = po.order_id 
                                    JOIN suppliers s ON po.supplier_id = s.supplier_id 
                                    WHERE ps.settlement_id = ?";
                    $settlementStmt = $conn->prepare($settlementSql);

                    if ($settlementStmt !== false) {
                        $settlementStmt->bind_param("i", $settlement_id);
                        if ($settlementStmt->execute()) {
                            $settlementResult = $settlementStmt->get_result();
                            if ($settlementResult && $settlementResult->num_rows > 0) {
                                $settlementData = $settlementResult->fetch_assoc();

                                $statusText = '';
                                switch ($new_status) {
                                    case 'paid':
                                        $statusText = '订单付款';
                                        break;
                                    case 'unpaid':
                                        $statusText = '调整';
                                        break;
                                    case 'refund':
                                        $statusText = '退款';
                                        break;
                                }

                                $message = "结算记录状态已更新为{$statusText}！";
                                $messageType = 'success';

                                // 记录操作日志
                                $operationDetails = "用户 {$_SESSION['username']} 将供应商 {$settlementData['supplier_name']} 的订单 {$settlementData['order_number']} 的结算记录（金额：{$settlementData['settlement_amount']}）更新为{$statusText}";
                                log_operation($_SESSION['user_id'], '更新结算类型', $operationDetails);
                            }
                        }
                        $settlementStmt->close();
                    } else {
                        $message = "获取结算记录信息失败！";
                        $messageType = 'error';
                    }
                } else {
                    $message = "更新结算类型失败: " . $stmt->error;
                    $messageType = 'error';
                }
                $stmt->close();
            }
        } catch (Exception $e) {
            $message = "系统错误: " . $e->getMessage();
            $messageType = 'error';
        }
    } else {
        $message = "无效的结算类型值！";
        $messageType = 'error';
    }

    // 重定向回结算列表，确保页面刷新
    header("Location: index.php?page=statement&message=" . urlencode($message) . "&type=" . urlencode($messageType));
    exit;
}

?>

<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>">
        <?php echo $message; ?>
    </div>
<?php endif; ?>

<!-- 添加或编辑采购对账表单 -->
<?php if (isset($_GET['action']) && ($_GET['action'] == 'add' || ($_GET['action'] == 'edit' && $editStatement))): ?>
    <div class="form-container">
        <h3><?php echo $_GET['action'] == 'add' ? '添加结算记录' : '编辑结算记录'; ?></h3>
        <form action="" method="post">
            <input type="hidden" name="action" value="<?php echo $_GET['action']; ?>">
            <?php if ($_GET['action'] == 'edit'): ?>
                <input type="hidden" name="settlement_id" value="<?php echo $editStatement['settlement_id']; ?>">
            <?php endif; ?>

            <?php if ($_GET['action'] == 'add'): ?>
                <div class="form-group">
                    <label for="supplier_id">供应商 <span class="required">*</span></label>
                    <select id="supplier_id" name="supplier_id" required onchange="loadOrders(this.value)">
                        <option value="">请选择供应商</option>
                        <?php
                        // 获取供应商列表
                        $supplierSql = "SELECT supplier_id, supplier_name FROM suppliers ORDER BY supplier_name";
                        $supplierResult = $conn->query($supplierSql);
                        if ($supplierResult && $supplierResult->num_rows > 0) {
                            while ($supplier = $supplierResult->fetch_assoc()) {
                                echo '<option value="' . $supplier['supplier_id'] . '">' . $supplier['supplier_name'] . '</option>';
                            }
                        }
                        ?>
                    </select>
                </div>
            <?php endif; ?>

            <div class="form-group">
                <label for="order_id">关联订单 <span class="required">*</span></label>
                <select id="order_id" name="order_id" required>
                    <option value="">请选择订单</option>
                    <?php foreach ($orders as $order): ?>
                        <option value="<?php echo $order['order_id']; ?>" <?php echo (isset($editStatement) && $editStatement['order_id'] == $order['order_id']) ? 'selected' : ''; ?>>
                            <?php echo $order['order_number'] . ' (' . $order['order_date'] . ') - ￥' . number_format($order['total_amount'], 2); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="form-group">
                <label for="settlement_type">结算类型 <span class="required">*</span></label>
                <select id="settlement_type" name="settlement_type" required>
                    <option value="payment" <?php echo (isset($editStatement) && $editStatement['payment_status'] == 'paid') ? 'selected' : ''; ?>>订单付款</option>
                    <option value="adjustment" <?php echo (isset($editStatement) && $editStatement['payment_status'] == 'unpaid') ? 'selected' : ''; ?>>调整</option>
                    <option value="refund" <?php echo (isset($editStatement) && $editStatement['payment_status'] == 'refund') ? 'selected' : ''; ?>>退款</option>
                </select>
            </div>

            <div class="form-group">
                <label for="settlement_date">结算日期 <span class="required">*</span></label>
                <input type="date" id="settlement_date" name="settlement_date" value="<?php echo isset($editStatement) ? $editStatement['payment_date'] : date('Y-m-d'); ?>" required>
            </div>

            <div class="form-group">
                <label for="amount">金额 <span class="required">*</span></label>
                <input type="number" id="amount" name="amount" step="0.01" min="0.01" value="<?php echo isset($editStatement) ? $editStatement['settlement_amount'] : ''; ?>" required>
            </div>

            <div class="form-group">
                <button type="submit" class="btn btn-primary">保存</button>
                <a href="index.php?page=statement" class="btn btn-secondary">取消</a>
            </div>
        </form>
    </div>

    <script>
        <?php if ($_GET['action'] == 'add'): ?>
            // 根据供应商ID加载订单列表
            function loadOrders(supplierId) {
                const orderSelect = document.getElementById('order_id');

                // 清空现有选项
                orderSelect.innerHTML = '<option value="">请选择订单</option>';

                if (!supplierId) {
                    return;
                }

                // 通过AJAX请求获取该供应商的订单列表
                fetch(`../../ajax/get_supplier_orders.php?supplier_id=${supplierId}`)
                    .then(response => response.json())
                    .then(orders => {
                        orders.forEach(order => {
                            const option = document.createElement('option');
                            option.value = order.order_id;
                            option.textContent = `${order.order_number} (${order.order_date}) - ￥${parseFloat(order.total_amount).toFixed(2)}`;
                            orderSelect.appendChild(option);
                        });
                    })
                    .catch(error => {
                        console.error('获取订单列表失败:', error);
                    });
            }
        <?php endif; ?>
    </script>

    <!-- 查看采购对账详情 -->
<?php elseif (isset($_GET['action']) && $_GET['action'] == 'view' && $viewStatement): ?>
    <div class="user-details">
        <h3>结算记录详情</h3>
        <div class="detail-group">
            <label>结算ID:</label>
            <span><?php echo $viewStatement['settlement_id']; ?></span>
        </div>
        <div class="detail-group">
            <label>供应商:</label>
            <span><?php echo $viewStatement['supplier_name']; ?></span>
        </div>
        <div class="detail-group">
            <label>关联订单:</label>
            <span><?php echo $viewStatement['order_number']; ?></span>
        </div>
        <div class="detail-group">
            <label>结算类型:</label>
            <span>
                <?php
                switch ($viewStatement['payment_status']) {
                    case 'paid':
                        echo '订单付款';
                        break;
                    case 'unpaid':
                        echo '调整';
                        break;
                    case 'refund':
                        echo '退款';
                        break;
                    default:
                        echo $viewStatement['payment_status'];
                }
                ?>
            </span>
        </div>
        <div class="detail-group">
            <label>结算日期:</label>
            <span><?php echo $viewStatement['payment_date']; ?></span>
        </div>
        <div class="detail-group">
            <label>金额:</label>
            <span>￥<?php echo number_format($viewStatement['settlement_amount'], 2); ?></span>
        </div>
        <div class="detail-group">
            <label>创建时间:</label>
            <span><?php echo $viewStatement['created_at']; ?></span>
        </div>
        <div class="detail-actions">
            <a href="index.php?page=statement" class="btn btn-secondary">返回列表</a>
            <a href="index.php?page=statement&action=edit&id=<?php echo $viewStatement['settlement_id']; ?>" class="btn btn-primary">编辑记录</a>
        </div>
    </div>

    <style>
        .user-details {
            background-color: #f9f9f9;
            padding: 20px;
            border-radius: 5px;
            margin-bottom: 20px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            border: 1px solid #e0e0e0;
        }

        .user-details h3 {
            margin-top: 0;
            margin-bottom: 20px;
            color: #333;
            border-bottom: 1px solid #ddd;
            padding-bottom: 10px;
            font-size: 1.2em;
        }

        .detail-group {
            margin-bottom: 12px;
            display: flex;
            align-items: center;
            border-bottom: 1px dashed #eee;
            padding-bottom: 8px;
        }

        .detail-group:last-of-type {
            border-bottom: none;
        }

        .detail-group label {
            font-weight: bold;
            width: 120px;
            color: #555;
            flex-shrink: 0;
        }

        .detail-group span {
            flex-grow: 1;
            color: #333;
        }

        .detail-actions {
            margin-top: 20px;
            padding-top: 15px;
            border-top: 1px solid #ddd;
            display: flex;
            gap: 10px;
        }
    </style>
    <!-- 采购对账列表 -->
<?php else: ?>
    <div class="module-tools">
        <div class="tool-left">
            <a href="index.php?page=statement&action=add" class="btn btn-primary">添加结算记录</a>

            <!-- 批量操作部分 -->
            <form method="post" id="batch-form" class="batch-form">
                <div class="batch-actions">
                    <select name="batch_action" class="form-control">
                        <option value="">批量操作...</option>
                        <option value="paid">批量设为订单付款</option>
                        <option value="unpaid">批量设为调整</option>
                        <option value="refund">批量设为退款</option>
                    </select>
                    <button type="submit" class="btn btn-primary" onclick="return confirm('确定要执行所选操作吗？')">应用</button>
                </div>
            </form>
        </div>
        <div class="tool-right">
            <form action="index.php" method="get" class="search-form">
                <input type="hidden" name="page" value="statement">
                <div class="search-group">
                    <input type="text" name="keyword" placeholder="供应商/订单编号" class="search-input" value="<?php echo htmlspecialchars($search); ?>">
                    <button type="submit" class="btn btn-primary">搜索</button>
                    <?php if (!empty($search)): ?>
                        <a href="index.php?page=statement" class="btn btn-secondary">清除</a>
                    <?php endif; ?>
                </div>
            </form>
        </div>
    </div>

    <div class="data-wrapper">
        <table class="data-table">
            <thead>
                <tr>
                    <th><input type="checkbox" id="select-all"></th>
                    <th>ID</th>
                    <th>供应商</th>
                    <th>结算类型</th>
                    <th>关联订单</th>
                    <th>结算日期</th>
                    <th>金额</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php if (count($statements) > 0): ?>
                    <?php foreach ($statements as $statement): ?>
                        <tr>
                            <td><input type="checkbox" name="settlement_ids[]" value="<?php echo $statement['settlement_id']; ?>" class="settlement-checkbox" form="batch-form"></td>
                            <td><?php echo $statement['settlement_id']; ?></td>
                            <td><?php echo $statement['supplier_name']; ?></td>
                            <td>
                                <?php
                                switch ($statement['payment_status']) {
                                    case 'paid':
                                        echo '<span class="badge badge-primary">订单付款</span> ';
                                        echo '<a href="javascript:void(0);" onclick="if(confirm(\'确定要将结算类型改为调整吗？\')) window.location.href=\'index.php?page=statement&action=update_payment&id=' . $statement['settlement_id'] . '&status=unpaid\';" class="btn btn-xs btn-warning" title="更改为调整"><i class="fa fa-exchange"></i></a>';
                                        echo ' <a href="javascript:void(0);" onclick="if(confirm(\'确定要将结算类型改为退款吗？\')) window.location.href=\'index.php?page=statement&action=update_payment&id=' . $statement['settlement_id'] . '&status=refund\';" class="btn btn-xs btn-info" title="更改为退款"><i class="fa fa-undo"></i></a>';
                                        break;
                                    case 'unpaid':
                                        echo '<span class="badge badge-warning">调整</span> ';
                                        echo '<a href="javascript:void(0);" onclick="if(confirm(\'确定要将结算类型改为订单付款吗？\')) window.location.href=\'index.php?page=statement&action=update_payment&id=' . $statement['settlement_id'] . '&status=paid\';" class="btn btn-xs btn-primary" title="更改为付款"><i class="fa fa-money"></i></a>';
                                        echo ' <a href="javascript:void(0);" onclick="if(confirm(\'确定要将结算类型改为退款吗？\')) window.location.href=\'index.php?page=statement&action=update_payment&id=' . $statement['settlement_id'] . '&status=refund\';" class="btn btn-xs btn-info" title="更改为退款"><i class="fa fa-undo"></i></a>';
                                        break;
                                    case 'refund':
                                        echo '<span class="badge badge-info">退款</span> ';
                                        echo '<a href="javascript:void(0);" onclick="if(confirm(\'确定要将结算类型改为订单付款吗？\')) window.location.href=\'index.php?page=statement&action=update_payment&id=' . $statement['settlement_id'] . '&status=paid\';" class="btn btn-xs btn-primary" title="更改为付款"><i class="fa fa-money"></i></a>';
                                        echo ' <a href="javascript:void(0);" onclick="if(confirm(\'确定要将结算类型改为调整吗？\')) window.location.href=\'index.php?page=statement&action=update_payment&id=' . $statement['settlement_id'] . '&status=unpaid\';" class="btn btn-xs btn-warning" title="更改为调整"><i class="fa fa-exchange"></i></a>';
                                        break;
                                    default:
                                        echo $statement['payment_status'];
                                }
                                ?>
                            </td>
                            <td><?php echo $statement['order_number']; ?></td>
                            <td><?php echo $statement['payment_date']; ?></td>
                            <td>￥<?php echo number_format($statement['settlement_amount'], 2); ?></td>
                            <td class="actions">
                                <a href="index.php?page=statement&action=view&id=<?php echo $statement['settlement_id']; ?>" class="btn btn-sm btn-secondary">查看</a>
                                <a href="index.php?page=statement&action=edit&id=<?php echo $statement['settlement_id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                <a href="javascript:void(0);" onclick="confirmDelete(<?php echo $statement['settlement_id']; ?>)" class="btn btn-sm btn-danger">删除</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="8" class="text-center">暂无结算记录数据</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <script>
        // 全选/取消全选
        document.getElementById('select-all').addEventListener('change', function() {
            var checkboxes = document.getElementsByClassName('settlement-checkbox');
            for (var i = 0; i < checkboxes.length; i++) {
                checkboxes[i].checked = this.checked;
            }
        });

        // 如果所有复选框都被勾选，则"全选"复选框也应该被勾选
        var settlementCheckboxes = document.getElementsByClassName('settlement-checkbox');
        for (var i = 0; i < settlementCheckboxes.length; i++) {
            settlementCheckboxes[i].addEventListener('change', function() {
                var allChecked = true;
                for (var j = 0; j < settlementCheckboxes.length; j++) {
                    if (!settlementCheckboxes[j].checked) {
                        allChecked = false;
                        break;
                    }
                }
                document.getElementById('select-all').checked = allChecked;
            });
        }

        // 删除确认
        function confirmDelete(id) {
            if (confirm('确定要删除此结算记录吗？')) {
                window.location.href = 'index.php?page=statement&action=delete&id=' + id;
            }
        }
    </script>

    <style>
        .badge {
            display: inline-block;
            padding: 0.25em 0.6em;
            font-size: 75%;
            font-weight: 700;
            line-height: 1;
            text-align: center;
            white-space: nowrap;
            vertical-align: baseline;
            border-radius: 0.25rem;
        }

        .badge-primary {
            color: #fff;
            background-color: #007bff;
        }

        .badge-warning {
            color: #212529;
            background-color: #ffc107;
        }

        .badge-info {
            color: #fff;
            background-color: #17a2b8;
        }

        .text-center {
            text-align: center;
        }

        /* 快速操作按钮样式 */
        .btn-xs {
            padding: 0.1rem 0.25rem;
            font-size: 0.675rem;
            line-height: 1.5;
            border-radius: 0.2rem;
        }

        td .btn-xs {
            margin-right: 2px;
        }

        td .btn-xs i {
            font-size: 10px;
        }

        td.actions {
            white-space: nowrap;
        }

        /* 批量操作和搜索框样式 */
        .module-tools {
            display: flex;
            justify-content: space-between;
            margin-bottom: 15px;
            flex-wrap: wrap;
        }

        .tool-left,
        .tool-right {
            display: flex;
            align-items: center;
            gap: 10px;
            margin-bottom: 10px;
        }

        .batch-form {
            display: inline-block;
            margin-left: 15px;
        }

        .batch-actions {
            display: flex;
            gap: 10px;
            align-items: center;
        }

        .batch-actions select {
            width: auto;
            display: inline-block;
            padding: 6px 12px;
            font-size: 14px;
            font-weight: 400;
            line-height: 1.5;
            color: #495057;
            background-color: #fff;
            background-clip: padding-box;
            border: 1px solid #ced4da;
            border-radius: 0.25rem;
            transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
        }

        .data-table th:first-child,
        .data-table td:first-child {
            width: 40px;
            text-align: center;
        }

        .search-group {
            display: flex;
            align-items: center;
        }

        .search-input {
            padding: 6px 12px;
            font-size: 14px;
            line-height: 1.5;
            color: #495057;
            background-color: #fff;
            background-clip: padding-box;
            border: 1px solid #ced4da;
            border-radius: 0.25rem 0 0 0.25rem;
            transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
        }

        .search-group .btn {
            border-radius: 0 0.25rem 0.25rem 0;
            margin-left: -1px;
        }
    </style>
<?php endif; ?>