<?php
// 供应商管理页面
// 此页面不需要开头的DOCTYPE和HTML标记，因为它被包含在index.php中

// 防止直接访问
if (!defined('IN_SYSTEM')) {
    define('IN_SYSTEM', true);
}

// 初始化消息变量
$successMsg = $errorMsg = '';

// 获取供应商列表
$keyword = isset($_GET['keyword']) ? sanitize($_GET['keyword']) : '';

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['add_supplier']) || isset($_POST['edit_supplier'])) {
        // 获取表单数据
        $supplierId = isset($_POST['supplier_id']) ? intval($_POST['supplier_id']) : 0;
        $supplierName = sanitize($_POST['supplier_name']);
        $contactName = sanitize($_POST['contact_name']);
        $contactPhone = sanitize($_POST['contact_phone']);
        $address = sanitize($_POST['supplier_address']);

        if (empty($supplierName)) {
            $errorMsg = '供应商名称不能为空';
        } else {
            try {
                if ($supplierId > 0) {
                    // 更新供应商
                    $sql = "UPDATE suppliers SET supplier_name = ?, contact_name = ?, contact_phone = ?, address = ? WHERE supplier_id = ?";
                    $stmt = $conn->prepare($sql);

                    // 检查prepare是否成功
                    if ($stmt === false) {
                        $errorMsg = '准备更新供应商的SQL语句失败: ' . $conn->error;
                    } else {
                        $stmt->bind_param("ssssi", $supplierName, $contactName, $contactPhone, $address, $supplierId);

                        // 执行并检查
                        if ($stmt->execute()) {
                            $successMsg = '供应商信息已更新';
                            // 记录操作日志
                            log_operation($_SESSION['user_id'], '更新', "更新供应商 ID: {$supplierId}, 名称: {$supplierName}");
                        } else {
                            $errorMsg = '更新供应商信息失败: ' . $stmt->error;
                        }
                        $stmt->close();
                    }
                } else {
                    // 添加新供应商
                    $sql = "INSERT INTO suppliers (supplier_name, contact_name, contact_phone, address) VALUES (?, ?, ?, ?)";
                    $stmt = $conn->prepare($sql);

                    // 检查prepare是否成功
                    if ($stmt === false) {
                        $errorMsg = '准备添加供应商的SQL语句失败: ' . $conn->error;
                    } else {
                        $stmt->bind_param("ssss", $supplierName, $contactName, $contactPhone, $address);

                        // 执行并检查
                        if ($stmt->execute()) {
                            $successMsg = '供应商添加成功';
                            // 记录操作日志
                            log_operation($_SESSION['user_id'], '添加', "添加新供应商, 名称: {$supplierName}");
                        } else {
                            $errorMsg = '添加供应商失败: ' . $stmt->error;
                        }
                        $stmt->close();
                    }
                }
            } catch (Exception $e) {
                $errorMsg = '操作供应商数据时发生错误: ' . $e->getMessage();
            }
        }
    }
}

// 处理删除操作
if (isset($_GET['delete_id']) && $_GET['delete_id'] > 0) {
    $deleteId = intval($_GET['delete_id']);

    try {
        // 先检查是否有关联的采购订单
        $checkSql = "SELECT COUNT(*) as count FROM purchase_orders WHERE supplier_id = ?";
        $checkStmt = $conn->prepare($checkSql);

        if ($checkStmt === false) {
            $errorMsg = '检查供应商关联的SQL语句失败: ' . $conn->error;
        } else {
            $checkStmt->bind_param("i", $deleteId);
            $checkStmt->execute();
            $checkResult = $checkStmt->get_result();

            if ($checkResult) {
                $row = $checkResult->fetch_assoc();

                if ($row['count'] > 0) {
                    $errorMsg = '无法删除该供应商，存在关联的采购订单';
                } else {
                    // 执行删除
                    $sql = "DELETE FROM suppliers WHERE supplier_id = ?";
                    $stmt = $conn->prepare($sql);

                    if ($stmt === false) {
                        $errorMsg = '准备删除供应商的SQL语句失败: ' . $conn->error;
                    } else {
                        $stmt->bind_param("i", $deleteId);

                        if ($stmt->execute()) {
                            $successMsg = '供应商删除成功';
                            // 记录操作日志
                            log_operation($_SESSION['user_id'], '删除', "删除供应商 ID: {$deleteId}");
                        } else {
                            $errorMsg = '删除供应商失败: ' . $stmt->error;
                        }
                        $stmt->close();
                    }
                }
            } else {
                $errorMsg = '检查供应商关联数据失败';
            }
            $checkStmt->close();
        }
    } catch (Exception $e) {
        $errorMsg = '删除供应商时发生错误: ' . $e->getMessage();
    }
}

// 获取要编辑的供应商信息
$editSupplier = null;
if (isset($_GET['edit_id']) && $_GET['edit_id'] > 0) {
    $editId = intval($_GET['edit_id']);

    try {
        $sql = "SELECT * FROM suppliers WHERE supplier_id = ?";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $errorMsg = '准备查询供应商的SQL语句失败: ' . $conn->error;
        } else {
            $stmt->bind_param("i", $editId);

            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result && $result->num_rows > 0) {
                    $editSupplier = $result->fetch_assoc();
                }
            } else {
                $errorMsg = '执行查询供应商失败: ' . $stmt->error;
            }
            $stmt->close();
        }
    } catch (Exception $e) {
        $errorMsg = '获取供应商信息时发生错误: ' . $e->getMessage();
    }
}

// 获取要查看的供应商详情
$viewSupplier = null;
if (isset($_GET['view_id']) && $_GET['view_id'] > 0) {
    $viewId = intval($_GET['view_id']);

    try {
        $sql = "SELECT * FROM suppliers WHERE supplier_id = ?";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $errorMsg = '准备查询供应商详情的SQL语句失败: ' . $conn->error;
        } else {
            $stmt->bind_param("i", $viewId);

            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result && $result->num_rows > 0) {
                    $viewSupplier = $result->fetch_assoc();
                }
            } else {
                $errorMsg = '执行查询供应商详情失败: ' . $stmt->error;
            }
            $stmt->close();
        }
    } catch (Exception $e) {
        $errorMsg = '获取供应商详情时发生错误: ' . $e->getMessage();
    }
}

// 获取供应商列表
$suppliers = [];

try {
    if (!empty($keyword)) {
        $sql = "SELECT * FROM suppliers WHERE supplier_name LIKE ? OR contact_name LIKE ? OR contact_phone LIKE ?";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $errorMsg = '准备查询供应商列表的SQL语句失败: ' . $conn->error;
        } else {
            $keywordParam = "%{$keyword}%";
            $stmt->bind_param("sss", $keywordParam, $keywordParam, $keywordParam);

            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result) {
                    while ($row = $result->fetch_assoc()) {
                        $suppliers[] = $row;
                    }
                }
            } else {
                $errorMsg = '执行查询供应商列表失败: ' . $stmt->error;
            }
            $stmt->close();
        }
    } else {
        $sql = "SELECT * FROM suppliers";
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $errorMsg = '准备查询供应商列表的SQL语句失败: ' . $conn->error;
        } else {
            if ($stmt->execute()) {
                $result = $stmt->get_result();

                if ($result) {
                    while ($row = $result->fetch_assoc()) {
                        $suppliers[] = $row;
                    }
                }
            } else {
                $errorMsg = '执行查询供应商列表失败: ' . $stmt->error;
            }
            $stmt->close();
        }
    }
} catch (Exception $e) {
    $errorMsg = '获取供应商列表时发生错误: ' . $e->getMessage();
}

// 处理URL传递的消息
if (isset($_GET['success'])) {
    $successMsg = $_GET['success'];
}
if (isset($_GET['error'])) {
    $errorMsg = $_GET['error'];
}
?>

<!-- 显示成功/错误消息 -->
<?php if (!empty($successMsg)): ?>
    <div class="alert alert-success"><?php echo $successMsg; ?></div>
<?php endif; ?>

<?php if (!empty($errorMsg)): ?>
    <div class="alert alert-error"><?php echo $errorMsg; ?></div>
<?php endif; ?>

<!-- 供应商详情查看 -->
<?php if ($viewSupplier): ?>
    <div class="user-details">
        <h3>供应商详情</h3>
        <div class="detail-group">
            <span class="label">供应商ID:</span>
            <span><?php echo $viewSupplier['supplier_id']; ?></span>
        </div>
        <div class="detail-group">
            <span class="label">供应商名称:</span>
            <span><?php echo $viewSupplier['supplier_name']; ?></span>
        </div>
        <div class="detail-group">
            <span class="label">联系人:</span>
            <span><?php echo $viewSupplier['contact_name'] ?: '未设置'; ?></span>
        </div>
        <div class="detail-group">
            <span class="label">联系电话:</span>
            <span><?php echo $viewSupplier['contact_phone'] ?: '未设置'; ?></span>
        </div>
        <div class="detail-group">
            <span class="label">地址:</span>
            <span><?php echo $viewSupplier['address'] ?: '未设置'; ?></span>
        </div>
        <div class="detail-group">
            <span class="label">应付账款:</span>
            <span>￥<?php echo number_format($viewSupplier['total_payable'], 2); ?></span>
        </div>
        <div class="detail-group">
            <span class="label">已付款:</span>
            <span>￥<?php echo number_format($viewSupplier['total_paid'], 2); ?></span>
        </div>
        <div class="detail-group">
            <span class="label">创建时间:</span>
            <span><?php echo $viewSupplier['created_at']; ?></span>
        </div>
        <div class="detail-group">
            <span class="label">最后更新:</span>
            <span><?php echo $viewSupplier['updated_at']; ?></span>
        </div>
        <div class="btn-group">
            <a href="index.php?page=supplier" class="btn btn-secondary">返回列表</a>
            <a href="index.php?page=supplier&edit_id=<?php echo $viewSupplier['supplier_id']; ?>" class="btn btn-primary">编辑供应商</a>
        </div>
    </div>
<?php else: ?>

    <!-- 供应商表单 -->
    <?php if (!$editSupplier && !$viewSupplier): ?>
        <div class="tool-left">
            <button type="button" class="btn btn-primary" id="showAddForm">添加供应商</button>
        </div>
    <?php endif; ?>

    <!-- 添加/编辑供应商表单 -->
    <div id="supplierForm" style="display: <?php echo ($editSupplier || isset($_POST['add_supplier']) || isset($_POST['edit_supplier'])) ? 'block' : 'none'; ?>">
        <h3><?php echo $editSupplier ? '编辑供应商' : '添加供应商'; ?></h3>
        <form method="post" action="index.php?page=supplier">
            <?php if ($editSupplier): ?>
                <input type="hidden" name="supplier_id" value="<?php echo $editSupplier['supplier_id']; ?>">
            <?php endif; ?>

            <div class="form-group">
                <label for="supplier_name">供应商名称 <span style="color: red;">*</span></label>
                <input type="text" id="supplier_name" name="supplier_name" value="<?php echo $editSupplier ? $editSupplier['supplier_name'] : ''; ?>" required>
            </div>

            <div class="form-group">
                <label for="contact_name">联系人</label>
                <input type="text" id="contact_name" name="contact_name" value="<?php echo $editSupplier ? $editSupplier['contact_name'] : ''; ?>">
            </div>

            <div class="form-group">
                <label for="contact_phone">联系电话</label>
                <input type="text" id="contact_phone" name="contact_phone" value="<?php echo $editSupplier ? $editSupplier['contact_phone'] : ''; ?>">
            </div>

            <div class="form-group">
                <label for="supplier_address">地址</label>
                <input type="text" id="supplier_address" name="supplier_address" value="<?php echo $editSupplier ? $editSupplier['address'] : ''; ?>">
            </div>

            <div class="form-group">
                <button type="submit" name="<?php echo $editSupplier ? 'edit_supplier' : 'add_supplier'; ?>" class="btn btn-primary">
                    <?php echo $editSupplier ? '更新供应商' : '添加供应商'; ?>
                </button>
                <a href="index.php?page=supplier" class="btn btn-secondary">取消</a>
            </div>
        </form>
    </div>

    <!-- 供应商搜索 -->
    <div class="search-form">
        <form method="get" action="index.php">
            <input type="hidden" name="page" value="supplier">
            <div class="search-group">
                <input type="text" name="keyword" placeholder="搜索供应商名称/联系人/电话" class="search-input" value="<?php echo htmlspecialchars($keyword); ?>">
                <button type="submit" class="btn btn-primary">搜索</button>
                <?php if (!empty($keyword)): ?>
                    <a href="index.php?page=supplier" class="btn btn-secondary">清除</a>
                <?php endif; ?>
            </div>
        </form>
    </div>

    <!-- 供应商列表 -->
    <?php if (!$editSupplier && !$viewSupplier): ?>
        <table class="data-table">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>供应商名称</th>
                    <th>联系人</th>
                    <th>联系电话</th>
                    <th>应付账款</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php if (empty($suppliers)): ?>
                    <tr>
                        <td colspan="6" style="text-align: center;">暂无供应商记录</td>
                    </tr>
                <?php else: ?>
                    <?php foreach ($suppliers as $supplier): ?>
                        <tr>
                            <td><?php echo $supplier['supplier_id']; ?></td>
                            <td><?php echo $supplier['supplier_name']; ?></td>
                            <td><?php echo $supplier['contact_name'] ?: '-'; ?></td>
                            <td><?php echo $supplier['contact_phone'] ?: '-'; ?></td>
                            <td>￥<?php echo number_format($supplier['total_payable'] - $supplier['total_paid'], 2); ?></td>
                            <td class="actions">
                                <a href="index.php?page=supplier&view_id=<?php echo $supplier['supplier_id']; ?>" class="btn btn-sm btn-secondary">查看</a>
                                <a href="index.php?page=supplier&edit_id=<?php echo $supplier['supplier_id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                <a href="javascript:void(0);" onclick="confirmDelete(<?php echo $supplier['supplier_id']; ?>, '<?php echo addslashes($supplier['supplier_name']); ?>')" class="btn btn-sm btn-danger">删除</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php endif; ?>
            </tbody>
        </table>
    <?php endif; ?>
<?php endif; ?>

<script>
    // 显示添加表单
    document.getElementById('showAddForm').addEventListener('click', function() {
        document.getElementById('supplierForm').style.display = 'block';
    });

    // 删除确认
    function confirmDelete(id, name) {
        if (confirm('确定要删除供应商 "' + name + '" 吗？')) {
            window.location.href = 'index.php?page=supplier&delete_id=' + id;
        }
    }
</script>

<style>
    .user-details {
        background-color: #f9f9f9;
        border: 1px solid #ddd;
        border-radius: 4px;
        padding: 20px;
        margin-bottom: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .user-details h3 {
        margin-top: 0;
        padding-bottom: 10px;
        border-bottom: 1px solid #ddd;
        margin-bottom: 15px;
    }

    .detail-group {
        display: flex;
        margin-bottom: 10px;
        padding-bottom: 10px;
        border-bottom: 1px dashed #eee;
    }

    .detail-group .label {
        width: 120px;
        color: #666;
        font-weight: bold;
    }

    .btn-group {
        display: flex;
        gap: 10px;
        margin-top: 20px;
        padding-top: 15px;
        border-top: 1px solid #ddd;
    }

    /* 搜索框样式 */
    .search-form {
        margin-bottom: 20px;
        float: right;
        margin-top: -40px;
    }

    .search-group {
        display: flex;
        align-items: center;
    }

    .search-input {
        padding: 6px 12px;
        font-size: 14px;
        line-height: 1.5;
        color: #495057;
        background-color: #fff;
        background-clip: padding-box;
        border: 1px solid #ced4da;
        border-radius: 0.25rem 0 0 0.25rem;
        transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
    }

    .search-group .btn {
        border-radius: 0 0.25rem 0.25rem 0;
        margin-left: -1px;
    }

    .search-group .btn-secondary {
        border-radius: 0.25rem;
        margin-left: 5px;
    }
</style>