<?php
// 防止直接访问
if (!defined('IN_SYSTEM')) {
    define('IN_SYSTEM', true);
}

// 获取账单ID（如果是编辑模式）
$bill_id = isset($_GET['id']) ? intval($_GET['id']) : 0;
$isEdit = ($action == 'edit' && $bill_id > 0);

// 初始化账单数据
$bill = [
    'bill_id' => 0,
    'bill_type' => 'income',
    'description' => '',
    'amount' => '',
    'transaction_date' => date('Y-m-d'),
    'payment_method' => '',
    'related_customer_id' => 0,
    'category' => '',
    'remark' => '',
    'created_by' => $_SESSION['user_id'],
    'created_at' => date('Y-m-d H:i:s'),
    'updated_at' => date('Y-m-d H:i:s')
];

// 如果是编辑模式，获取账单数据
if ($isEdit) {
    $sql = "SELECT * FROM custom_bills WHERE bill_id = ?";
    $stmt = $conn->prepare($sql);

    if ($stmt) {
        $stmt->bind_param("i", $bill_id);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($row = $result->fetch_assoc()) {
            $bill = $row;
        } else {
            // 账单不存在，显示错误
            $message = "未找到指定的账单记录";
            $messageType = "error";
            include 'custom_bill_list.php';
            exit();
        }

        $stmt->close();
    }
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // 验证和净化输入
    $bill_type = isset($_POST['bill_type']) ? sanitize($_POST['bill_type']) : '';
    $description = isset($_POST['description']) ? sanitize($_POST['description']) : '';
    $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
    $transaction_date = isset($_POST['transaction_date']) ? sanitize($_POST['transaction_date']) : '';
    $payment_method = isset($_POST['payment_method']) ? sanitize($_POST['payment_method']) : '';
    $related_customer_id = isset($_POST['related_customer_id']) ? intval($_POST['related_customer_id']) : 0;
    $category = isset($_POST['category']) ? sanitize($_POST['category']) : '';
    $remark = isset($_POST['remark']) ? sanitize($_POST['remark']) : '';

    // 验证必填字段
    $errors = [];

    if (empty($bill_type)) {
        $errors[] = "账单类型不能为空";
    }

    if (empty($description)) {
        $errors[] = "账单描述不能为空";
    }

    if ($amount <= 0) {
        $errors[] = "金额必须大于零";
    }

    if (empty($transaction_date)) {
        $errors[] = "交易日期不能为空";
    }

    if (empty($payment_method)) {
        $errors[] = "支付方式不能为空";
    }

    // 如果没有错误，继续处理
    if (empty($errors)) {
        // 准备SQL语句
        if ($isEdit) {
            // 更新现有账单
            $sql = "UPDATE custom_bills SET 
                    bill_type = ?, 
                    description = ?, 
                    amount = ?, 
                    transaction_date = ?, 
                    payment_method = ?, 
                    related_customer_id = ?, 
                    category = ?, 
                    remark = ?, 
                    updated_at = NOW() 
                    WHERE bill_id = ?";

            $stmt = $conn->prepare($sql);
            $stmt->bind_param(
                "ssdssissi",
                $bill_type,
                $description,
                $amount,
                $transaction_date,
                $payment_method,
                $related_customer_id,
                $category,
                $remark,
                $bill_id
            );
        } else {
            // 添加新账单
            $sql = "INSERT INTO custom_bills (
                    bill_type, 
                    description, 
                    amount, 
                    transaction_date, 
                    payment_method, 
                    related_customer_id, 
                    category, 
                    remark, 
                    created_by, 
                    created_at, 
                    updated_at
                ) VALUES (
                    ?, ?, ?, ?, ?, ?, ?, ?, ?, NOW(), NOW()
                )";

            $stmt = $conn->prepare($sql);
            $user_id = $_SESSION['user_id'];
            $stmt->bind_param(
                "ssdssissi",
                $bill_type,
                $description,
                $amount,
                $transaction_date,
                $payment_method,
                $related_customer_id,
                $category,
                $remark,
                $user_id
            );
        }

        // 执行SQL
        if ($stmt->execute()) {
            // 获取新插入的账单ID
            if (!$isEdit) {
                $bill_id = $conn->insert_id;
            }

            // 记录操作日志
            $operationDetails = "用户 {$_SESSION['username']} " . ($isEdit ? "更新" : "创建") . "了自定义账单 (ID: {$bill_id})";
            log_operation($_SESSION['user_id'], $isEdit ? '更新' : '创建', $operationDetails);

            // 设置成功消息
            $message = "账单" . ($isEdit ? "更新" : "创建") . "成功";
            $messageType = "success";

            // 重定向到账单列表页
            header("Location: index.php?page=custom_bill&message={$message}&messageType={$messageType}");
            exit();
        } else {
            // 设置错误消息
            $message = "操作失败: " . $stmt->error;
            $messageType = "error";
        }

        $stmt->close();
    } else {
        // 显示表单验证错误
        $message = "请修正以下错误:<ul><li>" . implode("</li><li>", $errors) . "</li></ul>";
        $messageType = "error";
    }
}

// 获取所有客户
$customerSql = "SELECT customer_id, customer_name FROM customers ORDER BY customer_name";
$customerResult = $conn->query($customerSql);
$customers = [];
while ($customerResult && $row = $customerResult->fetch_assoc()) {
    $customers[] = $row;
}

// 获取所有分类（用于下拉列表和数据列表）
$categorySql = "SELECT DISTINCT category FROM custom_bills WHERE category IS NOT NULL AND category != '' ORDER BY category";
$categoryResult = $conn->query($categorySql);
$categories = [];
while ($categoryResult && $row = $categoryResult->fetch_assoc()) {
    $categories[] = $row['category'];
}

// 获取所有支付方式（数据列表）
$paymentMethodSql = "SELECT DISTINCT payment_method FROM custom_bills WHERE payment_method IS NOT NULL AND payment_method != '' ORDER BY payment_method";
$paymentMethodResult = $conn->query($paymentMethodSql);
$paymentMethods = [];
while ($paymentMethodResult && $row = $paymentMethodResult->fetch_assoc()) {
    $paymentMethods[] = $row['payment_method'];
}
?>

<div class="page-header">
    <h3><?php echo $isEdit ? '编辑账单' : '新增账单'; ?></h3>
    <p><?php echo $isEdit ? '修改现有账单信息' : '创建新的自定义账单记录'; ?></p>
</div>

<!-- 消息提示 -->
<?php if (isset($message) && isset($messageType)): ?>
    <div class="alert alert-<?php echo $messageType == 'error' ? 'danger' : $messageType; ?> alert-dismissible fade show" role="alert">
        <?php echo $message; ?>
        <button type="button" class="close" data-dismiss="alert" aria-label="Close">
            <span aria-hidden="true">&times;</span>
        </button>
    </div>
<?php endif; ?>

<!-- 账单表单 -->
<div class="form-container">
    <form action="index.php?page=custom_bill&action=<?php echo $isEdit ? 'edit&id=' . $bill_id : 'add'; ?>" method="POST">
        <div class="row">
            <!-- 账单类型 -->
            <div class="form-group col-md-6">
                <label for="bill_type">账单类型 <span class="text-danger">*</span></label>
                <div class="bill-type-selector">
                    <div class="form-check form-check-inline">
                        <input class="form-check-input" type="radio" name="bill_type" id="bill_type_income"
                            value="income" <?php echo ($bill['bill_type'] == 'income' || empty($bill['bill_type'])) ? 'checked' : ''; ?>>
                        <label class="form-check-label" for="bill_type_income">
                            <span class="badge badge-success">收入</span>
                        </label>
                    </div>
                    <div class="form-check form-check-inline">
                        <input class="form-check-input" type="radio" name="bill_type" id="bill_type_expense"
                            value="expense" <?php echo $bill['bill_type'] == 'expense' ? 'checked' : ''; ?>>
                        <label class="form-check-label" for="bill_type_expense">
                            <span class="badge badge-danger">支出</span>
                        </label>
                    </div>
                </div>
            </div>

            <!-- 交易日期 -->
            <div class="form-group col-md-6">
                <label for="transaction_date">交易日期 <span class="text-danger">*</span></label>
                <input type="date" class="form-control" id="transaction_date" name="transaction_date"
                    value="<?php echo htmlspecialchars($bill['transaction_date']); ?>" required>
            </div>

            <!-- 账单描述 -->
            <div class="form-group col-md-12">
                <label for="description">账单描述 <span class="text-danger">*</span></label>
                <input type="text" class="form-control" id="description" name="description"
                    placeholder="例如：销售商品、采购原料、办公费用等"
                    value="<?php echo htmlspecialchars($bill['description']); ?>" required>
            </div>

            <!-- 金额 -->
            <div class="form-group col-md-6">
                <label for="amount">金额 (¥) <span class="text-danger">*</span></label>
                <input type="number" class="form-control" id="amount" name="amount" step="0.01" min="0.01"
                    placeholder="输入金额" value="<?php echo htmlspecialchars($bill['amount']); ?>" required>
            </div>

            <!-- 支付方式 -->
            <div class="form-group col-md-6">
                <label for="payment_method">支付方式 <span class="text-danger">*</span></label>
                <input type="text" class="form-control" id="payment_method" name="payment_method"
                    placeholder="例如：现金、微信、支付宝、银行转账等"
                    list="payment_method_list"
                    value="<?php echo htmlspecialchars($bill['payment_method']); ?>" required>
                <datalist id="payment_method_list">
                    <option value="现金">
                    <option value="微信">
                    <option value="支付宝">
                    <option value="银行转账">
                    <option value="信用卡">
                        <?php foreach ($paymentMethods as $method): ?>
                    <option value="<?php echo htmlspecialchars($method); ?>">
                    <?php endforeach; ?>
                </datalist>
            </div>

            <!-- 关联客户 -->
            <div class="form-group col-md-6">
                <label for="related_customer_id">关联客户</label>
                <select class="form-control" id="related_customer_id" name="related_customer_id">
                    <option value="0">-- 无关联客户 --</option>
                    <?php foreach ($customers as $customer): ?>
                        <option value="<?php echo $customer['customer_id']; ?>"
                            <?php echo $bill['related_customer_id'] == $customer['customer_id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($customer['customer_name']); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <!-- 账单分类 -->
            <div class="form-group col-md-6">
                <label for="category">账单分类</label>
                <input type="text" class="form-control" id="category" name="category"
                    placeholder="例如：销售收入、原材料采购、办公费用等"
                    list="category_list"
                    value="<?php echo htmlspecialchars($bill['category']); ?>">
                <datalist id="category_list">
                    <option value="销售收入">
                    <option value="原材料采购">
                    <option value="办公费用">
                    <option value="水电费">
                    <option value="租金">
                    <option value="工资">
                    <option value="税费">
                    <option value="运输费">
                    <option value="维修保养">
                    <option value="广告宣传">
                        <?php foreach ($categories as $cat): ?>
                    <option value="<?php echo htmlspecialchars($cat); ?>">
                    <?php endforeach; ?>
                </datalist>
            </div>

            <!-- 备注 -->
            <div class="form-group col-md-12">
                <label for="remark">备注</label>
                <textarea class="form-control" id="remark" name="remark" rows="3"
                    placeholder="可选：输入更多细节说明或备注"><?php echo htmlspecialchars($bill['remark']); ?></textarea>
            </div>

            <!-- 提交按钮 -->
            <div class="form-group col-md-12 form-actions">
                <button type="submit" class="btn btn-primary">
                    <?php echo $isEdit ? '保存修改' : '保存账单'; ?>
                </button>
                <a href="index.php?page=custom_bill" class="btn btn-secondary">
                    取消
                </a>
            </div>
        </div>
    </form>
</div>

<style>
    .page-header {
        margin-bottom: 20px;
    }

    .page-header h3 {
        margin-bottom: 10px;
    }

    .form-container {
        border: 1px solid #ddd;
        border-radius: 5px;
        padding: 20px;
        background-color: #fff;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .bill-type-selector .badge {
        padding: 6px 12px;
        border-radius: 4px;
        font-size: 14px;
        margin-left: 5px;
    }

    .badge-success {
        background-color: #28a745;
        color: white;
    }

    .badge-danger {
        background-color: #dc3545;
        color: white;
    }

    .text-danger {
        color: #dc3545;
    }

    .form-actions {
        margin-top: 20px;
        padding-top: 15px;
        border-top: 1px solid #eee;
    }
</style>

<script>
    $(document).ready(function() {
        // 金额输入格式化
        $('#amount').on('blur', function() {
            var val = parseFloat($(this).val());
            if (!isNaN(val)) {
                $(this).val(val.toFixed(2));
            }
        });
    });
</script>