<?php
// 防止直接访问
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 确保$conn变量存在
if (!isset($conn) || $conn === null) {
    die("数据库连接失败");
}

// 初始化消息变量
$message = '';
$messageType = '';

// 检查会话中是否有消息
if (isset($_SESSION['message']) && isset($_SESSION['message_type'])) {
    $message = $_SESSION['message'];
    $messageType = $_SESSION['message_type'];

    // 清除会话消息（只显示一次）
    unset($_SESSION['message']);
    unset($_SESSION['message_type']);
}

// 从URL获取消息（向后兼容）
if (empty($message) && isset($_GET['message'])) {
    $message = $_GET['message'];
    $messageType = isset($_GET['type']) ? $_GET['type'] : 'info';
}

// 处理客户删除操作
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $customer_id = (int)$_GET['id'];

    try {
        // 检查客户是否存在
        $checkSql = "SELECT customer_id FROM customers WHERE customer_id = ?";
        $checkStmt = $conn->prepare($checkSql);

        if ($checkStmt) {
            $checkStmt->bind_param("i", $customer_id);
            $checkStmt->execute();
            $checkResult = $checkStmt->get_result();

            if ($checkResult->num_rows > 0) {
                // 检查客户是否有关联的销售订单
                $orderSql = "SELECT COUNT(*) as count FROM sales_orders WHERE customer_id = ?";
                $orderStmt = $conn->prepare($orderSql);
                $orderStmt->bind_param("i", $customer_id);
                $orderStmt->execute();
                $orderResult = $orderStmt->get_result();
                $orderCount = $orderResult->fetch_assoc()['count'];
                $orderStmt->close();

                if ($orderCount > 0) {
                    $_SESSION['message'] = '客户已有关联销售订单，无法删除';
                    $_SESSION['message_type'] = 'error';
                    header("Location: index.php?page=customer");
                    exit;
                }

                // 检查客户是否有关联的应收账款
                $receivableSql = "SELECT COUNT(*) as count FROM sales_receivables WHERE customer_id = ?";
                $receivableStmt = $conn->prepare($receivableSql);
                $receivableStmt->bind_param("i", $customer_id);
                $receivableStmt->execute();
                $receivableResult = $receivableStmt->get_result();
                $receivableCount = $receivableResult->fetch_assoc()['count'];
                $receivableStmt->close();

                if ($receivableCount > 0) {
                    $_SESSION['message'] = '客户已有关联应收账款，无法删除';
                    $_SESSION['message_type'] = 'error';
                    header("Location: index.php?page=customer");
                    exit;
                }

                // 执行删除操作
                $deleteSql = "DELETE FROM customers WHERE customer_id = ?";
                $deleteStmt = $conn->prepare($deleteSql);
                $deleteStmt->bind_param("i", $customer_id);

                if ($deleteStmt->execute()) {
                    $_SESSION['message'] = '客户删除成功';
                    $_SESSION['message_type'] = 'success';
                    header("Location: index.php?page=customer");
                    exit;
                } else {
                    $_SESSION['message'] = '客户删除失败: ' . $conn->error;
                    $_SESSION['message_type'] = 'error';
                    header("Location: index.php?page=customer");
                    exit;
                }
            } else {
                $_SESSION['message'] = '客户不存在';
                $_SESSION['message_type'] = 'error';
                header("Location: index.php?page=customer");
                exit;
            }
        } else {
            $_SESSION['message'] = '操作失败: ' . $conn->error;
            $_SESSION['message_type'] = 'error';
            header("Location: index.php?page=customer");
            exit;
        }
    } catch (Exception $e) {
        $_SESSION['message'] = '操作异常: ' . $e->getMessage();
        $_SESSION['message_type'] = 'error';
        header("Location: index.php?page=customer");
        exit;
    }
}

// 处理表单提交（添加或编辑客户）
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    $action = $_POST['action'];

    // 获取表单数据
    $customer_name = isset($_POST['customer_name']) ? trim($_POST['customer_name']) : '';
    $contact_person = isset($_POST['contact_person']) ? trim($_POST['contact_person']) : '';
    $phone = isset($_POST['phone']) ? trim($_POST['phone']) : '';
    $email = isset($_POST['email']) ? trim($_POST['email']) : '';
    $address = isset($_POST['address']) ? trim($_POST['address']) : '';
    $customer_type = isset($_POST['customer_type']) ? trim($_POST['customer_type']) : 'retail';
    $credit_limit = isset($_POST['credit_limit']) ? (float)$_POST['credit_limit'] : 0;
    $account_period = isset($_POST['account_period']) ? (int)$_POST['account_period'] : 0;

    // 表单验证
    $errors = [];

    if (empty($customer_name)) {
        $errors[] = "客户名称不能为空";
    }

    if (empty($errors)) {
        if ($action == 'add') {
            // 添加新客户
            $sql = "INSERT INTO customers (customer_name, contact_person, phone, email, address, customer_type, credit_limit, account_period) 
                    VALUES (?, ?, ?, ?, ?, ?, ?, ?)";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("ssssssdi", $customer_name, $contact_person, $phone, $email, $address, $customer_type, $credit_limit, $account_period);

            if ($stmt->execute()) {
                // 记录操作日志
                log_operation($_SESSION['user_id'], '添加客户', "添加了客户: {$customer_name}");

                // 将消息存储在会话中
                $_SESSION['message'] = '客户添加成功';
                $_SESSION['message_type'] = 'success';

                // 添加成功后，重定向到列表页面
                header("Location: index.php?page=customer");
                exit;
            } else {
                $message = "客户添加失败: " . $conn->error;
                $messageType = "error";
            }
        } elseif ($action == 'edit' && isset($_POST['customer_id'])) {
            $customer_id = (int)$_POST['customer_id'];

            // 更新客户信息
            $sql = "UPDATE customers SET customer_name=?, contact_person=?, phone=?, email=?, address=?, 
                    customer_type=?, credit_limit=?, account_period=? WHERE customer_id=?";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param(
                "ssssssdii",
                $customer_name,
                $contact_person,
                $phone,
                $email,
                $address,
                $customer_type,
                $credit_limit,
                $account_period,
                $customer_id
            );

            if ($stmt->execute()) {
                // 记录操作日志
                log_operation($_SESSION['user_id'], '编辑客户', "编辑了客户ID: {$customer_id}, 名称: {$customer_name}");

                // 将消息存储在会话中
                $_SESSION['message'] = '客户更新成功';
                $_SESSION['message_type'] = 'success';

                // 更新成功后，重定向到列表页面
                header("Location: index.php?page=customer");
                exit;
            } else {
                $message = "客户更新失败: " . $conn->error;
                $messageType = "error";
            }
        }
    } else {
        $message = implode('<br>', $errors);
        $messageType = "error";
    }
}

// 检查是否为编辑模式
$isEdit = false;
$editData = [];

if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $customer_id = (int)$_GET['id'];
    $sql = "SELECT * FROM customers WHERE customer_id = ?";
    $stmt = $conn->prepare($sql);

    if ($stmt) {
        $stmt->bind_param("i", $customer_id);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            $isEdit = true;
            $editData = $result->fetch_assoc();
        } else {
            $message = "未找到客户记录";
            $messageType = "error";
        }
    }
}

// 获取客户列表
$page = isset($_GET['listpage']) ? (int)$_GET['listpage'] : 1;
$limit = 10; // 每页显示10条记录
$offset = ($page - 1) * $limit;

// 搜索条件
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$type = isset($_GET['type']) ? trim($_GET['type']) : '';

// 构建查询条件
$whereClause = "";
$params = [];
$types = "";

if (!empty($search)) {
    $whereClause = "WHERE (customer_name LIKE ? OR contact_person LIKE ? OR phone LIKE ?)";
    $searchParam = "%" . $search . "%";
    $params[] = $searchParam;
    $params[] = $searchParam;
    $params[] = $searchParam;
    $types .= "sss";
}

if (!empty($type)) {
    if (empty($whereClause)) {
        $whereClause = "WHERE customer_type = ?";
    } else {
        $whereClause .= " AND customer_type = ?";
    }
    $params[] = $type;
    $types .= "s";
}

// 获取总记录数
$countSql = "SELECT COUNT(*) as total FROM customers " . $whereClause;
$countStmt = $conn->prepare($countSql);

if (!empty($params)) {
    $countStmt->bind_param($types, ...$params);
}

$countStmt->execute();
$countResult = $countStmt->get_result();
$totalRecords = $countResult->fetch_assoc()['total'];
$totalPages = ceil($totalRecords / $limit);

// 获取客户列表
$sql = "SELECT * FROM customers {$whereClause} ORDER BY customer_id DESC LIMIT ?, ?";
$stmt = $conn->prepare($sql);

// 添加分页参数
$params[] = $offset;
$params[] = $limit;
$types .= "ii";

$stmt->bind_param($types, ...$params);
$stmt->execute();
$result = $stmt->get_result();

$customers = [];
while ($row = $result->fetch_assoc()) {
    $customers[] = $row;
}

// 记录日志，调试数据加载
error_log("客户查询结果: " . count($customers) . " 条记录");
error_log("查询条件: " . $whereClause);
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="module-tools">
    <div class="tool-left">
        <?php if ($isEdit): ?>
            <h4>编辑客户</h4>
        <?php else: ?>
            <button type="button" id="btnAddCustomer" class="btn btn-primary">添加客户</button>
        <?php endif; ?>
    </div>
    <div class="tool-right">
        <form action="index.php" method="get" class="search-form">
            <input type="hidden" name="page" value="customer">
            <div class="search-group">
                <input type="text" name="search" class="search-input" placeholder="搜索客户名称或联系人" value="<?php echo htmlspecialchars($search); ?>">
            </div>
            <div class="search-group">
                <select name="type" class="search-input">
                    <option value="">所有类型</option>
                    <option value="retail" <?php echo $type == 'retail' ? 'selected' : ''; ?>>零售客户</option>
                    <option value="wholesale" <?php echo $type == 'wholesale' ? 'selected' : ''; ?>>批发客户</option>
                </select>
            </div>
            <button type="submit" class="btn btn-secondary">搜索</button>
            <a href="index.php?page=customer" class="btn btn-secondary">重置</a>
        </form>
    </div>
</div>

<!-- 客户表单 -->
<div id="customerFormContainer" class="form-wrapper" style="<?php echo (!$isEdit) ? 'display:none;' : ''; ?>">
    <div class="form-header">
        <h4><?php echo $isEdit ? '编辑客户' : '添加客户'; ?></h4>
        <?php if (!$isEdit): ?>
            <button type="button" id="btnCloseForm" class="btn btn-sm btn-secondary">关闭</button>
        <?php endif; ?>
    </div>
    <form method="post" action="" class="form-horizontal">
        <input type="hidden" name="action" value="<?php echo $isEdit ? 'edit' : 'add'; ?>">
        <?php if ($isEdit): ?>
            <input type="hidden" name="customer_id" value="<?php echo $editData['customer_id']; ?>">
        <?php endif; ?>

        <div class="form-row">
            <div class="form-group col-md-6">
                <label for="customer_name">客户名称 <span class="required">*</span></label>
                <input type="text" name="customer_name" id="customer_name" class="form-control" required
                    value="<?php echo $isEdit ? htmlspecialchars($editData['customer_name']) : ''; ?>">
            </div>
            <div class="form-group col-md-6">
                <label for="contact_person">联系人</label>
                <input type="text" name="contact_person" id="contact_person" class="form-control"
                    value="<?php echo $isEdit ? htmlspecialchars($editData['contact_person']) : ''; ?>">
            </div>
        </div>

        <div class="form-row">
            <div class="form-group col-md-6">
                <label for="phone">联系电话</label>
                <input type="text" name="phone" id="phone" class="form-control"
                    value="<?php echo $isEdit ? htmlspecialchars($editData['phone']) : ''; ?>">
            </div>
            <div class="form-group col-md-6">
                <label for="email">电子邮箱</label>
                <input type="email" name="email" id="email" class="form-control"
                    value="<?php echo $isEdit ? htmlspecialchars($editData['email']) : ''; ?>">
            </div>
        </div>

        <div class="form-row">
            <div class="form-group col-md-12">
                <label for="address">地址</label>
                <input type="text" name="address" id="address" class="form-control"
                    value="<?php echo $isEdit ? htmlspecialchars($editData['address']) : ''; ?>">
            </div>
        </div>

        <div class="form-row">
            <div class="form-group col-md-4">
                <label for="customer_type">客户类型</label>
                <select name="customer_type" id="customer_type" class="form-control">
                    <option value="retail" <?php echo $isEdit && $editData['customer_type'] == 'retail' ? 'selected' : ''; ?>>零售客户</option>
                    <option value="wholesale" <?php echo $isEdit && $editData['customer_type'] == 'wholesale' ? 'selected' : ''; ?>>批发客户</option>
                </select>
            </div>
            <div class="form-group col-md-4">
                <label for="credit_limit">信用额度</label>
                <input type="number" name="credit_limit" id="credit_limit" class="form-control" step="0.01" min="0"
                    value="<?php echo $isEdit ? $editData['credit_limit'] : '0'; ?>">
            </div>
            <div class="form-group col-md-4">
                <label for="account_period">账期(天)</label>
                <input type="number" name="account_period" id="account_period" class="form-control" min="0"
                    value="<?php echo $isEdit ? $editData['account_period'] : '0'; ?>">
            </div>
        </div>

        <div class="form-group">
            <button type="submit" class="btn btn-primary">
                <?php echo $isEdit ? '更新客户' : '添加客户'; ?>
            </button>
            <a href="index.php?page=customer" class="btn btn-secondary">取消</a>
        </div>
    </form>
</div>

<!-- 客户列表 -->
<div class="data-wrapper">
    <h4 class="data-title">客户列表 (<?php echo count($customers); ?>条记录)</h4>

    <table class="data-table">
        <thead>
            <tr>
                <th>ID</th>
                <th>客户名称</th>
                <th>联系人</th>
                <th>联系电话</th>
                <th>客户类型</th>
                <th>信用额度</th>
                <th>账期(天)</th>
                <th>创建时间</th>
                <th>操作</th>
            </tr>
        </thead>
        <tbody>
            <?php if (count($customers) > 0): ?>
                <?php foreach ($customers as $customer): ?>
                    <tr>
                        <td><?php echo $customer['customer_id']; ?></td>
                        <td><?php echo htmlspecialchars($customer['customer_name']); ?></td>
                        <td><?php echo htmlspecialchars($customer['contact_person']); ?></td>
                        <td><?php echo htmlspecialchars($customer['phone']); ?></td>
                        <td><?php echo $customer['customer_type'] == 'retail' ? '零售客户' : '批发客户'; ?></td>
                        <td><?php echo number_format($customer['credit_limit'], 2); ?></td>
                        <td><?php echo $customer['account_period']; ?></td>
                        <td><?php echo $customer['created_at']; ?></td>
                        <td>
                            <a href="index.php?page=customer&action=edit&id=<?php echo $customer['customer_id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                            <a href="javascript:void(0);" onclick="confirmDelete(<?php echo $customer['customer_id']; ?>, '<?php echo htmlspecialchars($customer['customer_name']); ?>')" class="btn btn-sm btn-danger">删除</a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="9" class="text-center">暂无客户数据</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>

    <!-- 分页控件 -->
    <?php if ($totalPages > 1): ?>
        <div class="pagination">
            <?php if ($page > 1): ?>
                <a href="index.php?page=customer&listpage=1&search=<?php echo urlencode($search); ?>&type=<?php echo urlencode($type); ?>" class="pagination-item">首页</a>
                <a href="index.php?page=customer&listpage=<?php echo $page - 1; ?>&search=<?php echo urlencode($search); ?>&type=<?php echo urlencode($type); ?>" class="pagination-item">上一页</a>
            <?php endif; ?>

            <?php
            $startPage = max(1, $page - 2);
            $endPage = min($totalPages, $page + 2);

            for ($i = $startPage; $i <= $endPage; $i++):
            ?>
                <a href="index.php?page=customer&listpage=<?php echo $i; ?>&search=<?php echo urlencode($search); ?>&type=<?php echo urlencode($type); ?>" class="pagination-item <?php echo $i == $page ? 'active' : ''; ?>"><?php echo $i; ?></a>
            <?php endfor; ?>

            <?php if ($page < $totalPages): ?>
                <a href="index.php?page=customer&listpage=<?php echo $page + 1; ?>&search=<?php echo urlencode($search); ?>&type=<?php echo urlencode($type); ?>" class="pagination-item">下一页</a>
                <a href="index.php?page=customer&listpage=<?php echo $totalPages; ?>&search=<?php echo urlencode($search); ?>&type=<?php echo urlencode($type); ?>" class="pagination-item">末页</a>
            <?php endif; ?>
        </div>
    <?php endif; ?>
</div>

<script>
    function confirmDelete(id, name) {
        if (confirm('确定要删除客户 "' + name + '" 吗？此操作不可恢复！')) {
            window.location.href = 'index.php?page=customer&action=delete&id=' + id;
        }
    }

    // 添加表单显示/隐藏功能
    document.addEventListener('DOMContentLoaded', function() {
        const btnAddCustomer = document.getElementById('btnAddCustomer');
        const btnCloseForm = document.getElementById('btnCloseForm');
        const customerFormContainer = document.getElementById('customerFormContainer');

        if (btnAddCustomer) {
            btnAddCustomer.addEventListener('click', function() {
                customerFormContainer.style.display = 'block';
                document.getElementById('customer_name').focus();
            });
        }

        if (btnCloseForm) {
            btnCloseForm.addEventListener('click', function() {
                customerFormContainer.style.display = 'none';
            });
        }

        // 如果有成功消息，确保表单隐藏，只显示列表
        const messageElement = document.querySelector('.alert-success');
        if (messageElement && !<?php echo $isEdit ? 'true' : 'false'; ?>) {
            customerFormContainer.style.display = 'none';
        }

        // 确保客户列表始终显示
        const dataWrapper = document.querySelector('.data-wrapper');
        if (dataWrapper) {
            dataWrapper.style.display = 'block';
        }
    });
</script>

<style>
    .form-wrapper {
        background-color: #fff;
        padding: 20px;
        border-radius: 5px;
        margin-bottom: 20px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
    }

    .form-header {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin-bottom: 20px;
        padding-bottom: 10px;
        border-bottom: 1px solid #eee;
    }

    .form-header h4 {
        margin: 0;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -15px;
        margin-left: -15px;
    }

    .form-group {
        margin-bottom: 1rem;
    }

    .col-md-4 {
        flex: 0 0 33.333333%;
        max-width: 33.333333%;
        padding-right: 15px;
        padding-left: 15px;
    }

    .col-md-6 {
        flex: 0 0 50%;
        max-width: 50%;
        padding-right: 15px;
        padding-left: 15px;
    }

    .col-md-12 {
        flex: 0 0 100%;
        max-width: 100%;
        padding-right: 15px;
        padding-left: 15px;
    }

    .required {
        color: red;
    }

    .form-control {
        display: block;
        width: 100%;
        padding: 0.375rem 0.75rem;
        font-size: 1rem;
        line-height: 1.5;
        color: #495057;
        background-color: #fff;
        background-clip: padding-box;
        border: 1px solid #ced4da;
        border-radius: 0.25rem;
        transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
    }

    .data-wrapper {
        background-color: #fff;
        padding: 20px;
        border-radius: 5px;
        margin-bottom: 20px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
    }

    .data-title {
        margin-bottom: 15px;
        color: #333;
    }

    .alert {
        padding: 15px;
        margin-bottom: 20px;
        border: 1px solid transparent;
        border-radius: 4px;
    }

    .alert-success {
        color: #155724;
        background-color: #d4edda;
        border-color: #c3e6cb;
    }

    .alert-error {
        color: #721c24;
        background-color: #f8d7da;
        border-color: #f5c6cb;
    }
</style>