<?php
// 防止直接访问
defined('IN_SYSTEM') || die('禁止访问');

// 添加调试信息
error_log("正在加载delivery_form.php, action=" . $action);

// 获取操作类型
$action = isset($_GET['action']) ? $_GET['action'] : 'add';
$isEdit = $action === 'edit';
$deliveryId = isset($_GET['id']) ? (int) $_GET['id'] : 0;

// 检查是否是提交成功后的访问
$isSuccess = isset($_GET['success']) && $_GET['success'] == 1;
$successMessage = '';
if ($isSuccess) {
    if ($isEdit) {
        $successMessage = '销售出库单更新成功';
    } else {
        $successMessage = '销售出库单创建成功';
    }
}

// 记录表单参数
error_log("Delivery form参数: action=$action, isEdit=$isEdit, deliveryId=$deliveryId, isSuccess=$isSuccess");

// 获取表单数据
if (!isset($delivery)) {
    $delivery = [];
}
if (!isset($deliveryItems)) {
    $deliveryItems = [];
}

// 如果是编辑模式，获取出库单信息
if ($isEdit && empty($delivery)) {
    $sql = "SELECT * FROM sales_deliveries WHERE delivery_id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $deliveryId);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result && $row = $result->fetch_assoc()) {
        $delivery = $row;

        // 获取出库单明细
        $sql = "SELECT di.*, p.product_name, p.unit, p.barcode 
                FROM sales_delivery_items di 
                JOIN products p ON di.product_id = p.product_id 
                WHERE di.delivery_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $deliveryId);
        $stmt->execute();
        $result = $stmt->get_result();

        while ($row = $result->fetch_assoc()) {
            $deliveryItems[] = $row;
        }
    }
}

// 获取客户列表
$customerSql = "SELECT customer_id, customer_name FROM customers ORDER BY customer_name";
$customerResult = $conn->query($customerSql);
$customers = [];
while ($customerResult && $row = $customerResult->fetch_assoc()) {
    $customers[] = $row;
}

// 获取仓库列表
$warehouseSql = "SELECT warehouse_id, warehouse_name FROM warehouses ORDER BY warehouse_name";
$warehouseResult = $conn->query($warehouseSql);
$warehouses = [];
while ($warehouseResult && $row = $warehouseResult->fetch_assoc()) {
    $warehouses[] = $row;
}

// 获取销售订单列表
$orderSql = "SELECT o.order_id, o.order_number, o.customer_id, c.customer_name 
            FROM sales_orders o 
            LEFT JOIN customers c ON o.customer_id = c.customer_id 
            ORDER BY o.order_id DESC";
$orderResult = $conn->query($orderSql);
$orders = [];
while ($orderResult && $row = $orderResult->fetch_assoc()) {
    $orders[] = $row;
}

// 获取销售发票列表
$invoiceSql = "SELECT i.invoice_id, i.invoice_number, i.customer_id, c.customer_name 
              FROM sales_invoices i 
              LEFT JOIN customers c ON i.customer_id = c.customer_id 
              ORDER BY i.invoice_id DESC";
$invoiceResult = $conn->query($invoiceSql);
$invoices = [];
while ($invoiceResult && $row = $invoiceResult->fetch_assoc()) {
    $invoices[] = $row;
}

// 获取商品列表
$productSql = "SELECT product_id, product_name, unit_price, unit FROM products ORDER BY product_name";
$productResult = $conn->query($productSql);
$products = [];
while ($productResult && $row = $productResult->fetch_assoc()) {
    $products[] = $row;
}
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<?php if (!empty($successMessage)): ?>
    <div class="alert alert-success"><?php echo $successMessage; ?></div>
<?php endif; ?>

<div class="module-tools">
    <div class="tool-left">
        <a href="index.php?page=delivery" class="btn btn-secondary">返回列表</a>
    </div>
</div>

<div class="data-wrapper">
    <h4 class="data-title"><?php echo $isEdit ? '编辑销售出库单' : '创建销售出库单'; ?></h4>

    <form id="deliveryForm" action="index.php?page=delivery&action=<?php echo $isEdit ? 'edit&id=' . $deliveryId : 'add'; ?>" method="post" class="form-horizontal">
        <!-- 确保delivery_id字段存在 -->
        <?php if ($isEdit): ?>
            <input type="hidden" name="delivery_id" value="<?php echo $deliveryId; ?>">
        <?php endif; ?>

        <!-- 添加必要的隐藏字段 -->
        <input type="hidden" name="delivery_number" value="<?php echo isset($delivery['delivery_number']) ? $delivery['delivery_number'] : generateDeliveryNumber(); ?>">

        <div class="form-group">
            <label class="form-label">出库状态</label>
            <div class="form-input">
                <select name="delivery_status" class="form-control" required>
                    <option value="pending" <?php echo (isset($delivery['delivery_status']) && $delivery['delivery_status'] == 'pending') ? 'selected' : ''; ?>>待处理</option>
                    <option value="in_progress" <?php echo (isset($delivery['delivery_status']) && $delivery['delivery_status'] == 'in_progress') ? 'selected' : ''; ?>>进行中</option>
                    <option value="completed" <?php echo (isset($delivery['delivery_status']) && $delivery['delivery_status'] == 'completed') ? 'selected' : ''; ?>>已完成</option>
                    <option value="cancelled" <?php echo (isset($delivery['delivery_status']) && $delivery['delivery_status'] == 'cancelled') ? 'selected' : ''; ?>>已取消</option>
                </select>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">关联订单</label>
            <div class="form-input">
                <select id="order_id" name="order_id" class="form-control">
                    <option value="">-- 选择订单 --</option>
                    <?php foreach ($orders as $order): ?>
                        <option value="<?php echo $order['order_id']; ?>" data-customer="<?php echo $order['customer_id']; ?>" <?php echo (isset($delivery['order_id']) && $delivery['order_id'] == $order['order_id']) ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($order['order_number']); ?> (<?php echo htmlspecialchars($order['customer_name']); ?>)
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">关联发票</label>
            <div class="form-input">
                <select id="invoice_id" name="invoice_id" class="form-control">
                    <option value="">-- 选择发票 --</option>
                    <?php foreach ($invoices as $invoice): ?>
                        <option value="<?php echo $invoice['invoice_id']; ?>" data-customer="<?php echo $invoice['customer_id']; ?>" <?php echo (isset($delivery['invoice_id']) && $delivery['invoice_id'] == $invoice['invoice_id']) ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($invoice['invoice_number']); ?> (<?php echo htmlspecialchars($invoice['customer_name']); ?>)
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">客户 <span class="required">*</span></label>
            <div class="form-input">
                <select id="customer_id" name="customer_id" class="form-control" required>
                    <option value="">-- 请选择客户 --</option>
                    <?php foreach ($customers as $customer): ?>
                        <option value="<?php echo $customer['customer_id']; ?>" <?php echo (isset($delivery['customer_id']) && $delivery['customer_id'] == $customer['customer_id']) ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($customer['customer_name']); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">仓库 <span class="required">*</span></label>
            <div class="form-input">
                <select id="warehouse_id" name="warehouse_id" class="form-control" required>
                    <option value="">-- 请选择仓库 --</option>
                    <?php foreach ($warehouses as $warehouse): ?>
                        <option value="<?php echo $warehouse['warehouse_id']; ?>" <?php echo (isset($delivery['warehouse_id']) && $delivery['warehouse_id'] == $warehouse['warehouse_id']) ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($warehouse['warehouse_name']); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">出库日期 <span class="required">*</span></label>
            <div class="form-input">
                <input type="date" name="delivery_date" class="form-control" value="<?php echo isset($delivery['delivery_date']) ? $delivery['delivery_date'] : date('Y-m-d'); ?>" required>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">配送地址</label>
            <div class="form-input">
                <input type="text" name="shipping_address" class="form-control" value="<?php echo htmlspecialchars($delivery['shipping_address'] ?? ''); ?>">
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">联系人</label>
            <div class="form-input">
                <input type="text" name="contact_person" class="form-control" value="<?php echo htmlspecialchars($delivery['contact_person'] ?? ''); ?>">
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">联系电话</label>
            <div class="form-input">
                <input type="text" name="contact_phone" class="form-control" value="<?php echo htmlspecialchars($delivery['contact_phone'] ?? ''); ?>">
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">备注</label>
            <div class="form-input">
                <textarea name="remark" class="form-control" rows="3"><?php echo htmlspecialchars($delivery['remark'] ?? ''); ?></textarea>
            </div>
        </div>

        <div class="form-group">
            <label class="form-label">出库商品明细 <span class="required">*</span></label>
            <div class="form-input">
                <div class="table-responsive">
                    <table class="data-table" id="deliveryItemsTable">
                        <thead>
                            <tr>
                                <th class="product-column">商品 <span class="required">*</span></th>
                                <th class="batch-column">批次 <span class="required">*</span></th>
                                <th class="unit-column">单位</th>
                                <th class="quantity-column">数量 <span class="required">*</span></th>
                                <th class="price-column">单价(元) <span class="required">*</span></th>
                                <th class="discount-column">折扣(%)</th>
                                <th class="subtotal-column">小计(元)</th>
                                <th class="remark-column">备注</th>
                                <th class="action-column">操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($deliveryItems) > 0): ?>
                                <?php foreach ($deliveryItems as $index => $item): ?>
                                    <tr>
                                        <td class="product-column">
                                            <div class="product-select-container">
                                                <select name="items[<?php echo $index; ?>][product_id]" class="form-control product-select" data-row-index="<?php echo $index; ?>" required>
                                                    <option value="">请选择商品</option>
                                                    <?php foreach ($products as $product): ?>
                                                        <option value="<?php echo $product['product_id']; ?>"
                                                            data-price="<?php echo $product['unit_price']; ?>"
                                                            data-unit="<?php echo $product['unit']; ?>"
                                                            <?php echo $item['product_id'] == $product['product_id'] ? 'selected' : ''; ?>>
                                                            <?php echo htmlspecialchars($product['product_name']); ?>
                                                        </option>
                                                    <?php endforeach; ?>
                                                </select>
                                            </div>
                                        </td>
                                        <td class="batch-column">
                                            <select name="items[<?php echo $index; ?>][batch_id]" class="form-control batch-select" data-preselected-id="<?php echo $item['batch_id']; ?>" required>
                                                <option value="">请先选择商品和仓库</option>
                                            </select>
                                        </td>
                                        <td class="unit-column">
                                            <input type="text" name="items[<?php echo $index; ?>][unit]" class="form-control product-unit" value="<?php echo htmlspecialchars($item['unit'] ?? ''); ?>" readonly>
                                        </td>
                                        <td class="quantity-column">
                                            <input type="number" name="items[<?php echo $index; ?>][quantity]" class="form-control quantity" value="<?php echo $item['quantity']; ?>" min="1" required>
                                        </td>
                                        <td class="price-column">
                                            <input type="number" name="items[<?php echo $index; ?>][unit_price]" class="form-control unit-price" step="0.01" value="<?php echo $item['unit_price']; ?>" required>
                                        </td>
                                        <td class="discount-column">
                                            <input type="number" name="items[<?php echo $index; ?>][discount_rate]" class="form-control discount-rate" value="<?php echo $item['discount_rate'] ?? 0; ?>" min="0" max="100" step="0.01">
                                        </td>
                                        <td class="subtotal-column">
                                            <input type="text" class="form-control subtotal" value="<?php echo number_format($item['item_amount'], 2); ?>" readonly>
                                            <input type="hidden" name="items[<?php echo $index; ?>][item_amount]" class="item-amount" value="<?php echo $item['item_amount']; ?>">
                                        </td>
                                        <td class="remark-column">
                                            <input type="text" name="items[<?php echo $index; ?>][remark]" class="form-control" value="<?php echo htmlspecialchars($item['remark'] ?? ''); ?>">
                                        </td>
                                        <td class="action-column">
                                            <button type="button" class="btn btn-sm btn-danger remove-item">删除</button>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td class="product-column">
                                        <div class="product-select-container">
                                            <select name="items[0][product_id]" class="form-control product-select" required>
                                                <option value="">请选择商品</option>
                                                <?php foreach ($products as $product): ?>
                                                    <option value="<?php echo $product['product_id']; ?>"
                                                        data-price="<?php echo $product['unit_price']; ?>"
                                                        data-unit="<?php echo $product['unit']; ?>">
                                                        <?php echo htmlspecialchars($product['product_name']); ?>
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                        </div>
                                    </td>
                                    <td class="batch-column">
                                        <select name="items[0][batch_id]" class="form-control batch-select" required>
                                            <option value="">请先选择商品</option>
                                        </select>
                                    </td>
                                    <td class="unit-column">
                                        <input type="text" name="items[0][unit]" class="form-control product-unit" readonly>
                                    </td>
                                    <td class="quantity-column">
                                        <input type="number" name="items[0][quantity]" class="form-control quantity" min="1" value="1" required>
                                    </td>
                                    <td class="price-column">
                                        <input type="number" name="items[0][unit_price]" class="form-control unit-price" step="0.01" required>
                                    </td>
                                    <td class="discount-column">
                                        <input type="number" name="items[0][discount_rate]" class="form-control discount-rate" value="0" min="0" max="100" step="0.01">
                                    </td>
                                    <td class="subtotal-column">
                                        <input type="text" class="form-control subtotal" readonly>
                                        <input type="hidden" name="items[0][item_amount]" class="item-amount" value="0">
                                    </td>
                                    <td class="remark-column">
                                        <input type="text" name="items[0][remark]" class="form-control">
                                    </td>
                                    <td class="action-column">
                                        <button type="button" class="btn btn-sm btn-danger remove-item">删除</button>
                                    </td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                        <tfoot>
                            <tr>
                                <td colspan="6" class="text-right"><strong>总计：</strong></td>
                                <td>
                                    <input type="text" id="totalAmount" name="total_amount" class="form-control" readonly>
                                </td>
                                <td colspan="2">
                                    <button type="button" class="btn btn-sm btn-primary" id="addItemBtn">添加商品</button>
                                </td>
                            </tr>
                        </tfoot>
                    </table>
                </div>
            </div>
        </div>

        <div class="form-group">
            <div class="form-input">
                <button type="submit" class="btn btn-primary"><?php echo $isEdit ? '保存修改' : '创建出库单'; ?></button>
                <a href="index.php?page=delivery" class="btn btn-secondary">取消</a>
            </div>
        </div>
    </form>
</div>

<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />

<script>
    $(document).ready(function() {
        // 全局变量保存成功的批次加载URL
        window.successfulBatchUrl = null;

        // 初始化Select2组件
        initializeSelect2();

        // 计算总价
        calculateTotal();

        // 为所有行绑定事件处理器
        $('#deliveryItemsTable tbody tr').each(function() {
            bindEventHandlers($(this));
        });

        // 在编辑模式下，确保批次信息被加载
        <?php if ($isEdit && !empty($deliveryItems)): ?>
            // 在DOM完全加载后执行
            setTimeout(function() {
                // 遍历每一行
                <?php foreach ($deliveryItems as $index => $item): ?>
                    var currentRow<?php echo $index; ?> = $('#deliveryItemsTable tbody tr').eq(<?php echo $index; ?>);
                    var batchSelect<?php echo $index; ?> = currentRow<?php echo $index; ?>.find('.batch-select');

                    // 设置预选批次ID
                    batchSelect<?php echo $index; ?>.data('preselected-id', '<?php echo $item['batch_id']; ?>');

                    // 手动加载批次
                    var row<?php echo $index; ?> = currentRow<?php echo $index; ?>;
                    loadBatches(row<?php echo $index; ?>);
                <?php endforeach; ?>
            }, 500);
        <?php endif; ?>

        // 关联订单和客户的联动
        $('#order_id').change(function() {
            var selectedOption = $(this).find('option:selected');
            if (selectedOption.val()) {
                var customerId = selectedOption.data('customer');
                if (customerId) {
                    $('#customer_id').val(customerId).trigger('change');
                }
            }
        });

        // 关联发票和客户的联动
        $('#invoice_id').change(function() {
            var selectedOption = $(this).find('option:selected');
            if (selectedOption.val()) {
                var customerId = selectedOption.data('customer');
                if (customerId) {
                    $('#customer_id').val(customerId).trigger('change');
                }
            }
        });

        // 添加商品行
        $('#addItemBtn').click(function() {
            var rowIndex = $('#deliveryItemsTable tbody tr').length;
            var newRow = `
            <tr>
                <td class="product-column">
                    <div class="product-select-container">
                        <select name="items[${rowIndex}][product_id]" class="form-control product-select" required>
                            <option value="">请选择商品</option>
                            <?php foreach ($products as $product): ?>
                                <option value="<?php echo $product['product_id']; ?>"
                                    data-price="<?php echo $product['unit_price']; ?>"
                                    data-unit="<?php echo $product['unit']; ?>">
                                    <?php echo htmlspecialchars($product['product_name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                </td>
                <td class="batch-column">
                    <select name="items[${rowIndex}][batch_id]" class="form-control batch-select" required>
                        <option value="">请先选择商品</option>
                    </select>
                </td>
                <td class="unit-column">
                    <input type="text" name="items[${rowIndex}][unit]" class="form-control product-unit" readonly>
                </td>
                <td class="quantity-column">
                    <input type="number" name="items[${rowIndex}][quantity]" class="form-control quantity" min="1" value="1" required>
                </td>
                <td class="price-column">
                    <input type="number" name="items[${rowIndex}][unit_price]" class="form-control unit-price" step="0.01" required>
                </td>
                <td class="discount-column">
                    <input type="number" name="items[${rowIndex}][discount_rate]" class="form-control discount-rate" value="0" min="0" max="100" step="0.01">
                </td>
                <td class="subtotal-column">
                    <input type="text" class="form-control subtotal" readonly>
                    <input type="hidden" name="items[${rowIndex}][item_amount]" class="item-amount" value="0">
                </td>
                <td class="remark-column">
                    <input type="text" name="items[${rowIndex}][remark]" class="form-control">
                </td>
                <td class="action-column">
                    <button type="button" class="btn btn-sm btn-danger remove-item">删除</button>
                </td>
            </tr>
        `;

            $('#deliveryItemsTable tbody').append(newRow);

            // 初始化新添加行的Select2
            var newRow = $('#deliveryItemsTable tbody tr:last');
            initializeRowSelect2(newRow);
            bindEventHandlers(newRow);
        });

        // 删除商品行
        $(document).on('click', '.remove-item', function() {
            var tbody = $('#deliveryItemsTable tbody');
            if (tbody.children('tr').length > 1) {
                $(this).closest('tr').remove();
                calculateTotal();
            } else {
                alert('至少需要一行商品明细');
            }
        });

        // 商品选择变更时，更新单位和单价
        $(document).on('change', '.product-select', function() {
            var row = $(this).closest('tr');
            var selectedOption = $(this).find('option:selected');

            if (selectedOption.val()) {
                // 更新单位
                var unit = selectedOption.data('unit');
                row.find('.product-unit').val(unit || '');

                // 更新单价
                var price = selectedOption.data('price');
                row.find('.unit-price').val(price || '');

                // 更新批次下拉框
                loadBatches(row);

                // 更新小计
                calculateSubtotal(row);
            } else {
                // 清空相关字段
                row.find('.product-unit').val('');
                row.find('.unit-price').val('');
                row.find('.batch-select').html('<option value="">请先选择商品</option>');
                row.find('.subtotal').val('');
                row.find('.item-amount').val('0');
                calculateTotal();
            }
        });

        // 仓库选择变更时，更新所有批次
        $('#warehouse_id').change(function() {
            $('#deliveryItemsTable tbody tr').each(function() {
                var row = $(this);
                var productSelect = row.find('.product-select');

                if (productSelect.val()) {
                    loadBatches(row);
                }
            });
        });

        // 数量、单价或折扣变更时，更新小计
        $(document).on('input', '.quantity, .unit-price, .discount-rate', function() {
            var row = $(this).closest('tr');
            calculateSubtotal(row);
        });

        // 表单提交前验证
        $('#deliveryForm').submit(function(e) {
            try {
                // 检查客户选择
                if (!$('#customer_id').val()) {
                    alert('请选择客户');
                    e.preventDefault();
                    return false;
                }

                // 检查仓库选择
                if (!$('#warehouse_id').val()) {
                    alert('请选择仓库');
                    e.preventDefault();
                    return false;
                }

                // 检查至少有一个商品行
                if ($('#deliveryItemsTable tbody tr').length === 0) {
                    alert('请至少添加一个商品');
                    e.preventDefault();
                    return false;
                }

                // 验证每一行商品明细
                var isValid = true;
                $('#deliveryItemsTable tbody tr').each(function() {
                    var row = $(this);
                    var productSelect = row.find('.product-select');
                    var batchSelect = row.find('.batch-select');
                    var quantityInput = row.find('.quantity');
                    var priceInput = row.find('.unit-price');

                    if (!productSelect.val()) {
                        alert('请选择商品');
                        productSelect.focus();
                        isValid = false;
                        return false;
                    }

                    if (!batchSelect.val()) {
                        alert('请选择批次');
                        batchSelect.focus();
                        isValid = false;
                        return false;
                    }

                    if (!quantityInput.val() || parseInt(quantityInput.val()) <= 0) {
                        alert('请输入有效的数量');
                        quantityInput.focus();
                        isValid = false;
                        return false;
                    }

                    if (!priceInput.val() || parseFloat(priceInput.val()) <= 0) {
                        alert('请输入有效的单价');
                        priceInput.focus();
                        isValid = false;
                        return false;
                    }
                });

                if (!isValid) {
                    e.preventDefault();
                    return false;
                }

                // 保存总金额到隐藏字段
                var total = 0;
                $('.subtotal').each(function() {
                    total += parseFloat($(this).val()) || 0;
                });
                $('<input>').attr({
                    type: 'hidden',
                    name: 'total_amount',
                    value: total.toFixed(2)
                }).appendTo('#deliveryForm');

                return true;
            } catch (error) {
                console.error('表单验证错误:', error);
                alert('表单验证发生错误，请检查输入');
                e.preventDefault();
                return false;
            }
        });

        // 初始化Select2组件
        function initializeSelect2() {
            $('.product-select').select2({
                placeholder: '请选择商品',
                allowClear: true,
                width: '100%'
            });

            $('.batch-select').select2({
                placeholder: '请选择批次',
                allowClear: true,
                width: '100%'
            });
        }

        // 为新行初始化Select2
        function initializeRowSelect2(row) {
            row.find('.product-select').select2({
                placeholder: '请选择商品',
                allowClear: true,
                width: '100%'
            });

            row.find('.batch-select').select2({
                placeholder: '请选择批次',
                allowClear: true,
                width: '100%'
            });
        }

        // 绑定行事件
        function bindEventHandlers(row) {
            // 初始化 Select2
            initializeRowSelect2(row);

            // 初始化小计
            calculateSubtotal(row);

            // 如果已有商品和仓库选择，加载批次
            var productId = row.find('.product-select').val();
            if (productId && $('#warehouse_id').val()) {
                loadBatches(row);
            }
        }

        // 加载批次
        function loadBatches(row) {
            var productSelect = row.find('.product-select');
            var batchSelect = row.find('.batch-select');
            var productId = productSelect.val();
            var warehouseId = $('#warehouse_id').val();
            var batchId = batchSelect.data('preselected-id') || '';

            if (!productId || !warehouseId) {
                batchSelect.html('<option value="">请先选择商品和仓库</option>');
                batchSelect.prop('disabled', true);
                return;
            }

            console.log('加载批次 - 商品ID:', productId, '仓库ID:', warehouseId, '批次ID:', batchId);
            batchSelect.html('<option value="">加载中...</option>');
            batchSelect.prop('disabled', true);

            // 定义可能的AJAX URL路径
            var urls = [
                '../../ajax/get_batches.php', // 使用项目根目录下的批次加载脚本（与发票表单相同）
                'index.php?module=sales&page=ajax/get_batches', // 通过index.php路由
                '../ajax/get_batches.php', // 相对路径尝试
                'modules/sales/ajax/get_batches.php' // 绝对路径（相对于网站根目录）
            ];

            // 如果之前有成功的URL，将其移到数组第一位
            if (window.successfulBatchUrl && urls.indexOf(window.successfulBatchUrl) > 0) {
                console.log('使用之前成功的URL:', window.successfulBatchUrl);
                urls = [window.successfulBatchUrl].concat(
                    urls.filter(function(url) {
                        return url !== window.successfulBatchUrl;
                    })
                );
            }

            // 尝试第一个URL
            tryLoadBatches(0);

            // 递归尝试不同的URL
            function tryLoadBatches(urlIndex) {
                if (urlIndex >= urls.length) {
                    console.error('所有批次加载URL都失败');
                    batchSelect.html('<option value="">加载失败，请重试</option>');
                    batchSelect.prop('disabled', false);
                    return;
                }

                var currentUrl = urls[urlIndex];
                console.log('尝试从URL加载批次:', currentUrl);

                $.ajax({
                    url: currentUrl,
                    type: 'GET',
                    dataType: 'json',
                    data: {
                        product_id: productId,
                        warehouse_id: warehouseId,
                        batch_id: batchId
                    },
                    success: function(response) {
                        console.log('批次加载响应:', response);

                        batchSelect.empty();
                        batchSelect.append('<option value="">请选择批次</option>');

                        // 检查返回格式 - 处理两种可能的API格式
                        var batches = [];
                        if (Array.isArray(response)) {
                            // 这是项目根目录ajax/get_batches.php返回的格式
                            batches = response;
                            console.log('检测到数组格式响应，直接使用');
                        } else if (response && response.success && Array.isArray(response.batches)) {
                            // 这是模块内ajax/get_batches.php返回的格式
                            batches = response.batches;
                            console.log('检测到对象格式响应，提取batches数组');
                        }

                        if (batches.length > 0) {
                            $.each(batches, function(i, batch) {
                                // 批次文本显示逻辑
                                var displayText = batch.batch_number;

                                // 添加生产日期信息（如果有）
                                if (batch.production_date) {
                                    displayText += ' (生产日期:' + batch.production_date + ')';
                                }

                                // 添加库存数量信息（如果有）
                                if (batch.quantity !== undefined) {
                                    displayText += ' [库存:' + batch.quantity + ']';
                                } else if (batch.available_quantity !== undefined) {
                                    displayText += ' [库存:' + batch.available_quantity + ']';
                                }

                                var option = $('<option></option>')
                                    .val(batch.batch_id)
                                    .text(displayText);

                                if (batch.batch_id == batchId) {
                                    option.prop('selected', true);
                                }

                                batchSelect.append(option);
                            });

                            // 记录成功的URL以便将来使用
                            console.log('成功的批次加载URL:', currentUrl);
                            console.log('%c批次加载成功！', 'color: green; font-weight: bold;');

                            // 保存成功的URL供将来使用
                            window.successfulBatchUrl = currentUrl;

                            // 如果不是第一个URL，弹出提示告知用户
                            if (urlIndex > 0) {
                                console.log('%c注意：默认URL失败，使用了备用URL', 'color: orange; font-weight: bold;');
                            }
                        } else {
                            batchSelect.append('<option value="">没有可用批次</option>');
                            console.warn('未找到批次，响应:', response);
                        }

                        batchSelect.prop('disabled', false);

                        // 如果有预选批次ID，设置选中
                        if (batchId) {
                            batchSelect.val(batchId).trigger('change');
                        }
                    },
                    error: function(xhr, status, error) {
                        console.error('URL ' + currentUrl + ' 加载批次失败:', status, error);
                        // 尝试下一个URL
                        tryLoadBatches(urlIndex + 1);
                    }
                });
            }
        }

        // 计算小计
        function calculateSubtotal(row) {
            var quantity = parseFloat(row.find('.quantity').val()) || 0;
            var unitPrice = parseFloat(row.find('.unit-price').val()) || 0;
            var discountRate = parseFloat(row.find('.discount-rate').val()) || 0;

            var subtotal = quantity * unitPrice * (1 - discountRate / 100);

            row.find('.subtotal').val(subtotal.toFixed(2));
            row.find('.item-amount').val(subtotal.toFixed(2));

            calculateTotal();
        }

        // 计算总计
        function calculateTotal() {
            var total = 0;
            $('.subtotal').each(function() {
                var value = $(this).val();
                total += parseFloat(value) || 0;
            });

            $('#totalAmount').val(total.toFixed(2));
        }
    });
</script>

<style>
    /* 添加自定义样式 */
    .product-select-container {
        position: relative;
        width: 100%;
    }

    .data-table th,
    .data-table td {
        padding: 8px;
        vertical-align: middle;
    }

    .product-column {
        min-width: 200px;
    }

    .batch-column {
        min-width: 180px;
    }

    .unit-column {
        width: 80px;
    }

    .quantity-column {
        width: 100px;
    }

    .price-column {
        width: 120px;
    }

    .discount-column {
        width: 100px;
    }

    .subtotal-column {
        width: 120px;
    }

    .remark-column {
        width: 150px;
    }

    .action-column {
        width: 80px;
        text-align: center;
    }

    .select2-container {
        width: 100% !important;
    }
</style>