<?php
// 防止直接访问
defined('IN_SYSTEM') || die('禁止访问');

// 获取客户列表（用于搜索筛选）
$customerSql = "SELECT customer_id, customer_name FROM customers ORDER BY customer_name";
$customerResult = $conn->query($customerSql);
$customers = [];
while ($customerResult && $row = $customerResult->fetch_assoc()) {
    $customers[] = $row;
}
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<div class="module-tools">
    <div class="tool-left">
        <a href="index.php?page=order&action=add" class="btn btn-primary">创建销售订单</a>
    </div>
    <div class="tool-right">
        <form action="index.php" method="get" class="search-form">
            <input type="hidden" name="page" value="order">
            <div class="search-group">
                <input type="text" name="search" class="search-input" placeholder="搜索订单号或客户" value="<?php echo htmlspecialchars($search); ?>">
            </div>
            <div class="search-group">
                <select name="status" class="search-input">
                    <option value="">所有状态</option>
                    <option value="pending" <?php echo $status == 'pending' ? 'selected' : ''; ?>>待处理</option>
                    <option value="processing" <?php echo $status == 'processing' ? 'selected' : ''; ?>>处理中</option>
                    <option value="shipped" <?php echo $status == 'shipped' ? 'selected' : ''; ?>>已发货</option>
                    <option value="delivered" <?php echo $status == 'delivered' ? 'selected' : ''; ?>>已送达</option>
                    <option value="completed" <?php echo $status == 'completed' ? 'selected' : ''; ?>>已完成</option>
                    <option value="cancelled" <?php echo $status == 'cancelled' ? 'selected' : ''; ?>>已取消</option>
                </select>
            </div>
            <div class="search-group">
                <input type="date" name="start_date" class="search-input date" placeholder="开始日期" value="<?php echo htmlspecialchars($start_date); ?>">
            </div>
            <div class="search-group">
                <input type="date" name="end_date" class="search-input date" placeholder="结束日期" value="<?php echo htmlspecialchars($end_date); ?>">
            </div>
            <button type="submit" class="btn btn-secondary">搜索</button>
            <a href="index.php?page=order" class="btn btn-secondary">重置</a>
        </form>
    </div>
</div>

<!-- 订单列表 -->
<div class="data-wrapper">
    <h4 class="data-title">销售订单列表 (<?php echo $totalRecords; ?>条记录)</h4>

    <table class="data-table">
        <thead>
            <tr>
                <th>订单编号</th>
                <th>客户</th>
                <th>订单日期</th>
                <th>预计交付日期</th>
                <th>总金额(元)</th>
                <th>订单状态</th>
                <th>支付状态</th>
                <th>创建时间</th>
                <th>操作</th>
            </tr>
        </thead>
        <tbody>
            <?php if (count($orders) > 0): ?>
                <?php foreach ($orders as $order): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($order['order_number']); ?></td>
                        <td><?php echo htmlspecialchars($order['customer_name'] ?? '未知客户'); ?></td>
                        <td><?php echo $order['order_date'] ?? ''; ?></td>
                        <td><?php echo isset($order['delivery_date']) && !empty($order['delivery_date']) ? $order['delivery_date'] : '未设置'; ?></td>
                        <td class="text-right"><?php echo number_format($order['total_amount'] ?? 0, 2); ?></td>
                        <td>
                            <span class="badge badge-<?php echo getOrderStatusBadgeClass($order['order_status'] ?? 'pending'); ?>">
                                <?php echo getOrderStatusName($order['order_status'] ?? 'pending'); ?>
                            </span>
                        </td>
                        <td><?php echo getPaymentStatusName($order['payment_status'] ?? 'unpaid'); ?></td>
                        <td><?php echo $order['created_at'] ?? ''; ?></td>
                        <td>
                            <a href="index.php?page=order&action=view&id=<?php echo $order['order_id']; ?>" class="btn btn-sm btn-info">查看</a>
                            <a href="index.php?page=order&action=edit&id=<?php echo $order['order_id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                            <?php if (($order['order_status'] ?? 'pending') == 'pending'): ?>
                                <a href="javascript:void(0);" onclick="confirmDelete(<?php echo $order['order_id']; ?>, '<?php echo htmlspecialchars($order['order_number']); ?>')" class="btn btn-sm btn-danger">删除</a>
                            <?php endif; ?>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="9" class="text-center">暂无订单数据</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>

    <!-- 分页控件 -->
    <?php if ($totalPages > 1): ?>
        <div class="pagination">
            <?php if ($page > 1): ?>
                <a href="index.php?page=order&listpage=1&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item">首页</a>
                <a href="index.php?page=order&listpage=<?php echo $page - 1; ?>&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item">上一页</a>
            <?php endif; ?>

            <?php
            $startPage = max(1, $page - 2);
            $endPage = min($totalPages, $page + 2);

            for ($i = $startPage; $i <= $endPage; $i++):
            ?>
                <a href="index.php?page=order&listpage=<?php echo $i; ?>&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item <?php echo $i == $page ? 'active' : ''; ?>"><?php echo $i; ?></a>
            <?php endfor; ?>

            <?php if ($page < $totalPages): ?>
                <a href="index.php?page=order&listpage=<?php echo $page + 1; ?>&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item">下一页</a>
                <a href="index.php?page=order&listpage=<?php echo $totalPages; ?>&search=<?php echo urlencode($search); ?>&status=<?php echo urlencode($status); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>" class="pagination-item">末页</a>
            <?php endif; ?>
        </div>
    <?php endif; ?>
</div>

<script>
    // 删除订单确认
    function confirmDelete(orderId, orderNumber) {
        if (confirm('确定要删除订单 ' + orderNumber + ' 吗？此操作不可恢复！')) {
            window.location.href = 'index.php?page=order&action=delete&id=' + orderId;
        }
    }
</script>