<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 移除管理员权限限制，允许所有已登录用户访问备份功能

// 设置备份目录
$backupDir = __DIR__ . '/../../backups/';
if (!is_dir($backupDir)) {
    mkdir($backupDir, 0755, true);
}

// 初始化消息变量
$message = '';
$messageType = '';

// 处理备份和删除操作
if (isset($_POST['action'])) {
    switch ($_POST['action']) {
        case 'backup':
            // 执行数据备份
            $timestamp = date('Y-m-d_H-i-s');
            $filename = "backup_{$timestamp}.sql";
            $backupFile = $backupDir . $filename;

            // 记录操作日志
            try {
                $operationDetails = "用户 {$_SESSION['username']} 创建了数据库备份：{$filename}";
                log_operation($_SESSION['user_id'], '数据备份', $operationDetails);
            } catch (Exception $e) {
                // 记录日志失败，继续执行备份
            }

            // 执行备份命令
            try {
                // 获取数据库配置
                $host = $conn->host_info;
                $hostParts = explode(':', $host);
                $dbHost = $hostParts[0];

                // 通过连接配置获取数据库名称、用户名和密码
                $dbName = DB_NAME;
                $dbUser = DB_USER;
                $dbPass = DB_PASS;

                // 构建mysqldump命令
                $command = "mysqldump";
                if (!empty($dbUser)) {
                    $command .= " -u " . escapeshellarg($dbUser);
                }
                if (!empty($dbPass)) {
                    $command .= " -p" . escapeshellarg($dbPass);
                }
                $command .= " -h " . escapeshellarg($dbHost);
                $command .= " " . escapeshellarg($dbName);
                $command .= " > " . escapeshellarg($backupFile);

                // 执行命令
                $output = [];
                $returnVar = 0;
                exec($command, $output, $returnVar);

                if ($returnVar === 0) {
                    $message = "数据库备份成功，备份文件：{$filename}";
                    $messageType = 'success';
                } else {
                    // 如果mysqldump命令失败，尝试使用PHP的备份方法
                    // 这里只是一个简单的实现，可能需要根据实际情况修改
                    $tables = [];
                    $result = $conn->query("SHOW TABLES");
                    while ($row = $result->fetch_row()) {
                        $tables[] = $row[0];
                    }

                    $backupContent = "-- 数据库备份\n";
                    $backupContent .= "-- 创建时间: " . date("Y-m-d H:i:s") . "\n";
                    $backupContent .= "-- 服务器版本: " . $conn->server_info . "\n";
                    $backupContent .= "-- PHP 版本: " . phpversion() . "\n\n";
                    $backupContent .= "SET SQL_MODE = \"NO_AUTO_VALUE_ON_ZERO\";\n";
                    $backupContent .= "SET time_zone = \"+00:00\";\n\n";
                    $backupContent .= "-- 数据库: `{$dbName}`\n\n";
                    $backupContent .= "-- --------------------------------------------------------\n\n";

                    foreach ($tables as $table) {
                        // 获取表结构
                        $result = $conn->query("SHOW CREATE TABLE {$table}");
                        $row = $result->fetch_row();

                        // 修改表创建语句，添加IF NOT EXISTS
                        $createTable = $row[1];
                        if (strpos($createTable, 'CREATE TABLE') === 0) {
                            $createTable = str_replace('CREATE TABLE', 'CREATE TABLE IF NOT EXISTS', $createTable);
                        }

                        $backupContent .= "-- 表结构 `{$table}`\n\n";
                        $backupContent .= "{$createTable};\n\n";

                        // 获取表数据
                        $result = $conn->query("SELECT * FROM {$table}");
                        if ($result->num_rows > 0) {
                            $backupContent .= "-- 转存表中的数据 `{$table}`\n";
                            $backupContent .= "INSERT INTO `{$table}` VALUES\n";

                            $rowCount = 0;
                            while ($row = $result->fetch_array(MYSQLI_NUM)) {
                                $rowCount++;
                                $values = [];
                                foreach ($row as $value) {
                                    if (is_null($value)) {
                                        $values[] = "NULL";
                                    } else {
                                        $values[] = "'" . $conn->real_escape_string($value) . "'";
                                    }
                                }
                                $backupContent .= "(" . implode(",", $values) . ")";
                                if ($rowCount < $result->num_rows) {
                                    $backupContent .= ",\n";
                                } else {
                                    $backupContent .= ";\n\n";
                                }
                            }
                        }
                    }

                    // 写入备份文件
                    if (file_put_contents($backupFile, $backupContent)) {
                        $message = "数据库备份成功，备份文件：{$filename}";
                        $messageType = 'success';
                    } else {
                        $message = "数据库备份失败，无法写入备份文件";
                        $messageType = 'error';
                    }
                }
            } catch (Exception $e) {
                $message = "数据库备份失败：" . $e->getMessage();
                $messageType = 'error';
            }
            break;

        case 'delete':
            // 删除备份文件
            if (isset($_POST['backup_file']) && !empty($_POST['backup_file'])) {
                $backupFile = $backupDir . basename($_POST['backup_file']);

                if (file_exists($backupFile)) {
                    // 记录操作日志
                    try {
                        $operationDetails = "用户 {$_SESSION['username']} 删除了数据库备份：" . basename($_POST['backup_file']);
                        log_operation($_SESSION['user_id'], '删除备份', $operationDetails);
                    } catch (Exception $e) {
                        // 记录日志失败，继续执行删除
                    }

                    if (unlink($backupFile)) {
                        $message = "备份文件已删除";
                        $messageType = 'success';
                    } else {
                        $message = "备份文件删除失败";
                        $messageType = 'error';
                    }
                } else {
                    $message = "备份文件不存在";
                    $messageType = 'error';
                }
            } else {
                $message = "请选择要删除的备份文件";
                $messageType = 'error';
            }
            break;
    }
}

// 获取所有备份文件
$backupFiles = [];
if (is_dir($backupDir)) {
    $files = scandir($backupDir);
    foreach ($files as $file) {
        if (pathinfo($file, PATHINFO_EXTENSION) == 'sql') {
            $filePath = $backupDir . $file;
            $backupFiles[] = [
                'name' => $file,
                'size' => filesize($filePath),
                'time' => filemtime($filePath)
            ];
        }
    }

    // 按时间降序排序
    usort($backupFiles, function ($a, $b) {
        return $b['time'] - $a['time'];
    });
}
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<!-- 备份操作区域 -->
<div class="module-tools">
    <div class="tool-left">
        <button type="button" id="btnBackup" class="btn btn-primary">创建备份</button>
    </div>
</div>

<!-- 备份文件列表 -->
<div class="data-wrapper">
    <table class="data-table">
        <thead>
            <tr>
                <th>备份文件名</th>
                <th>文件大小</th>
                <th>创建时间</th>
                <th>操作</th>
            </tr>
        </thead>
        <tbody>
            <?php if (count($backupFiles) > 0): ?>
                <?php foreach ($backupFiles as $file): ?>
                    <tr>
                        <td><?php echo $file['name']; ?></td>
                        <td><?php echo formatFileSize($file['size']); ?></td>
                        <td><?php echo date('Y-m-d H:i:s', $file['time']); ?></td>
                        <td>
                            <form method="post" style="display: inline-block;">
                                <input type="hidden" name="action" value="delete">
                                <input type="hidden" name="backup_file" value="<?php echo $file['name']; ?>">
                                <button type="submit" class="btn btn-danger btn-sm" onclick="return confirm('确定要删除此备份文件吗？此操作无法撤销！')">删除</button>
                            </form>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="4" class="text-center">暂无备份文件</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>
</div>

<!-- 确认备份对话框 -->
<div id="backupModal" class="modal" style="display: none;">
    <div class="modal-content">
        <span class="close">&times;</span>
        <h2>创建数据备份</h2>
        <p>确定要创建数据库备份吗？此操作可能需要一些时间。</p>
        <form method="post">
            <input type="hidden" name="action" value="backup">
            <div class="form-actions">
                <button type="submit" class="btn btn-primary">确认备份</button>
                <button type="button" class="btn btn-secondary modal-close">取消</button>
            </div>
        </form>
    </div>
</div>

<style>
    /* 模态对话框样式 */
    .modal {
        position: fixed;
        z-index: 1000;
        left: 0;
        top: 0;
        width: 100%;
        height: 100%;
        background-color: rgba(0, 0, 0, 0.5);
    }

    .modal-content {
        background-color: #fff;
        margin: 10% auto;
        padding: 20px;
        border-radius: 5px;
        width: 50%;
        box-shadow: 0 5px 15px rgba(0, 0, 0, 0.3);
        position: relative;
    }

    .close {
        position: absolute;
        right: 10px;
        top: 5px;
        font-size: 24px;
        font-weight: bold;
        cursor: pointer;
    }

    .form-actions {
        margin-top: 20px;
        text-align: right;
    }

    .form-actions .btn {
        margin-left: 10px;
    }
</style>

<script>
    // 初始化模态对话框
    document.addEventListener('DOMContentLoaded', function() {
        var modal = document.getElementById('backupModal');
        var btn = document.getElementById('btnBackup');
        var closeSpan = modal.querySelector('.close');
        var cancelBtn = modal.querySelector('.modal-close');

        // 点击按钮打开模态对话框
        btn.onclick = function() {
            modal.style.display = 'block';
        }

        // 点击 x 关闭模态对话框
        closeSpan.onclick = function() {
            modal.style.display = 'none';
        }

        // 点击取消按钮关闭模态对话框
        cancelBtn.onclick = function() {
            modal.style.display = 'none';
        }

        // 点击模态对话框外部关闭
        window.onclick = function(event) {
            if (event.target == modal) {
                modal.style.display = 'none';
            }
        }
    });
</script>

<?php
// 文件大小格式化函数
function formatFileSize($size)
{
    $units = ['B', 'KB', 'MB', 'GB', 'TB'];
    $i = 0;
    while ($size >= 1024 && $i < count($units) - 1) {
        $size /= 1024;
        $i++;
    }
    return round($size, 2) . ' ' . $units[$i];
}
?>