<?php
// 防止直接访问此文件
defined('IN_SYSTEM') || define('IN_SYSTEM', true);

// 处理表单提交
$message = '';
$messageType = '';

// 处理删除用户
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $userId = intval($_GET['id']);
    // 不允许删除自己
    if ($userId == $_SESSION['user_id']) {
        $message = '不能删除当前登录的用户';
        $messageType = 'error';
    } else {
        $sql = "DELETE FROM users WHERE user_id = ?";
        $stmt = $conn->prepare($sql);
        if ($stmt) {
            $stmt->bind_param("i", $userId);
            if ($stmt->execute()) {
                // 记录操作日志
                $operationDetails = "用户 {$_SESSION['username']} 删除了ID为{$userId}的用户";
                log_operation($_SESSION['user_id'], '删除', $operationDetails);

                $message = '用户删除成功';
                $messageType = 'success';
            } else {
                $message = '用户删除失败: ' . $conn->error;
                $messageType = 'error';
            }
            $stmt->close();
        } else {
            $message = '系统错误: ' . $conn->error;
            $messageType = 'error';
        }
    }
}

// 处理添加/编辑用户
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // 获取表单数据
    $editId = isset($_POST['edit_id']) ? intval($_POST['edit_id']) : 0;
    $username = isset($_POST['username']) ? sanitize($_POST['username']) : '';
    $password = isset($_POST['password']) ? $_POST['password'] : '';
    $fullName = isset($_POST['full_name']) ? sanitize($_POST['full_name']) : '';
    $phone = isset($_POST['phone']) ? sanitize($_POST['phone']) : '';
    $address = isset($_POST['user_address']) ? sanitize($_POST['user_address']) : '';
    $role = isset($_POST['user_role']) ? sanitize($_POST['user_role']) : '';

    // 验证必填字段
    if (empty($username) || empty($fullName) || empty($phone) || empty($role)) {
        $message = '请填写所有必填字段';
        $messageType = 'error';
    } else {
        // 编辑用户
        if ($editId > 0) {
            if (empty($password)) {
                // 不更新密码
                $sql = "UPDATE users SET username = ?, full_name = ?, phone = ?, user_address = ?, user_role = ? WHERE user_id = ?";
                $stmt = $conn->prepare($sql);
                if ($stmt) {
                    $stmt->bind_param("sssssi", $username, $fullName, $phone, $address, $role, $editId);
                }
            } else {
                // 更新密码
                $passwordHash = hash('sha256', $password);
                $sql = "UPDATE users SET username = ?, password_hash = ?, full_name = ?, phone = ?, user_address = ?, user_role = ? WHERE user_id = ?";
                $stmt = $conn->prepare($sql);
                if ($stmt) {
                    $stmt->bind_param("ssssssi", $username, $passwordHash, $fullName, $phone, $address, $role, $editId);
                }
            }

            if ($stmt) {
                if ($stmt->execute()) {
                    // 记录操作日志
                    $operationDetails = "用户 {$_SESSION['username']} 更新了用户 {$username} 的信息";
                    log_operation($_SESSION['user_id'], '更新', $operationDetails);

                    $message = '用户更新成功';
                    $messageType = 'success';
                } else {
                    $message = '用户更新失败: ' . $conn->error;
                    $messageType = 'error';
                }
                $stmt->close();
            } else {
                $message = '系统错误: ' . $conn->error;
                $messageType = 'error';
            }
        } else {
            // 添加新用户，密码必填
            if (empty($password)) {
                $message = '添加新用户时密码必填';
                $messageType = 'error';
            } else {
                // 检查用户名是否已存在
                $checkSql = "SELECT COUNT(*) as count FROM users WHERE username = ?";
                $checkStmt = $conn->prepare($checkSql);
                if ($checkStmt) {
                    $checkStmt->bind_param("s", $username);
                    $checkStmt->execute();
                    $result = $checkStmt->get_result();
                    $row = $result->fetch_assoc();
                    if ($row['count'] > 0) {
                        $message = '用户名已存在';
                        $messageType = 'error';
                    } else {
                        // 添加新用户
                        $passwordHash = hash('sha256', $password);
                        $sql = "INSERT INTO users (username, password_hash, full_name, phone, user_address, user_role) VALUES (?, ?, ?, ?, ?, ?)";
                        $stmt = $conn->prepare($sql);
                        if ($stmt) {
                            $stmt->bind_param("ssssss", $username, $passwordHash, $fullName, $phone, $address, $role);
                            if ($stmt->execute()) {
                                // 记录操作日志
                                $operationDetails = "用户 {$_SESSION['username']} 添加了新用户 {$username}";
                                log_operation($_SESSION['user_id'], '添加', $operationDetails);

                                $message = '用户添加成功';
                                $messageType = 'success';
                            } else {
                                $message = '用户添加失败: ' . $conn->error;
                                $messageType = 'error';
                            }
                            $stmt->close();
                        } else {
                            $message = '系统错误: ' . $conn->error;
                            $messageType = 'error';
                        }
                    }
                    $checkStmt->close();
                } else {
                    $message = '系统错误: ' . $conn->error;
                    $messageType = 'error';
                }
            }
        }
    }
}

// 准备编辑用户
$editUser = null;
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $userId = intval($_GET['id']);
    $sql = "SELECT user_id, username, full_name, phone, user_address, user_role FROM users WHERE user_id = ?";
    $stmt = $conn->prepare($sql);
    if ($stmt) {
        $stmt->bind_param("i", $userId);
        $stmt->execute();
        $result = $stmt->get_result();
        if ($result->num_rows > 0) {
            $editUser = $result->fetch_assoc();
        }
        $stmt->close();
    }
}

// 查看用户详情
$viewUser = null;
if (isset($_GET['action']) && $_GET['action'] == 'view' && isset($_GET['id'])) {
    $userId = intval($_GET['id']);
    $sql = "SELECT user_id, username, full_name, phone, user_address, user_role, created_at, updated_at FROM users WHERE user_id = ?";
    $stmt = $conn->prepare($sql);
    if ($stmt) {
        $stmt->bind_param("i", $userId);
        $stmt->execute();
        $result = $stmt->get_result();
        if ($result->num_rows > 0) {
            $viewUser = $result->fetch_assoc();
        }
        $stmt->close();
    }
}

// 获取用户列表
$sql = "SELECT user_id, username, full_name, phone, user_address, user_role FROM users ORDER BY user_id";
$result = $conn->query($sql);
$users = [];
if ($result) {
    while ($row = $result->fetch_assoc()) {
        $users[] = $row;
    }
}
?>

<!-- 显示消息 -->
<?php if (!empty($message)): ?>
    <div class="alert alert-<?php echo $messageType; ?>"><?php echo $message; ?></div>
<?php endif; ?>

<!-- 添加/编辑用户表单 -->
<?php if (isset($_GET['action']) && ($_GET['action'] == 'add' || $_GET['action'] == 'edit')): ?>
    <div class="form-wrapper">
        <form action="index.php?page=user" method="post" class="data-form">
            <?php if ($editUser): ?>
                <input type="hidden" name="edit_id" value="<?php echo $editUser['user_id']; ?>">
                <h3>编辑用户</h3>
            <?php else: ?>
                <h3>添加新用户</h3>
            <?php endif; ?>

            <div class="form-group">
                <label for="username">用户名 <span class="required">*</span></label>
                <input type="text" id="username" name="username" value="<?php echo $editUser ? $editUser['username'] : ''; ?>" required>
            </div>

            <div class="form-group">
                <label for="password">密码 <?php echo $editUser ? '' : '<span class="required">*</span>'; ?></label>
                <input type="password" id="password" name="password" <?php echo $editUser ? '' : 'required'; ?>>
                <?php if ($editUser): ?>
                    <small>如果不需要修改密码，请留空</small>
                <?php endif; ?>
            </div>

            <div class="form-group">
                <label for="full_name">姓名 <span class="required">*</span></label>
                <input type="text" id="full_name" name="full_name" value="<?php echo $editUser ? $editUser['full_name'] : ''; ?>" required>
            </div>

            <div class="form-group">
                <label for="phone">电话 <span class="required">*</span></label>
                <input type="text" id="phone" name="phone" value="<?php echo $editUser ? $editUser['phone'] : ''; ?>" required>
            </div>

            <div class="form-group">
                <label for="user_address">地址</label>
                <input type="text" id="user_address" name="user_address" value="<?php echo $editUser ? $editUser['user_address'] : ''; ?>">
            </div>

            <div class="form-group">
                <label for="user_role">角色 <span class="required">*</span></label>
                <input type="text" id="user_role" name="user_role" value="<?php echo $editUser ? $editUser['user_role'] : ''; ?>" required>
            </div>

            <div class="form-group">
                <button type="submit" class="btn btn-primary">保存</button>
                <a href="index.php?page=user" class="btn btn-secondary">取消</a>
            </div>
        </form>
    </div>
    <!-- 查看用户详情 -->
<?php elseif (isset($_GET['action']) && $_GET['action'] == 'view' && $viewUser): ?>
    <div class="user-details">
        <h3>用户详情</h3>
        <div class="detail-group">
            <label>用户ID:</label>
            <span><?php echo $viewUser['user_id']; ?></span>
        </div>
        <div class="detail-group">
            <label>用户名:</label>
            <span><?php echo $viewUser['username']; ?></span>
        </div>
        <div class="detail-group">
            <label>姓名:</label>
            <span><?php echo $viewUser['full_name']; ?></span>
        </div>
        <div class="detail-group">
            <label>电话:</label>
            <span><?php echo $viewUser['phone']; ?></span>
        </div>
        <div class="detail-group">
            <label>地址:</label>
            <span><?php echo $viewUser['user_address'] ? $viewUser['user_address'] : '未设置'; ?></span>
        </div>
        <div class="detail-group">
            <label>角色:</label>
            <span><?php echo $viewUser['user_role']; ?></span>
        </div>
        <div class="detail-group">
            <label>创建时间:</label>
            <span><?php echo $viewUser['created_at']; ?></span>
        </div>
        <div class="detail-group">
            <label>最后更新:</label>
            <span><?php echo $viewUser['updated_at']; ?></span>
        </div>
        <div class="detail-actions">
            <a href="index.php?page=user" class="btn btn-secondary">返回用户列表</a>
            <a href="index.php?page=user&action=edit&id=<?php echo $viewUser['user_id']; ?>" class="btn btn-primary">编辑用户</a>
        </div>
    </div>

    <style>
        /* 用户详情页面样式 */
        .user-details {
            background-color: #f9f9f9;
            padding: 20px;
            border-radius: 5px;
            margin-bottom: 20px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            border: 1px solid #e0e0e0;
        }

        .user-details h3 {
            margin-top: 0;
            margin-bottom: 20px;
            color: #333;
            border-bottom: 1px solid #ddd;
            padding-bottom: 10px;
            font-size: 1.2em;
        }

        .detail-group {
            margin-bottom: 12px;
            display: flex;
            align-items: center;
            border-bottom: 1px dashed #eee;
            padding-bottom: 8px;
        }

        .detail-group:last-of-type {
            border-bottom: none;
        }

        .detail-group label {
            font-weight: bold;
            width: 120px;
            color: #555;
            flex-shrink: 0;
        }

        .detail-group span {
            flex-grow: 1;
            color: #333;
        }

        .detail-actions {
            margin-top: 20px;
            padding-top: 15px;
            border-top: 1px solid #ddd;
            display: flex;
            gap: 10px;
        }

        .detail-actions .btn {
            padding: 8px 16px;
            text-decoration: none;
            border-radius: 4px;
            font-weight: normal;
            text-align: center;
        }

        /* 确保按钮样式与系统一致 */
        .btn {
            display: inline-block;
            padding: 6px 12px;
            margin-bottom: 0;
            font-size: 14px;
            font-weight: 400;
            line-height: 1.42857143;
            text-align: center;
            white-space: nowrap;
            vertical-align: middle;
            cursor: pointer;
            border: 1px solid transparent;
            border-radius: 4px;
        }

        .btn-primary {
            color: #fff;
            background-color: #337ab7;
            border-color: #2e6da4;
        }

        .btn-primary:hover {
            background-color: #286090;
            border-color: #204d74;
        }

        .btn-secondary {
            color: #fff;
            background-color: #6c757d;
            border-color: #6c757d;
        }

        .btn-secondary:hover {
            background-color: #5a6268;
            border-color: #545b62;
        }
    </style>
    <!-- 用户列表 -->
<?php else: ?>
    <div class="module-tools">
        <div class="tool-left">
            <a href="index.php?page=user&action=add" class="btn btn-primary">添加用户</a>
        </div>
        <div class="tool-right">
            <form action="" method="get" class="search-form">
                <input type="hidden" name="page" value="user">
                <input type="text" name="keyword" placeholder="用户名/姓名/电话" class="search-input">
                <button type="submit" class="btn btn-secondary">搜索</button>
            </form>
        </div>
    </div>

    <div class="data-wrapper">
        <table class="data-table">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>用户名</th>
                    <th>姓名</th>
                    <th>电话</th>
                    <th>地址</th>
                    <th>角色</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php if (count($users) > 0): ?>
                    <?php foreach ($users as $user): ?>
                        <tr>
                            <td><?php echo $user['user_id']; ?></td>
                            <td><?php echo $user['username']; ?></td>
                            <td><?php echo $user['full_name']; ?></td>
                            <td><?php echo $user['phone']; ?></td>
                            <td><?php echo $user['user_address'] ? $user['user_address'] : '未设置'; ?></td>
                            <td><?php echo $user['user_role']; ?></td>
                            <td class="actions">
                                <a href="index.php?page=user&action=view&id=<?php echo $user['user_id']; ?>" class="btn btn-secondary btn-sm">查看</a>
                                <a href="index.php?page=user&action=edit&id=<?php echo $user['user_id']; ?>" class="btn btn-primary btn-sm">编辑</a>
                                <?php if ($user['user_id'] != $_SESSION['user_id']): ?>
                                    <a href="index.php?page=user&action=delete&id=<?php echo $user['user_id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('确定要删除此用户吗？')">删除</a>
                                <?php endif; ?>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="7" class="text-center">暂无用户数据</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
<?php endif; ?>